@@ -1,6 +1,7 @@
 #!/bin/sh
 
 set -xe
+git config --global --add safe.directory /io
 
 if test -d "/io"
 then
@@ -16,9 +17,13 @@ ARCH=x86_64
 MINGW_PREFIX=/usr/${ARCH}-w64-mingw32
 PYMAJMIN=310
 PREFIX=${PWD}/install
-CXXFLAGS="-Wall -Wextra -Wpedantic -Wshadow -Werror -D_GLIBCXX_ASSERTIONS -fuse-ld=lld" ${ARCH}-w64-mingw32-cmake \
-  -DSWIG_COMPILE_FLAGS="-O0 -Wno-unused-parameter -Wno-shadow" \
+CFLAGS="-Wall -Wextra -Wpedantic -Werror" \
+CXXFLAGS="-Wall -Wextra -Wpedantic -Wshadow -Wsuggest-override -Werror -D_GLIBCXX_ASSERTIONS" \
+${ARCH}-w64-mingw32-cmake \
+  -DSWIG_COMPILE_FLAGS="-O1 -Wno-unused-parameter -Wno-shadow" -DSWIG_CXX_COMPILE_FLAGS="-Wno-suggest-override" \
   -DCMAKE_INSTALL_PREFIX=${PREFIX} -DCMAKE_INSTALL_LIBDIR=${PREFIX}/lib \
+  -DCMAKE_LINKER_TYPE=LLD \
+  -DBLA_VENDOR=Generic \
   -DPython_INCLUDE_DIR=${MINGW_PREFIX}/include/python${PYMAJMIN} \
   -DPython_LIBRARY=${MINGW_PREFIX}/lib/libpython${PYMAJMIN}.dll.a \
   -DPython_EXECUTABLE=/usr/bin/${ARCH}-w64-mingw32-python${PYMAJMIN}-bin \
@@ -27,6 +32,6 @@ CXXFLAGS="-Wall -Wextra -Wpedantic -Wshadow -Werror -D_GLIBCXX_ASSERTIONS -fuse-
 make install
 ${ARCH}-w64-mingw32-strip --strip-unneeded ${PREFIX}/bin/*.dll ${PREFIX}/Lib/site-packages/openturns/*.pyd
 echo lib/test ${PREFIX}/Lib/site-packages/openturns | xargs -n 1 cp ${PREFIX}/bin/*.dll
-OPENTURNS_NUM_THREADS=2 ctest -R pyinstallcheck --output-on-failure ${MAKEFLAGS} --repeat after-timeout:2 --schedule-random
+ctest -R pyinstallcheck --output-on-failure ${MAKEFLAGS} --repeat after-timeout:2 --schedule-random
 make tests
-OPENTURNS_NUM_THREADS=2 ctest -R cppcheck --output-on-failure --timeout 1000 ${MAKEFLAGS} --repeat after-timeout:2 --schedule-random
+ctest -R cppcheck --output-on-failure --timeout 1000 ${MAKEFLAGS} --repeat after-timeout:2 --schedule-random
