@@ -2,7 +2,7 @@
 /**
  *  @brief Design matrix cached evaluation
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -103,7 +103,7 @@ String DesignProxy::__repr__() const
 
 
 /* Compute the design matrix with the provided basis terms indices */
-MatrixImplementation DesignProxy::computeDesign(const Indices & indices) const
+Matrix DesignProxy::computeDesign(const Indices & indices) const
 {
   // Quick return if the cache is *exactly* the design matrix
   // In particular, it is the case if the DesignProxy has been
