@@ -2,7 +2,7 @@
 /**
  *  @brief LeastSquares solving algorithm interface
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -76,6 +76,13 @@ LeastSquaresMethod::LeastSquaresMethod(const LeastSquaresMethodImplementation &
   // Nothing to do
 }
 
+/* Constructor from implementation pointer */
+LeastSquaresMethod::LeastSquaresMethod(LeastSquaresMethodImplementation * p_implementation)
+  : TypedInterfaceObject<LeastSquaresMethodImplementation>(p_implementation)
+{
+  // Nothing to do
+}
+
 /* String converter */
 String LeastSquaresMethod::__repr__() const
 {
