@@ -2,7 +2,7 @@
 /**
  *  @brief This Penalized Least Squares Algorithm as a functor class
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -242,7 +242,9 @@ void PenalizedLeastSquaresAlgorithm::run(const DesignProxy & proxy)
   const Scalar empiricalError = quadraticResidual / sampleSize;
 
   // The relative error
-  setRelativeError(empiricalError / y_.computeVariance()[0]);
+  const Scalar yVariance = y_.computeVariance()[0];
+  const Scalar relativeError = (yVariance > 0.0 ? empiricalError / yVariance : -1.0);
+  setRelativeError(relativeError);
 }
 
 
