@@ -2,7 +2,7 @@
 /**
  *  @brief Sparse approximation LS solver
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -23,7 +23,6 @@
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/ResourceMap.hxx"
 #include "openturns/SparseMethod.hxx"
-#include "openturns/TriangularMatrix.hxx"
 #include "openturns/SpecFunc.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
@@ -83,7 +82,7 @@ Point SparseMethod::solve(const Point & rhs)
   const Indices currentIndices(method_.getCurrentIndices());
 
   // for each sub-basis ...
-  Scalar minimumError = SpecFunc::MaxScalar;
+  Scalar minimumError = SpecFunc::Infinity;
 
   Indices optimalBasisIndices;
   UnsignedInteger iterations = 0;
