@@ -2,7 +2,7 @@
 /**
  *  @brief Log records all user information to a file or tty
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,10 +18,9 @@
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
+#include <filesystem>
 #include <iostream>
-#include <cstdlib>
 #include <cassert>
-#include <errno.h>
 
 #include "openturns/Log.hxx"
 #include "openturns/OTconfig.hxx"
@@ -30,16 +29,16 @@
 BEGIN_NAMESPACE_OPENTURNS
 
 static std::mutex Log_InstanceMutex_;
-static Log * Log_P_instance_ = 0;
+static Pointer<Log> Log_P_instance_;
 static const Log_init static_initializer_Log;
 
 static inline
-_Prefix make_prefix( const _Prefix::Value & color, const _Prefix::Value & nocolor, const _Prefix::Value & prefix)
+_Prefix make_prefix(const _Prefix::Value & color, const _Prefix::Value & nocolor, const _Prefix::Value & prefix)
 {
   return _Prefix( color, nocolor, prefix );
 }
 
-std::ostream & operator << ( std::ostream & os, const _Prefix & pfx )
+std::ostream & operator << (std::ostream & os, const _Prefix & pfx)
 {
   return os << (TTY::ColoredOutput() ? pfx.color_ : pfx.nocolor_) << pfx.prefix_;
 }
@@ -53,7 +52,7 @@ Log_init::Log_init()
     Log_P_instance_ = new Log;
     Log_P_instance_->push(Log::Entry(Log::INFO, "*** Log Beginning ***"));
   });
-  assert(Log_P_instance_);
+  assert(Log_P_instance_.get());
 }
 
 Log_init::~Log_init()
@@ -62,8 +61,7 @@ Log_init::~Log_init()
   std::call_once(flag, [&]()
   {
     Log_P_instance_->push(Log::Entry(Log::INFO, "*** Log End ***"));
-    delete Log_P_instance_;
-    Log_P_instance_ = 0;
+    Log_P_instance_.reset();
   });
 }
 
@@ -78,19 +76,13 @@ const Log::Severity Log::WARN    = 1 << 4;
 const Log::Severity Log::ERROR   = 1 << 5;
 const Log::Severity Log::TRACE   = 1 << 6;
 
-const Log::Severity Log::DEFAULT = Log::USER | Log::WARN | Log::ERROR | Log::TRACE;
+const Log::Severity Log::DEFAULT = Log::USER | Log::WARN | Log::ERROR;
 
 static AtomicInt Log_Severity_ = Log::DEFAULT;
 
 
 /* Constructor */
 Log::Log()
-  : logName_(),
-    openturnsLogSeverityVariableName_("OPENTURNS_LOG_SEVERITY"),
-    p_file_(0),
-    previousMessage_(),
-    count_(0),
-    repeat_(1)
 {
   logName_[NONE]    = make_prefix( String(TTY::GetColor(TTY::DEFAULT)), "", "   " );
   logName_[ALL]     = make_prefix( String(TTY::GetColor(TTY::DEFAULT)), "", "ALL" );
@@ -102,22 +94,13 @@ Log::Log()
   logName_[TRACE]   = make_prefix( String(TTY::GetColor(TTY::YELLOWFG)), "", "TRA" );
 
   initSeverityFromEnvironment();
-
 }
 
 
-/* Destructor */
-Log::~Log()
-{
-  delete p_file_;
-  p_file_ = 0;
-}
-
-
-/* Set Severity according to Openturns LogSeverity Variable */
+/* Set Severity according to environment variable */
 void Log::initSeverityFromEnvironment()
 {
-  const char * logSeverityVariableContent = getenv(openturnsLogSeverityVariableName_);
+  const char * logSeverityVariableContent = getenv("OPENTURNS_LOG_SEVERITY");
   if (logSeverityVariableContent != NULL)
   {
     String severityVariableContent(logSeverityVariableContent);
@@ -144,7 +127,7 @@ void Log::initSeverityFromEnvironment()
     }
     while (endPos != static_cast<SignedInteger>(severityVariableContent.size()));
 
-    Show( theSeverity );
+    Show(theSeverity);
   }
 }
 
@@ -165,6 +148,7 @@ MutexLockSingleton<Log> Log::GetInstance()
 
 void Log::Reset()
 {
+  GetInstance().lock().reset();
 }
 
 
@@ -239,23 +223,30 @@ void Log::Flush()
  *  and a message counting how much identical messages were
  *  received after that.
  */
-void Log::Repeat(Bool r)
+void Log::Repeat(const Bool repeat)
 {
-  GetInstance().lock().repeat(r);
+  GetInstance().lock().repeat(repeat);
 }
 
-void Log::repeat(Bool r)
+void Log::repeat(const Bool repeat)
 {
-  repeat_ = r ? 1 : 0;
+  repeat_ = repeat ? 1 : 0;
 }
 
 void Log::flush()
 {
-  printRepeatedMessage( previousMessage_ );
+  printRepeatedMessage(previousMessage_);
   previousMessage_ = Entry();
   count_ = 0;
 }
 
+void Log::reset()
+{
+  Log_Severity_ = Log::DEFAULT;
+  p_file_.reset();
+  repeat_ = 1;
+  initSeverityFromEnvironment();
+}
 
 /* Append an entry at the end of the list */
 void Log::push(const Entry & entry)
@@ -266,8 +257,8 @@ void Log::push(const Entry & entry)
     if (entry.sev_ != Log::TRACE && repeat_.get() && entry == previousMessage_) ++count_;
     else
     {
-      printRepeatedMessage( previousMessage_ );
-      previousMessage_ = entry ;
+      printRepeatedMessage(previousMessage_);
+      previousMessage_ = entry;
       count_ = 0;
       os << logName_[entry.sev_] << " - " << entry.msg_ << TTY::GetColor(TTY::DEFAULT) << std::endl;
     }
@@ -289,16 +280,18 @@ void Log::SetFile(const FileName & file)
 
 
 /* Set the name of the log file */
-void Log::setFile(const FileName & file)
+void Log::setFile(const FileName & fileName)
 {
-  if (file.size())
-    push(Entry(INFO, String("Diverting log to file: ") + file));
+  if (fileName.size())
+    push(Entry(INFO, String("Diverting log to file: ") + fileName));
   push(Entry(INFO, "*** Log End ***"));
-  delete p_file_;
-  TTY::ShowColors(file.size() == 0);
-  p_file_ = file.size() ? new std::ofstream(file.c_str()) : nullptr;
-  if (file.size())
+  p_file_.reset();
+  TTY::ShowColors(fileName.size() == 0);
+  if (fileName.size())
+  {
+    p_file_ = new std::ofstream(std::filesystem::u8path(fileName));
     push(Entry(INFO, "*** Log Beginning ***"));
+  }
 }
 
 /* Color accessor */
