@@ -2,7 +2,7 @@
 /**
  *  @brief This class provides all the treatments for wrapper file manipulation
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,54 +18,33 @@
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
-#include <vector>                 // for std::vector
 #include <string>                 // for std::string
 #include <cstdlib>                // for getenv
-#include <cstring>                // for strcpy
 
 #ifdef _WIN32
-#include <fstream>                // for ofstream
-#include "openturns/OTwindows.h"            // for GetTempFileName, GetModuleFileName
-#ifdef _MSC_VER
-# include <direct.h>
-#define mkdir(p)  _mkdir(p)
-#endif /* _MSC_VER */
-#endif /* WIN32 */
+#include "openturns/OTwindows.h"  // for GetModuleFileName
+#endif
 
 // Include OTConfig that defines OPENTURNS_HAVE_XXX
-// It also defines INSTALL_PATH, SYSCONFIG_PATH, DATA_PATH, OPENTURNS_HOME_ENV_VAR
+// It also defines INSTALL_PATH, SYSCONFIG_PATH, OPENTURNS_HOME_ENV_VAR
 #include "openturns/OTconfig.hxx"
 
 #include "openturns/OSS.hxx"
 #include "openturns/Path.hxx"
 #include "openturns/Exception.hxx"
-#include "openturns/ResourceMap.hxx"
 #include "openturns/Os.hxx"
 #include "openturns/Log.hxx"
-#ifdef OPENTURNS_HAVE_LIBGEN_H
-#include <libgen.h>               // for dirname
-#endif
 
-#ifdef OPENTURNS_HAVE_UNISTD_H
-#include <unistd.h>               // for getpid, readlink, close
-#endif
+#include <filesystem>
 
 #ifndef INSTALL_PATH
 #error "INSTALL_PATH is NOT defined. Check configuration."
 #endif
 
-#ifdef OPENTURNS_HAVE_DIRENT_H
-#include <dirent.h>
-#endif
-
 #ifndef SYSCONFIG_PATH
 #error "SYSCONFIG_PATH is NOT defined. Check configuration."
 #endif
 
-#ifndef DATA_PATH
-#error "DATA_PATH is NOT defined. Check configuration."
-#endif
-
 #ifndef OPENTURNS_HOME_ENV_VAR
 #error "OPENTURNS_HOME_ENV_VAR is NOT defined. Check configuration."
 #endif
@@ -124,27 +103,9 @@ FileName Path::GetInstallationDirectory()
 }
 
 
-FileName Path::GetParentDirectory(const FileName & file)
+FileName Path::GetParentDirectory(const FileName & fileName)
 {
-  FileName parent;
-#ifdef OPENTURNS_HAVE_LIBGEN_H
-  char * szPath = strdup(file.c_str());
-  parent = FileName(dirname(szPath));
-  free(szPath);
-#else
-  parent = file;
-  if (parent.empty()) return parent;
-  for(SignedInteger i = parent.size() - 1; i >= 0; -- i)
-  {
-    /* We do not care about escaped backslashes */
-    if(parent.at(i) == Os::GetDirectorySeparator()[0])
-    {
-      parent.resize(i);
-      break;
-    }
-  }
-#endif
-  return parent;
+  return std::filesystem::u8path(fileName).parent_path().string();
 }
 
 
@@ -302,132 +263,4 @@ FileName Path::FindFileByNameInDirectoryList(const FileName & name,
 } /* end findFileByNameInDirectoryList */
 
 
-/*
- * escape backslash in filename
- * ex: if filename = C:\windows\temp, return C:\\windows\\temp
- */
-void Path::EscapeBackslash(FileName & filename)
-{
-  String backslash("\\");
-  String::size_type loc = filename.find(backslash);
-  while(loc != String::npos)
-  {
-    // "\" at the last pos
-    if(loc == filename.size() - 1)
-    {
-      filename.insert(loc, backslash);
-      break;
-    }
-    // "\" in the middle
-    if(filename.at(loc + 1) != backslash[0])
-      filename.insert(loc, backslash);
-    // else: no "\", or "\\" in the middle
-    loc = filename.find(backslash, loc + 2);
-  }
-}
-
-
-FileName Path::GetTemporaryDirectory()
-{
-  FileName tempDirectory;
-
-  String tempStr(ResourceMap::GetAsString("Path-TemporaryDirectory"));
-#ifndef _WIN32
-  tempDirectory = tempStr;
-#else
-  const char * tempEnv = getenv(tempStr.c_str());
-  if (tempEnv)
-  {
-    // if temporary-directory is an env var, return the content of the env var.
-    tempDirectory = String(tempEnv);
-  }
-  else
-  {
-    // if not, just return the content of temporary-directory
-    tempDirectory = tempStr;
-  }
-#endif
-
-  return tempDirectory;
-}
-
-
-/* Build a temporary file name given a prefix */
-FileName Path::BuildTemporaryFileName(const FileName & prefix)
-{
-#ifndef _WIN32
-  const String fullPattern(GetTemporaryDirectory() + String(Os::GetDirectorySeparator()) + prefix + String("_XXXXXX"));
-  char * temporaryFileName = strdup(fullPattern.c_str());
-  int fileDescriptor(mkstemp(temporaryFileName));
-  close(fileDescriptor);
-  FileName result(temporaryFileName);
-  free(temporaryFileName);
-  return result;
-#else
-  // get uniq name
-  char temporaryFileName[MAX_PATH];
-  GetTempFileName(GetTemporaryDirectory().c_str(), // directory for tmp files
-                  TEXT(prefix.c_str()), // temp file name prefix
-                  0,                     // create unique name
-                  temporaryFileName);    // buffer for name
-  // check temporary filename
-  if (!Os::IsFile(String(temporaryFileName)))
-    LOGERROR(OSS() << "Temporary file name " << temporaryFileName << " does NOT exists. Check your temporary directory.");
-  // add "/" to the directory
-  String slashedTemporaryFileName(temporaryFileName);
-  EscapeBackslash(slashedTemporaryFileName);
-  return slashedTemporaryFileName;
-#endif
-}
-
-/* Create a temporary directory.
- */
-String Path::CreateTemporaryDirectory (const FileName & directoryPrefix)
-{
-  if (directoryPrefix.size() == 0) throw InvalidArgumentException(HERE) << "No prefix defined to create temporary directory";
-
-#ifndef _WIN32
-  String tempDir(GetTemporaryDirectory());
-  tempDir += Os::GetDirectorySeparator();
-  tempDir += directoryPrefix;
-  tempDir += "_XXXXXX";
-
-  char * tempDirName = (char *) calloc(tempDir.size() + 1, sizeof (char));
-  strncpy(tempDirName, tempDir.c_str(), tempDir.size() + 1);
-  char *tempDirName_p = mkdtemp(tempDirName);
-  if ( ! tempDirName_p ) throw FileOpenException(HERE) << "Could not create temporary directory from template " << tempDir;
-  const String finalTempDirName(tempDirName);
-  free(tempDirName);
-#else
-  char temporaryDirName[MAX_PATH];
-  int ret = 0;
-  for (int retry = 10000; retry >= 0; --retry)
-  {
-    ret = GetTempFileName(GetTemporaryDirectory().c_str(),             // directory for tmp files
-                          TEXT((directoryPrefix + "abc").c_str()),     // temp file name prefix (only 3 characters are used)
-                          0,                                           // create unique name
-                          temporaryDirName);                           // buffer for name
-    if (0 == ret)
-    {
-      ret = -1;
-      continue;
-    }
-    DeleteFile(temporaryDirName);
-    ret = mkdir(temporaryDirName);
-    if (0 == ret) break;
-  }
-  if (0 != ret)
-  {
-    LOGERROR(OSS() << "Can't create temporary directory.");
-    temporaryDirName[0] = '\0';
-  }
-
-  const String finalTempDirName(temporaryDirName);
-
-#endif
-
-  return finalTempDirName;
-}
-
-
 END_NAMESPACE_OPENTURNS
