@@ -92,12 +92,6 @@ Description PlatformInfo::GetFeatures()
     Features_["dlib"] = false;
 #endif
 
-#ifdef OPENTURNS_HAVE_IPOPT
-    Features_["ipopt"] = true;
-#else
-    Features_["ipopt"] = false;
-#endif
-
 #ifdef OPENTURNS_HAVE_BONMIN
     Features_["bonmin"] = true;
 #else
@@ -110,6 +104,18 @@ Description PlatformInfo::GetFeatures()
     Features_["cminpack"] = false;
 #endif
 
+#ifdef OPENTURNS_HAVE_HIGHS
+    Features_["highs"] = true;
+#else
+    Features_["highs"] = false;
+#endif
+
+#ifdef OPENTURNS_HAVE_IPOPT
+    Features_["ipopt"] = true;
+#else
+    Features_["ipopt"] = false;
+#endif
+
 #ifdef OPENTURNS_HAVE_PAGMO
     Features_["pagmo"] = true;
 #else
