@@ -2,7 +2,7 @@
 /**
  *  @brief XMLStorageManager provides an interface for different storage classes
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -32,7 +32,6 @@
 #include "openturns/Log.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/OTconfig.hxx"
-#include "openturns/SpecFunc.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -347,7 +346,7 @@ void toStringConverter(const _Tp & value, String & st)
 static inline
 void fromStringConverter(const String & st, Bool & value)
 {
-  value = (st == "true") ? true : false;
+  value = (st == "true");
 }
 
 static inline
