@@ -2,7 +2,7 @@
 /**
  *  @brief Constant basis factory
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -20,7 +20,7 @@
  */
 #include "openturns/ConstantBasisFactory.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
-#include "openturns/LinearFunction.hxx"
+#include "openturns/ConstantFunction.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -52,12 +52,7 @@ ConstantBasisFactory* ConstantBasisFactory::clone() const
 
 Basis ConstantBasisFactory::build() const
 {
-  Point constant(1);
-  constant[0] = 1.;
-  return Basis(Collection<Function>(1,
-                                    LinearFunction (Point(inputDimension_, 0.0),
-                                        constant,
-                                        Matrix(1, inputDimension_))));
+  return Basis({ConstantFunction(inputDimension_, Point({1.0}))});
 }
 
 /* Method save() stores the object through the StorageManager */
