@@ -2,7 +2,7 @@
 /**
  * @brief Abstract top-level class for all evaluation implementations
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -22,12 +22,16 @@
 #include <iterator>
 
 #include "openturns/EvaluationImplementation.hxx"
+#include "openturns/Evaluation.hxx"
 #include "openturns/OTconfig.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
+#include "openturns/Cloud.hxx"
 #include "openturns/Contour.hxx"
 #include "openturns/Curve.hxx"
 #include "openturns/Box.hxx"
 #include "openturns/MarginalEvaluation.hxx"
+#include "openturns/SpecFunc.hxx"
+#include "openturns/PointWithDescription.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -81,6 +85,23 @@ String EvaluationImplementation::__str__(const String & ) const
   return OSS(false) << "EvaluationImplementation";
 }
 
+/* String converter */
+String EvaluationImplementation::_repr_html_() const
+{
+  PointWithDescription parameters(parameter_);
+  parameters.setDescription(parameterDescription_);
+
+  OSS oss(true);
+  oss << "<ul>\n";
+  oss << "  <li> " << "Input dimension = " << getInputDimension() << "  </li>\n";
+  oss << "  <li> " << "Input description = " << getInputDescription() << "  </li>\n";
+  oss << "  <li> " << "Output dimension = " << getOutputDimension() << "  </li>\n";
+  oss << "  <li> " << "Output description = " << getOutputDescription() << "  </li>\n";
+  oss << "  <li> " << "Parameter = " << parameters.__str__() << "  </li>\n";
+  oss << "</ul>\n";
+  return oss;
+}
+
 /* Description Accessor */
 void EvaluationImplementation::setDescription(const Description & description)
 {
@@ -145,7 +166,12 @@ Sample EvaluationImplementation::operator() (const Sample & inSample) const
   Sample outSample(size, getOutputDimension());
   // Simple loop over the evaluation operator based on point
   // The calls number is updated by these calls
-  for (UnsignedInteger i = 0; i < size; ++i) outSample[i] = operator()(inSample[i]);
+  for (UnsignedInteger i = 0; i < size; ++ i)
+  {
+    outSample[i] = operator()(inSample[i]);
+    if (stopCallback_.first && stopCallback_.first(stopCallback_.second))
+      throw InterruptionException(HERE) << "User stopped evaluation";
+  }
   outSample.setDescription(getOutputDescription());
   return outSample;
 }
@@ -307,24 +333,38 @@ Graph EvaluationImplementation::draw(const UnsignedInteger inputMarginal,
   if (!(getInputDimension() >= 1)) throw InvalidArgumentException(HERE) << "Error: cannot use this version of the draw() method with a function of input dimension less than 1, here inputDimension=" << getInputDimension();
   if (!(inputMarginal < getInputDimension())) throw InvalidArgumentException(HERE) << "Error: the given input marginal index=" << inputMarginal << " must be less than the input dimension=" << getInputDimension();
   if (!(outputMarginal < getOutputDimension())) throw InvalidArgumentException(HERE) << "Error: the given output marginal index=" << outputMarginal << " must be less than the output dimension=" << getOutputDimension();
+  if (!(xMin <= xMax)) throw InvalidArgumentException(HERE) << "Error: xMin (" << xMin << ") cannot be greater than xMax(" << xMax << ")";
+  if (pointNumber < 2) throw InvalidArgumentException(HERE) << "Error: the discretization must have at least 2 points";
   const Bool useLogX = (scale == GraphImplementation::LOGX || scale == GraphImplementation::LOGXY);
   if (useLogX && (!(xMin > 0.0 && xMax > 0.0))) throw InvalidArgumentException(HERE) << "Error: cannot use logarithmic scale on an interval containing nonpositive values.";
   if (centralPoint.getDimension() != getInputDimension()) throw InvalidArgumentException(HERE) << "Error: expected a central point of dimension=" << getInputDimension() << ", got dimension=" << centralPoint.getDimension();
-  Sample inputData(pointNumber, centralPoint);
-  if (useLogX)
+
+  Sample inputData;
+  if (xMin < xMax)
   {
-    const Scalar a = std::log(xMin);
-    const Scalar b = std::log(xMax);
-    const Scalar dLogX = (b - a) / (pointNumber - 1.0);
-    for (UnsignedInteger i = 0; i < pointNumber; ++i)
-      inputData(i, inputMarginal) = std::exp(a + i * dLogX);
+    inputData = Sample(pointNumber, centralPoint);
+    if (useLogX)
+    {
+      const Scalar a = std::log(xMin);
+      const Scalar b = std::log(xMax);
+      const Scalar dLogX = (b - a) / (pointNumber - 1.0);
+      for (UnsignedInteger i = 0; i < pointNumber; ++i)
+        inputData(i, inputMarginal) = std::exp(a + i * dLogX);
+    }
+    else
+    {
+      const Scalar dx = (xMax - xMin) / (pointNumber - 1.0);
+      for (UnsignedInteger i = 0; i < pointNumber; ++i)
+        inputData(i, inputMarginal) = xMin + i * dx;
+    }
   }
   else
   {
-    const Scalar dx = (xMax - xMin) / (pointNumber - 1.0);
-    for (UnsignedInteger i = 0; i < pointNumber; ++i)
-      inputData(i, inputMarginal) = xMin + i * dx;
+    // single point
+    inputData = Sample(1, centralPoint);
+    inputData(0, inputMarginal) = xMin;
   }
+
   // Evaluate the function over all its input in one call in order to benefit from potential parallelism
   const Sample outputData((*this)(inputData));
   const Description inputDescription(getInputDescription());
@@ -333,8 +373,12 @@ Graph EvaluationImplementation::draw(const UnsignedInteger inputMarginal,
   const String yName(outputDescription[outputMarginal]);
   String title(OSS() << yName << " as a function of " << xName);
   if (centralPoint.getDimension() > 1) title = String(OSS(false) << title << " around " << centralPoint);
-  Graph graph(title, xName, yName, true, "", 1.0, scale);
-  graph.add(Curve(inputData.getMarginal(inputMarginal), outputData.getMarginal(outputMarginal)));
+  Graph graph(title, xName, yName, true);
+  graph.setLogScale(scale);
+  if (xMin < xMax)
+    graph.add(Curve(inputData.getMarginal(inputMarginal), outputData.getMarginal(outputMarginal)));
+  else
+    graph.add(Cloud(inputData.getMarginal(inputMarginal), outputData.getMarginal(outputMarginal)));
   return graph;
 }
 
@@ -346,7 +390,8 @@ Graph EvaluationImplementation::draw(const UnsignedInteger firstInputMarginal,
                                      const Point & xMin,
                                      const Point & xMax,
                                      const Indices & pointNumber,
-                                     const GraphImplementation::LogScale scale) const
+                                     const GraphImplementation::LogScale scale,
+                                     const Bool isFilled) const
 {
   if (!(getInputDimension() >= 2)) throw InvalidArgumentException(HERE) << "Error: cannot use this version of the draw() method with a function of input dimension less than 2";
   if (!(xMin.getDimension() == 2 && xMax.getDimension() == 2 && pointNumber.getSize() == 2)) throw InvalidArgumentException(HERE) << "Error: xMin, xMax and PointNumber must be bidimensional";
@@ -356,6 +401,7 @@ Graph EvaluationImplementation::draw(const UnsignedInteger firstInputMarginal,
   const Bool useLogY = (scale == GraphImplementation::LOGY || scale == GraphImplementation::LOGXY);
   if (useLogY && (!(xMin[1] > 0.0 && xMax[1] > 0.0))) throw InvalidArgumentException(HERE) << "Error: cannot use logarithmic scale on an interval containing nonpositive values for the second argument.";
   if (centralPoint.getDimension() != getInputDimension()) throw InvalidArgumentException(HERE) << "Error: expected a central point of dimension=" << getInputDimension() << ", got dimension=" << centralPoint.getDimension();
+
   // Discretization of the first component
   const UnsignedInteger nX = pointNumber[0];
   Sample x(nX, 1);
@@ -373,6 +419,7 @@ Graph EvaluationImplementation::draw(const UnsignedInteger firstInputMarginal,
     for (UnsignedInteger i = 0; i < nX; ++i)
       x(i, 0) = xMin[0] + i * dX;
   }
+
   // Discretization of the second component
   const Scalar nY = pointNumber[1];
   Sample y(nY, 1);
@@ -390,42 +437,101 @@ Graph EvaluationImplementation::draw(const UnsignedInteger firstInputMarginal,
     for (UnsignedInteger i = 0; i < nY; ++i)
       y(i, 0) = xMin[1] + i * dY;
   }
-  // Discretization of the XY plane
-  Sample inputSample(nX * nY, centralPoint);
-  // Prepare the input sample
-  UnsignedInteger index = 0;
-  for (UnsignedInteger j = 0; j < nY; ++j)
-  {
-    const Scalar yJ = y(j, 0);
-    for (UnsignedInteger i = 0; i < nX; ++i)
-    {
-      const Scalar xI = x(i, 0);
-      inputSample(index, firstInputMarginal)  = xI;
-      inputSample(index, secondInputMarginal) = yJ;
-      ++index;
-    } // i
-  } // j
-  // Compute the output sample, using possible parallelism
-  const Sample z((*this)(inputSample).getMarginal(outputMarginal));
+
   const String xName(getInputDescription()[firstInputMarginal]);
   const String yName(getInputDescription()[secondInputMarginal]);
   String title(OSS() << getOutputDescription()[outputMarginal] << " as a function of (" << xName << "," << yName << ")");
   if (centralPoint.getDimension() > 2) title = String(OSS(false) << title << " around " << centralPoint);
-  Graph graph(title, xName, yName, true, "topright", 1.0, scale);
-  Contour isoValues(Contour(x, y, z, Point(0), Description(0), true, title));
-  isoValues.buildDefaultLevels();
-  isoValues.buildDefaultLabels();
-  const Point levels(isoValues.getLevels());
-  const Description labels(isoValues.getLabels());
-  for (UnsignedInteger i = 0; i < levels.getDimension(); ++i)
+  Graph graph(title, xName, yName, true, "upper left");
+  graph.setLogScale(scale);
+
+  if (Interval(xMin, xMax).getVolume() > 0.0)
   {
-    Contour current(isoValues);
-    current.setLevels(Point(1, levels[i]));
-    current.setLabels(Description(1, labels[i]));
-    current.setDrawLabels(false);
-    current.setLegend(labels[i]);
-    current.setColor(Contour::ConvertFromHSV((360.0 * i / levels.getDimension()), 1.0, 1.0));
-    graph.add(current);
+    // Discretization of the XY plane
+    Sample inputSample(nX * nY, centralPoint);
+    // Prepare the input sample
+    UnsignedInteger index = 0;
+    for (UnsignedInteger j = 0; j < nY; ++j)
+    {
+      const Scalar yJ = y(j, 0);
+      for (UnsignedInteger i = 0; i < nX; ++i)
+      {
+        const Scalar xI = x(i, 0);
+        inputSample(index, firstInputMarginal)  = xI;
+        inputSample(index, secondInputMarginal) = yJ;
+        ++index;
+      } // i
+    } // j
+    // Compute the output sample, using possible parallelism
+    const Sample z((*this)(inputSample).getMarginal(outputMarginal));
+    Contour isoValues(x, y, z);
+    isoValues.setIsFilled(isFilled);
+    isoValues.setDrawLabels(false);
+    graph.add(isoValues);
+  }
+  else
+  {
+    // degenerate cases
+    Sample inputSample;
+    if (xMin[0] < xMax[0])
+    {
+      // constant Y
+      inputSample = Sample(nX, centralPoint);
+      for (UnsignedInteger i = 0; i < nX; ++ i)
+      {
+        inputSample(i, firstInputMarginal)  = x(i, 0);
+        inputSample(i, secondInputMarginal) = xMin[1];
+      }
+    }
+    else if (xMin[1] < xMax[1])
+    {
+      // constant X
+      inputSample = Sample(nY, centralPoint);
+      for (UnsignedInteger j = 0; j < nY; ++ j)
+      {
+        inputSample(j, firstInputMarginal)  = xMin[0];
+        inputSample(j, secondInputMarginal) = y(j, 0);
+      }
+    }
+    else
+    {
+      // single point
+      inputSample = Sample(1, centralPoint);
+      inputSample(0, firstInputMarginal)  = xMin[0];
+      inputSample(0, secondInputMarginal) = xMin[1];
+    }
+    // Compute the output sample, using possible parallelism
+    const Sample z((*this)(inputSample).getMarginal(outputMarginal));
+    const UnsignedInteger size = inputSample.getSize();
+    if (size > 1)
+    {
+      if (xMin[0] < xMax[0])
+      {
+        // constant Y
+        graph.setXTitle(xName);
+        graph.setYTitle(getOutputDescription()[outputMarginal]);
+        graph.setTitle(OSS() << graph.getYTitle() << " as a function of " << graph.getXTitle());
+        Curve curve(inputSample.getMarginal(firstInputMarginal), z);
+        graph.add(curve);
+      }
+      else if (xMin[1] < xMax[1])
+      {
+        // constant X
+        graph.setXTitle(yName);
+        graph.setYTitle(getOutputDescription()[outputMarginal]);
+        graph.setTitle(OSS() << graph.getYTitle() << " as a function of " << graph.getXTitle());
+        Curve curve(inputSample.getMarginal(secondInputMarginal), z);
+        graph.add(curve);
+      }
+    }
+    else
+    {
+      // single point
+      Cloud cloud(inputSample.getMarginal({firstInputMarginal, secondInputMarginal}), z);
+      const Scalar zMin = z.getMin()[0];
+      cloud.setLegend(OSS() << zMin);
+      graph.add(cloud);
+    }
   }
   return graph;
 }
@@ -453,6 +559,120 @@ Graph EvaluationImplementation::draw(const Point & xMin,
   return draw(0, 1, 0, Point(2), xMin, xMax, pointNumber, scale);
 }
 
+/** Draw the cross-cuts of the function supposed to have 1D output */
+GridLayout EvaluationImplementation::drawCrossCuts(const Point & centralPoint,
+    const Point & xMin,
+    const Point & xMax,
+    const Indices& pointNumber,
+    const Bool withMonoDimensionalCuts,
+    const Bool isFilled,
+    const Scalar vMin,
+    const Scalar vMax) const
+{
+  const UnsignedInteger inputDimension = getInputDimension();
+  if (!(inputDimension >= 2)) throw InvalidArgumentException(HERE) << "Error: cannot draw cross cuts of a function with input dimension=" << inputDimension << " less than 2 using this method. See the other draw() methods.";
+  if (getOutputDimension() != 1) throw InvalidArgumentException(HERE) << "Error: cannot draw cross cuts of a function with output dimension=" << getOutputDimension() << " different from 1 using this method. See the other draw() methods.";
+  if (!(xMin.getDimension() == inputDimension && xMax.getDimension() == inputDimension && pointNumber.getSize() == inputDimension)) throw InvalidArgumentException(HERE) << "Error: xMin, xMax and PointNumber must be of dimension " << inputDimension;
+  for (UnsignedInteger i = 0; i < inputDimension; ++i)
+    if (!(pointNumber[i] > 2)) throw InvalidArgumentException(HERE) << "Error: the discretization must have at least 2 points per component";
+  const Bool buildVMinMax = vMax == -SpecFunc::Infinity && vMin == -SpecFunc::Infinity;
+  Scalar vMinCal = buildVMinMax ? SpecFunc::Infinity : vMin;
+  Scalar vMaxCal = vMax;
+  if (!buildVMinMax && !(vMin < vMax))throw InvalidArgumentException(HERE) << "Error: the vMin value must be less than the vMax value";
+  //Building component samples
+  Collection<Sample>samples(inputDimension);
+  for (UnsignedInteger iX = 0; iX < inputDimension; iX++)
+  {
+    const UnsignedInteger nX = pointNumber[iX];
+    Sample sample(nX, 1);
+    const Scalar dX = (xMax[iX] - xMin[iX]) / (nX - 1.0);
+    for (UnsignedInteger i = 0; i < nX; ++i)
+      sample(i, 0) = xMin[iX] + i * dX;
+    samples[iX] = sample;
+  }
+  //Build contours
+  GridLayout grid(withMonoDimensionalCuts ? inputDimension : inputDimension - 1, withMonoDimensionalCuts ? inputDimension : inputDimension - 1);
+  if (!getName().empty())
+    grid.setTitle("Cross cuts of function " + getName());
+  for (UnsignedInteger iX = 0; iX < inputDimension; iX++)
+  {
+    const Sample x(samples[iX]);
+    for (UnsignedInteger iY = iX + 1; iY < inputDimension; iY++)
+    {
+      // Discretization of the XY plane
+      const UnsignedInteger nX = pointNumber[iX], nY = pointNumber[iY];
+      const Sample y(samples[iY]);
+      Sample inputSample(nX * nY, centralPoint);
+      // Prepare the input sample
+      UnsignedInteger index = 0;
+      for (UnsignedInteger j = 0; j < nY; ++j)
+      {
+        const Scalar yJ = y(j, 0);
+        for (UnsignedInteger i = 0; i < nX; ++i)
+        {
+          const Scalar xI = x(i, 0);
+          inputSample(index, iX) = xI;
+          inputSample(index, iY) = yJ;
+          ++index;
+        } // i
+      } // j
+      // Compute the output sample, using possible parallelism
+      const Sample z((*this)(inputSample));
+      if (buildVMinMax)
+      {
+        vMinCal = std::min(vMinCal, z.getMin()[0]);
+        vMaxCal = std::max(vMaxCal, z.getMax()[0]);
+      }
+      Contour isoValues(x, y, z);
+      isoValues.setIsFilled(isFilled);
+      isoValues.setDrawLabels(!isFilled);
+      isoValues.setColorBarPosition("");
+      Graph graph("", iY + 1 == inputDimension ? getInputDescription()[iX] : "", iX == 0 ? getInputDescription()[iY] : "", true);
+      graph.add(isoValues);
+      grid.setGraph(withMonoDimensionalCuts ? iY : iY - 1, iX, graph);
+    }
+  }
+  if (withMonoDimensionalCuts)
+  {
+    //Build curves
+    for (UnsignedInteger iX = 0; iX < inputDimension; iX++)
+    {
+      Sample x(samples[iX]);
+      const UnsignedInteger nX = pointNumber[iX];
+      Sample inputSample(nX, centralPoint);
+      for (UnsignedInteger i = 0; i < nX; ++i)
+        inputSample(i, iX) = x(i, 0);
+      Graph graph("", iX + 1 == inputDimension ? getInputDescription()[iX] : "", getOutputDescription()[0], true);
+      graph.add(Curve(x, (*this)(inputSample)));
+      grid.setGraph(iX, iX, graph);
+    }
+  }
+  //Uniformize vMin and vMax
+  for (UnsignedInteger iX = 0; iX < inputDimension; iX++)
+  {
+    for (UnsignedInteger iY = iX + 1; iY < inputDimension; iY++)
+    {
+      Contour* contour = dynamic_cast<Contour*>(grid.getGraph(withMonoDimensionalCuts ? iY : iY - 1, iX).getDrawable(0).getImplementation().get());
+      contour->setVmin(vMinCal);
+      contour->setVmax(vMaxCal);
+      Point levels(ResourceMap::GetAsUnsignedInteger("Contour-DefaultLevelsNumber"));
+      for (UnsignedInteger i = 0; i < levels.getSize(); i++)
+        levels[i] = vMinCal + (vMaxCal - vMinCal) * (i + 1) / (levels.getSize() + 1);
+      contour->setLevels(levels);
+    }
+  }
+  return grid;
+}
+
+void EvaluationImplementation::setStopCallback(StopCallback callBack, void * state)
+{
+  stopCallback_ = std::pair<StopCallback, void *>(callBack, state);
+}
+
+void EvaluationImplementation::setDetachCallback(DetachCallback callBack, void * state)
+{
+  detachCallback_ = std::pair<DetachCallback, void *>(callBack, state);
+}
 
 /* Method save() stores the object through the StorageManager */
 void EvaluationImplementation::save(Advocate & adv) const
