@@ -2,7 +2,7 @@
 /**
  * @brief Marginal evaluation
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -88,6 +88,13 @@ String MarginalEvaluation::__repr__() const
   return oss;
 }
 
+String MarginalEvaluation::__str__(const String & ) const
+{
+  OSS oss(false);
+  oss << MarginalEvaluation::GetClassName() << " evaluation=" << p_evaluation_->__str__();
+  return oss;
+}
+
 /* Indices accessor */
 Indices MarginalEvaluation::getIndices() const
 {
