@@ -2,7 +2,7 @@
 /**
  *  @brief Quadratic canonical basis factory
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -20,6 +20,7 @@
  */
 #include "openturns/QuadraticBasisFactory.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
+#include "openturns/ConstantFunction.hxx"
 #include "openturns/LinearFunction.hxx"
 #include "openturns/QuadraticFunction.hxx"
 
@@ -55,7 +56,7 @@ Basis QuadraticBasisFactory::build() const
 {
   Collection<Function> functions;
   // constant term
-  functions.add(LinearFunction (Point(inputDimension_, 0.0), Point(1, 1.0), Matrix(1, inputDimension_)));
+  functions.add(ConstantFunction(inputDimension_, Point({1.0})));
 
   // linear terms
   for ( UnsignedInteger i = 0; i < inputDimension_; ++ i )
