@@ -2,7 +2,7 @@
 /**
  *  @brief DomainImplementation is defined as a domain of \mathbb{R}^d
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -21,6 +21,7 @@
 #include "openturns/DomainImplementation.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/Exception.hxx"
+#include "openturns/TBBImplementation.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -63,13 +64,37 @@ Bool DomainImplementation::contains(const Point & ) const
   throw NotYetImplementedException(HERE) << "In DomainImplementation::contains(const Point & point) const";
 }
 
+class DomainImplementationContainsSamplePolicy
+{
+  const Sample & input_;
+  DomainImplementation::BoolCollection & output_;
+  const DomainImplementation & domain_;
+
+public:
+  DomainImplementationContainsSamplePolicy(const Sample & input,
+      DomainImplementation::BoolCollection & output,
+      const DomainImplementation & domain)
+    : input_(input)
+    , output_(output)
+    , domain_(domain)
+  {
+    // Nothing to do
+  }
+
+  inline void operator()( const TBBImplementation::BlockedRange<UnsignedInteger> & r ) const
+  {
+    for (UnsignedInteger i = r.begin(); i != r.end(); ++i)
+      output_[i] = domain_.contains(input_[i]);
+  } // operator ()
+};  // class DomainImplementationContainsSamplePolicy
+
 /* Check if the given points are inside of the domain */
 DomainImplementation::BoolCollection DomainImplementation::contains(const Sample & sample) const
 {
   const UnsignedInteger size = sample.getSize();
   BoolCollection result(size, 0);
-  for(UnsignedInteger i = 0; i < size; ++ i)
-    result[i] = contains(sample[i]);
+  const DomainImplementationContainsSamplePolicy policy( sample, result, *this );
+  TBBImplementation::ParallelForIf(isParallel(), 0, size, policy);
   return result;
 }
 
@@ -94,6 +119,12 @@ UnsignedInteger DomainImplementation::getDimension() const
   return dimension_;
 }
 
+/* Is it safe to call in parallel? */
+Bool DomainImplementation::isParallel() const
+{
+  return false;
+}
+
 /* Method save() stores the object through the StorageManager */
 void DomainImplementation::save(Advocate & adv) const
 {
