@@ -2,7 +2,7 @@
 /**
  *  @brief DomainUnion represents the union of two Domain
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -28,7 +28,7 @@ BEGIN_NAMESPACE_OPENTURNS
 CLASSNAMEINIT(DomainUnion)
 
 static const Factory<DomainUnion> Factory_DomainUnion;
-
+static const Factory<PersistentCollection<Domain> > Factory_PersistentCollection_Domain;
 
 /* Default constructor */
 DomainUnion::DomainUnion()
@@ -47,13 +47,6 @@ DomainUnion::DomainUnion(const DomainCollection & collection)
       throw InvalidArgumentException(HERE) << "Error: cannot build a DomainUnion from domains of different dimensions";
 }
 
-/* Default constructor */
-DomainUnion::DomainUnion(const Domain & left, const Domain & right)
-  : DomainUnion(DomainCollection({left, right}))
-{
-  LOGWARN(OSS() << "DomainUnion(Domain, Domain) is deprecated in favor of DomainUnion(List[Domain])");
-}
-
 /* Clone method */
 DomainUnion * DomainUnion::clone() const
 {
@@ -86,7 +79,7 @@ Bool DomainUnion::contains(const Point & point) const
 /* Compute the Euclidean distance from a given point to the domain */
 Scalar DomainUnion::computeDistance(const Point & point) const
 {
-  Scalar distance = SpecFunc::MaxScalar;
+  Scalar distance = SpecFunc::Infinity;
   for (UnsignedInteger i = 0; i < collection_.getSize(); ++ i)
     distance = std::min(distance, collection_[i].computeDistance(point));
   return distance;
@@ -103,6 +96,15 @@ Bool DomainUnion::operator != (const DomainUnion & other) const
   return !operator==(other);
 }
 
+/* Is it safe to call in parallel? */
+Bool DomainUnion::isParallel() const
+{
+  for (UnsignedInteger i = 0; i < collection_.getSize(); ++ i)
+    if (!collection_[i].getImplementation()->isParallel())
+      return false;
+  return true;
+}
+
 /* Method save() stores the object through the StorageManager */
 void DomainUnion::save(Advocate & adv) const
 {
