@@ -2,7 +2,7 @@
 /**
  *  @brief MeshDomain converts a Mesh into a DomainImplementation
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -114,6 +114,12 @@ Point MeshDomain::getUpperBound() const
   return mesh_.getUpperBound();
 }
 
+/* Is it safe to call in parallel? */
+Bool MeshDomain::isParallel() const
+{
+  return true;
+}
+
 /* Method save() stores the object through the StorageManager */
 void MeshDomain::save(Advocate & adv) const
 {
