@@ -220,7 +220,7 @@ void AbdoRackwitz::run()
     if (stopCallback_.first && stopCallback_.first(stopCallback_.second))
     {
       stop = true;
-      LOGTRACE(OSS() << "AbdoRackwitz was stopped by user");
+      LOGINFO(OSS() << "AbdoRackwitz was stopped by user");
       result_.setStatus(OptimizationResult::INTERRUPTION);
       result_.setStatusMessage(OSS() << "AbdoRackwitz was stopped by user");
     }
@@ -229,7 +229,7 @@ void AbdoRackwitz::run()
     const Scalar timeDuration = std::chrono::duration<Scalar>(t1 - t0).count();
     if ((getMaximumTimeDuration() > 0.0) && (timeDuration > getMaximumTimeDuration()))
     {
-      LOGTRACE("Optim timeout");
+      LOGINFO("Optim timeout");
       stop = true;
       result_.setStatus(OptimizationResult::TIMEOUT);
       result_.setStatusMessage(OSS() << "AbdoRackwitz optimization timeout after " << timeDuration << "s");
