@@ -2,7 +2,7 @@
 /**
  *  @brief CMinpack solver
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -155,20 +155,20 @@ int CMinpack::ComputeObjectiveJacobian(void *p, int m, int n, const Scalar *x, S
     try
     {
       outP = algorithm->getProblem().getResidualFunction()(inP);
+
+      // track input/outputs
+      algorithm->evaluationInputHistory_.add(inP);
+      algorithm->evaluationOutputHistory_.add(Point(1, 0.5 * outP.normSquare()));
+
+      // update result
+      algorithm->result_.setCallsNumber(algorithm->evaluationInputHistory_.getSize());
+      algorithm->result_.store(inP, Point(1, 0.5 * outP.normSquare()), 0.0, 0.0, 0.0, 0.0);
     }
     catch (const std::exception & exc)
     {
-      LOGWARN(OSS() << "CMinpack went to an abnormal point x=" << inP.__str__() << " y=" << outP.__str__() << " msg=" << exc.what());
+      LOGWARN(OSS() << "CMinpack failed to evaluate residual for x=" << inP.__str__() << " msg=" << exc.what());
+      outP = Point(algorithm->getProblem().getResidualFunction().getOutputDimension(), std::sqrt(SpecFunc::MaxScalar));
     }
-
-    // track input/outputs
-    algorithm->evaluationInputHistory_.add(inP);
-    algorithm->evaluationOutputHistory_.add(Point(1, 0.5 * outP.normSquare()));
-
-    // update result
-    algorithm->result_.setCallsNumber(algorithm->evaluationInputHistory_.getSize());
-    algorithm->result_.store(inP, Point(1, 0.5 * outP.normSquare()), 0.0, 0.0, 0.0, 0.0);
-
     std::copy(outP.begin(), outP.end(), fvec);
   }
   else if (iflag == 2)
@@ -181,7 +181,7 @@ int CMinpack::ComputeObjectiveJacobian(void *p, int m, int n, const Scalar *x, S
     }
     catch (const std::exception & exc)
     {
-      LOGWARN(OSS() << "CMinpack went to an abnormal point x=" << inP.__str__() << " jacobian=" << jacobian.__str__() << " msg=" << exc.what());
+      LOGWARN(OSS() << "CMinpack failed to evaluate residual gradient for x=" << inP.__str__() << " msg=" << exc.what());
     }
     if (algorithm->getProblem().hasBounds())
     {
@@ -204,7 +204,7 @@ int CMinpack::ComputeObjectiveJacobian(void *p, int m, int n, const Scalar *x, S
   }
   if (algorithm->stopCallback_.first && algorithm->stopCallback_.first(algorithm->stopCallback_.second))
   {
-    LOGWARN("CMinpack was stopped by user");
+    LOGINFO("CMinpack was stopped by user");
     return -1;
   }
   return 0;
@@ -216,6 +216,7 @@ int CMinpack::ComputeObjectiveJacobian(void *p, int m, int n, const Scalar *x, S
 void CMinpack::run()
 {
 #ifdef OPENTURNS_HAVE_CMINPACK
+  result_ = OptimizationResult(getProblem());
   const UnsignedInteger dimension = getProblem().getDimension();
   Point startingPoint(getStartingPoint());
   if (startingPoint.getDimension() != dimension)
@@ -389,8 +390,7 @@ void CMinpack::run()
                maxfev, &diag[0], mode, factor, nprint, &nfev, &njev,
                &ipvt[0], &qtf[0], &wa1[0], &wa2[0], &wa3[0], &wa4[0]);
 
-  setResultFromEvaluationHistory(evaluationInputHistory_, evaluationOutputHistory_);
-
+  result_ = OptimizationResult(getProblem());
   std::chrono::steady_clock::time_point t1 = std::chrono::steady_clock::now();
   const Scalar timeDuration = std::chrono::duration<Scalar>(t1 - t0_).count();
   result_.setTimeDuration(timeDuration);
@@ -434,7 +434,7 @@ void CMinpack::run()
       result_.setStatusMessage("Unknown");
       throw NotYetImplementedException(HERE) << "CMinpack: unknown status code:" << info;
   }
-  LOGDEBUG(OSS() << "CMinpack status: " << result_.getStatusMessage());
+  setResultFromEvaluationHistory(evaluationInputHistory_, evaluationOutputHistory_);
 #else
   throw NotYetImplementedException(HERE) << "No CMinpack support";
 #endif
