@@ -2,7 +2,7 @@
 /**
  *  @brief Ceres solver
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -132,8 +132,9 @@ public:
       algorithm_.evaluationInputHistory_.add(inP);
       algorithm_.evaluationOutputHistory_.add(Point(1, 0.5 * outP.normSquare()));
     }
-    catch (Exception &)
+    catch (const Exception & exc)
     {
+      LOGWARN(OSS() << "Ceres failed to evaluate residual for x=" << inP.__str__() << " msg=" << exc.what());
       return false;
     }
 
@@ -145,8 +146,9 @@ public:
         const Matrix gradient(problem.getResidualFunction().gradient(inP));
         std::copy(gradient.data(), gradient.data() + m * n, jacobians[0]);
       }
-      catch (Exception &)
+      catch (const Exception & exc)
       {
+        LOGWARN(OSS() << "Ceres failed to evaluate residual gradient for x=" << inP.__str__() << " msg=" << exc.what());
         return false;
       }
     }
@@ -191,8 +193,9 @@ public:
       algorithm_.result_.setCallsNumber(algorithm_.evaluationInputHistory_.getSize());
       algorithm_.result_.store(inP, outP, 0.0, 0.0, 0.0, 0.0);
     }
-    catch (Exception &)
+    catch (const Exception & exc)
     {
+      LOGWARN(OSS() << "Ceres failed to evaluate objective for x=" << inP.__str__() << " msg=" << exc.what());
       return false;
     }
 
@@ -204,8 +207,9 @@ public:
         const Matrix gradient(problem.isMinimization() ? problem.getObjective().gradient(inP) : -1.0 * problem.getObjective().gradient(inP));
         std::copy(gradient.data(), gradient.data() + n, jacobian);
       }
-      catch (Exception &)
+      catch (const Exception & exc)
       {
+        LOGWARN(OSS() << "Ceres failed to evaluate objective gradient for x=" << inP.__str__() << " msg=" << exc.what());
         return false;
       }
     }
@@ -224,7 +228,7 @@ public:
     : ceres::IterationCallback()
     , algorithm_(algorithm) {}
 
-  virtual ceres::CallbackReturnType operator()(const ceres::IterationSummary & summary)
+  virtual ceres::CallbackReturnType operator()(const ceres::IterationSummary & summary) override
   {
     if (algorithm_.progressCallback_.first)
       algorithm_.progressCallback_.first(100.0 * summary.iteration / algorithm_.getMaximumIterationNumber(), algorithm_.progressCallback_.second);
@@ -245,6 +249,7 @@ protected:
 void Ceres::run()
 {
 #ifdef OPENTURNS_HAVE_CERES
+  result_ = OptimizationResult(getProblem());
   const UnsignedInteger dimension = getProblem().getDimension();
   Point x(getStartingPoint());
   if (x.getDimension() != dimension)
@@ -359,16 +364,26 @@ void Ceres::run()
       options.gradient_tolerance = ResourceMap::GetAsScalar("Ceres-gradient_tolerance");
     if (ResourceMap::HasKey("Ceres-parameter_tolerance"))
       options.parameter_tolerance = ResourceMap::GetAsScalar("Ceres-parameter_tolerance");
-    if (ResourceMap::HasKey("Ceres-linear_solver_type") && !ceres::StringToLinearSolverType(ResourceMap::Get("Ceres-linear_solver_type"), &options.linear_solver_type))
-      throw InvalidArgumentException(HERE) << "Invalid value for linear_solver_type";
     if (ResourceMap::HasKey("Ceres-preconditioner_type") && !ceres::StringToPreconditionerType(ResourceMap::Get("Ceres-preconditioner_type"), &options.preconditioner_type))
       throw InvalidArgumentException(HERE) << "Invalid value for preconditioner_type";
     if (ResourceMap::HasKey("Ceres-visibility_clustering_type") && !ceres::StringToVisibilityClusteringType(ResourceMap::Get("Ceres-visibility_clustering_type"), &options.visibility_clustering_type))
       throw InvalidArgumentException(HERE) << "Invalid value for visibility_clustering_type";
     if (ResourceMap::HasKey("Ceres-dense_linear_algebra_library_type") && !ceres::StringToDenseLinearAlgebraLibraryType(ResourceMap::Get("Ceres-dense_linear_algebra_library_type"), &options.dense_linear_algebra_library_type))
       throw InvalidArgumentException(HERE) << "Invalid value for dense_linear_algebra_library_type";
+
+    // prefer eigen sparse algebra backend over suitesparse
+    if (ceres::IsSparseLinearAlgebraLibraryTypeAvailable(ceres::EIGEN_SPARSE))
+      options.sparse_linear_algebra_library_type = ceres::EIGEN_SPARSE;
+    else
+    {
+      options.sparse_linear_algebra_library_type = ceres::NO_SPARSE;
+      options.linear_solver_type = ceres::DENSE_QR;
+    }
     if (ResourceMap::HasKey("Ceres-sparse_linear_algebra_library_type") && !ceres::StringToSparseLinearAlgebraLibraryType(ResourceMap::Get("Ceres-sparse_linear_algebra_library_type"), &options.sparse_linear_algebra_library_type))
       throw InvalidArgumentException(HERE) << "Invalid value for sparse_linear_algebra_library_type";
+    if (ResourceMap::HasKey("Ceres-linear_solver_type") && !ceres::StringToLinearSolverType(ResourceMap::Get("Ceres-linear_solver_type"), &options.linear_solver_type))
+      throw InvalidArgumentException(HERE) << "Invalid value for linear_solver_type";
+
     if (ResourceMap::HasKey("Ceres-use_explicit_schur_complement"))
       options.use_explicit_schur_complement = ResourceMap::GetAsBool("Ceres-use_explicit_schur_complement");
     if (ResourceMap::HasKey("Ceres-dynamic_sparsity"))
@@ -486,11 +501,12 @@ void Ceres::run()
     time = summary.total_time_in_seconds;
   }
 
-  setResultFromEvaluationHistory(evaluationInputHistory_, evaluationOutputHistory_);
+  result_ = OptimizationResult(getProblem());
   result_.setIterationNumber(iterationNumber);
   result_.setStatusMessage(ceres::TerminationTypeToString(termination_type));
   result_.setTimeDuration(time);
 
+  setResultFromEvaluationHistory(evaluationInputHistory_, evaluationOutputHistory_);
   if (termination_type == ceres::FAILURE)
   {
     result_.setStatus(OptimizationResult::FAILURE);
