@@ -2,7 +2,7 @@
 /**
  *  @brief NLopt solver
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,6 +36,15 @@ static const Factory<NLopt> Factory_NLopt;
 /* Map to associate algorithm names and codes */
 std::map<String, UnsignedInteger> NLopt::AlgorithmNames_;
 
+UnsignedInteger NLopt::GetVersion()
+{
+  int major = 0, minor = 0, bugfix = 0;
+#ifdef OPENTURNS_HAVE_NLOPT
+  nlopt::version(major, minor, bugfix);
+#endif
+  return major * 100000 + minor * 100 + bugfix;
+}
+
 /* Static method to initialize the algorithm names/codes pairing in nlopt */
 void NLopt::InitializeAlgorithmNames()
 {
@@ -49,13 +58,9 @@ void NLopt::InitializeAlgorithmNames()
   AlgorithmNames_["GN_DIRECT_L_RAND_NOSCAL"] = nlopt::GN_DIRECT_L_RAND_NOSCAL;
   AlgorithmNames_["GN_ORIG_DIRECT"] = nlopt::GN_ORIG_DIRECT;
   AlgorithmNames_["GN_ORIG_DIRECT_L"] = nlopt::GN_ORIG_DIRECT_L;
-#ifdef OPENTURNS_NLOPT_HAVE_STOGO
-  AlgorithmNames_["GD_STOGO"] = nlopt::GD_STOGO;
-  AlgorithmNames_["GD_STOGO_RAND"] = nlopt::GD_STOGO_RAND;
-#endif
-  // LD_LBFGS_NOCEDAL is not wired
+  // GD_STOGO/GD_STOGO_RAND: https://github.com/stevengj/nlopt/issues/529
   AlgorithmNames_["LD_LBFGS"] = nlopt::LD_LBFGS;
-  AlgorithmNames_["LN_PRAXIS"] = nlopt::LN_PRAXIS;
+  // LN_PRAXIS: https://github.com/stevengj/nlopt/issues/528
   AlgorithmNames_["LD_VAR1"] = nlopt::LD_VAR1;
   AlgorithmNames_["LD_VAR2"] = nlopt::LD_VAR2;
   AlgorithmNames_["LD_TNEWTON"] = nlopt::LD_TNEWTON;
@@ -70,8 +75,8 @@ void NLopt::InitializeAlgorithmNames()
   AlgorithmNames_["LD_MMA"] = nlopt::LD_MMA;
   AlgorithmNames_["LN_COBYLA"] = nlopt::LN_COBYLA;
   AlgorithmNames_["LN_NEWUOA"] = nlopt::LN_NEWUOA;
-  // https://github.com/stevengj/nlopt/issues/511
-  //AlgorithmNames_["LN_NEWUOA_BOUND"] = nlopt::LN_NEWUOA_BOUND;
+  if (GetVersion() >= 200900) // https://github.com/stevengj/nlopt/issues/511
+    AlgorithmNames_["LN_NEWUOA_BOUND"] = nlopt::LN_NEWUOA_BOUND;
   AlgorithmNames_["LN_NELDERMEAD"] = nlopt::LN_NELDERMEAD;
   AlgorithmNames_["LN_SBPLX"] = nlopt::LN_SBPLX;
   AlgorithmNames_["LN_AUGLAG"] = nlopt::LN_AUGLAG;
@@ -87,9 +92,7 @@ void NLopt::InitializeAlgorithmNames()
   AlgorithmNames_["LD_SLSQP"] = nlopt::LD_SLSQP;
   AlgorithmNames_["LD_CCSAQ"] = nlopt::LD_CCSAQ;
   AlgorithmNames_["GN_ESCH"] = nlopt::GN_ESCH;
-#ifdef OPENTURNS_NLOPT_HAVE_AGS
-  AlgorithmNames_["GN_AGS"] = nlopt::GN_AGS;
-#endif
+  // GN_AGS only supports 1-d constraint
 #else
   throw NotYetImplementedException(HERE) << "No NLopt support";
 #endif
@@ -114,22 +117,21 @@ UnsignedInteger NLopt::GetAlgorithmCode(const String & name)
   return it->second;
 }
 
-
-void NLopt::SetSeed(const UnsignedInteger seed)
+void NLopt::setSeed(const UnsignedInteger seed)
 {
-#ifdef OPENTURNS_HAVE_NLOPT
-  nlopt::srand(seed);
-#else
-  (void)seed;
-  throw NotYetImplementedException(HERE) << "No NLopt support";
-#endif
+  seed_ = seed;
 }
 
+UnsignedInteger NLopt::getSeed() const
+{
+  return seed_;
+}
 
 /* Default constructor */
 NLopt::NLopt(const String & algoName)
   : OptimizationAlgorithmImplementation()
   , algoName_(algoName)
+  , seed_(ResourceMap::GetAsUnsignedInteger("NLopt-InitialSeed"))
 {
   GetAlgorithmCode(algoName);
 }
@@ -138,6 +140,7 @@ NLopt::NLopt(const OptimizationProblem & problem,
              const String & algoName)
   : OptimizationAlgorithmImplementation(problem)
   , algoName_(algoName)
+  , seed_(ResourceMap::GetAsUnsignedInteger("NLopt-InitialSeed"))
 {
   checkProblem(problem);
 }
@@ -153,6 +156,10 @@ void NLopt::checkProblem(const OptimizationProblem & problem) const
 {
   if (problem.hasMultipleObjective())
     throw InvalidArgumentException(HERE) << "Error: " << getAlgorithmName() << " does not support multi-objective optimization";
+
+  if (problem.hasResidualFunction())
+    throw InvalidArgumentException(HERE) << "Error : " << this->getClassName() << " does not support least squares problems";
+
   if (!problem.isContinuous())
     throw InvalidArgumentException(HERE) << "Error: " << getClassName() << " does not support non continuous problems";
 
@@ -171,8 +178,15 @@ void NLopt::checkProblem(const OptimizationProblem & problem) const
   if ((getAlgorithmName() == "LN_NEWUOA") && problem.hasBounds())
     throw InvalidArgumentException(HERE) << "Error: LN_NEWUOA algorithm does not support bounds";
 
-#ifdef OPENTURNS_HAVE_NLOPT
   const UnsignedInteger dimension = problem.getDimension();
+  if (Description({"LN_NEWUOA", "LN_NEWUOA_BOUND"}).contains(getAlgorithmName()) && (dimension < 2))
+    throw InvalidArgumentException(HERE) << "Error: LN_NEWUOA algorithm does not support dimension < 2";
+
+  // PRAXIS bounds support is buggy https://github.com/stevengj/nlopt/issues/528
+  if ((getAlgorithmName() == "LN_PRAXIS") && problem.hasBounds() && (GetVersion() < 200900))
+    throw InvalidArgumentException(HERE) << "Error: LN_PRAXIS algorithm does not support bounds";
+
+#ifdef OPENTURNS_HAVE_NLOPT
   const nlopt::algorithm algo = static_cast<nlopt::algorithm>(GetAlgorithmCode(getAlgorithmName()));
   nlopt::opt opt(algo, dimension);
 
@@ -210,6 +224,7 @@ void NLopt::checkProblem(const OptimizationProblem & problem) const
 void NLopt::run()
 {
 #ifdef OPENTURNS_HAVE_NLOPT
+  result_ = OptimizationResult(getProblem());
   const UnsignedInteger dimension = getProblem().getDimension();
   Point startingPoint(getStartingPoint());
   if (startingPoint.getDimension() != dimension)
@@ -238,7 +253,9 @@ void NLopt::run()
   opt.set_xtol_abs(getMaximumAbsoluteError());
   opt.set_xtol_rel(getMaximumRelativeError());
   opt.set_ftol_rel(getMaximumResidualError());
-  opt.set_maxeval(getMaximumEvaluationNumber());
+  opt.set_maxeval(getMaximumCallsNumber());
+  if (getMaximumTimeDuration() > 0.0)
+    opt.set_maxtime(getMaximumTimeDuration());
 
   if (getProblem().hasBounds())
   {
@@ -252,7 +269,7 @@ void NLopt::run()
     for (UnsignedInteger i = 0; i < dimension; ++ i)
     {
       if (!finiteLowerBound[i]) lb[i] = SpecFunc::LowestScalar;
-      if (!finiteUpperBound[i]) ub[i] =  SpecFunc::MaxScalar;
+      if (!finiteUpperBound[i]) ub[i] =  SpecFunc::Infinity;
     }
     opt.set_lower_bounds(lb);
     opt.set_upper_bounds(ub);
@@ -287,7 +304,7 @@ void NLopt::run()
     local_opt.set_xtol_abs(getMaximumAbsoluteError());
     local_opt.set_xtol_rel(getMaximumRelativeError());
     local_opt.set_ftol_rel(getMaximumResidualError());
-    local_opt.set_maxeval(getMaximumEvaluationNumber());
+    local_opt.set_maxeval(getMaximumCallsNumber());
     opt.set_local_optimizer(local_opt);
   }
   else
@@ -298,7 +315,7 @@ void NLopt::run()
     local_opt.set_xtol_abs(p_localSolver_->getMaximumAbsoluteError());
     local_opt.set_xtol_rel(p_localSolver_->getMaximumRelativeError());
     local_opt.set_ftol_rel(p_localSolver_->getMaximumResidualError());
-    local_opt.set_maxeval(p_localSolver_->getMaximumEvaluationNumber());
+    local_opt.set_maxeval(p_localSolver_->getMaximumCallsNumber());
     if (p_localSolver_->getInitialStep().getDimension() > 0)
     {
       Point localInitialStep(p_localSolver_->getInitialStep());
@@ -311,26 +328,31 @@ void NLopt::run()
   std::vector<double> x(startingPoint.toStdVector());
   double optimalValue = 0.0;
 
+  // the default seed is non-deterministic
+  nlopt::srand(seed_);
+  nlopt::result rc = nlopt::FAILURE;
+
   try
   {
     // The C++ interface of NLopt does not return a code for failures cases.
     // It is either positive (termination criterion) or an exception is thrown.
     p_opt_ = &opt;
-    opt.optimize(x, optimalValue);
+    rc = opt.optimize(x, optimalValue);
   }
   catch (const nlopt::roundoff_limited &)
   {
-    // Here we catch the roundoff_limited exception as the result
-    // of the optimization may be useful even if not at the requested precision
-    LOGWARN("NLopt raised a roundoff-limited exception");
+    rc = nlopt::ROUNDOFF_LIMITED;
   }
   catch (const nlopt::forced_stop &)
   {
-    LOGWARN("NLopt was stopped by user");
+    rc = nlopt::FORCED_STOP;
   }
-  catch (const std::exception & exc)
+  catch (const std::bad_alloc &)
+  {
+    rc = nlopt::OUT_OF_MEMORY;
+  }
+  catch (const std::exception &)
   {
-    throw InternalException(HERE) << "NLopt raised an exception: " << exc.what();
   }
   p_opt_ = nullptr;
 
@@ -339,7 +361,26 @@ void NLopt::run()
   if (getProblem().hasInequalityConstraint() && (inequalityConstraintHistory_.getSize() != evaluationInputHistory_.getSize()))
     inequalityConstraintHistory_ = getProblem().getInequalityConstraint()(evaluationInputHistory_);
 
+  result_ = OptimizationResult(getProblem());
+  result_.setStatusMessage(nlopt_result_to_string((nlopt_result)rc));
+  if (rc == nlopt::MAXTIME_REACHED)
+    result_.setStatus(OptimizationResult::TIMEOUT);
+  else if ((rc == nlopt::MAXEVAL_REACHED) && (algoName_[0] != 'G')) // global algorithms never converge, do not return an error
+    result_.setStatus(OptimizationResult::MAXIMUMCALLS);
+  else if (rc == nlopt::FORCED_STOP)
+    result_.setStatus(OptimizationResult::SUCCESS);
+  else if (rc < 0)
+    result_.setStatus(OptimizationResult::FAILURE);
+
   setResultFromEvaluationHistory(evaluationInputHistory_, evaluationOutputHistory_, inequalityConstraintHistory_, equalityConstraintHistory_);
+  if (result_.getStatus() != OptimizationResult::SUCCESS)
+  {
+    if (getCheckStatus())
+      throw InternalException(HERE) << "NLopt raised an exception: " << result_.getStatusMessage();
+    else
+      LOGWARN(OSS() << "NLopt algorithm failed: " << result_.getStatusMessage());
+  }
+
 #else
   (void) p_opt_;
   throw NotYetImplementedException(HERE) << "No NLopt support";
@@ -373,6 +414,7 @@ void NLopt::save(Advocate & adv) const
   adv.saveAttribute("initialStep_", initialStep_);
   if (!p_localSolver_.isNull())
     adv.saveAttribute("localSolver_", *p_localSolver_);
+  adv.saveAttribute("seed_", seed_);
 }
 
 /* Method load() reloads the object from the StorageManager */
@@ -387,6 +429,8 @@ void NLopt::load(Advocate & adv)
     adv.loadAttribute("localSolver_", localSolver);
     p_localSolver_ = localSolver.clone();
   }
+  if (adv.hasAttribute("seed_"))
+    adv.loadAttribute("seed_", seed_);
 }
 
 void NLopt::setAlgorithmName(const String algoName)
@@ -436,7 +480,7 @@ double NLopt::ComputeObjective(const std::vector<double> & x, std::vector<double
   algorithm->evaluationOutputHistory_.add(outP);
 
   // update result
-  algorithm->result_.setEvaluationNumber(algorithm->evaluationInputHistory_.getSize());
+  algorithm->result_.setCallsNumber(algorithm->evaluationInputHistory_.getSize());
   algorithm->result_.store(inP, outP, 0.0, 0.0, 0.0, 0.0);
 
   // gradient
@@ -457,7 +501,7 @@ double NLopt::ComputeObjective(const std::vector<double> & x, std::vector<double
   // callbacks
   if (algorithm->progressCallback_.first)
   {
-    algorithm->progressCallback_.first((100.0 * algorithm->evaluationInputHistory_.getSize()) / algorithm->getMaximumEvaluationNumber(), algorithm->progressCallback_.second);
+    algorithm->progressCallback_.first((100.0 * algorithm->evaluationInputHistory_.getSize()) / algorithm->getMaximumCallsNumber(), algorithm->progressCallback_.second);
   }
   if (algorithm->stopCallback_.first)
   {
