@@ -2,7 +2,7 @@
 /**
  *  @brief OptimizationAlgorithm provides capabilities to solve optimization problems
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -19,12 +19,14 @@
  *
  */
 #include "openturns/OptimizationAlgorithm.hxx"
+#include "openturns/AbdoRackwitz.hxx"
 #include "openturns/Bonmin.hxx"
 #include "openturns/Ceres.hxx"
 #include "openturns/CMinpack.hxx"
 #include "openturns/Cobyla.hxx"
 #include "openturns/Dlib.hxx"
 #include "openturns/Ipopt.hxx"
+#include "openturns/SQP.hxx"
 #include "openturns/TNC.hxx"
 #include "openturns/NLopt.hxx"
 #include "openturns/Pagmo.hxx"
@@ -76,6 +78,18 @@ void OptimizationAlgorithm::setStartingPoint(const Point & startingPoint)
   getImplementation()->setStartingPoint(startingPoint);
 }
 
+/* Starting sample accessor */
+Sample OptimizationAlgorithm::getStartingSample() const
+{
+  return getImplementation()->getStartingSample();
+}
+
+void OptimizationAlgorithm::setStartingSample(const Sample & startingSample)
+{
+  copyOnWrite();
+  getImplementation()->setStartingSample(startingSample);
+}
+
 /* Problem accessor */
 OptimizationProblem OptimizationAlgorithm::getProblem() const
 {
@@ -238,7 +252,11 @@ Bool OptimizationAlgorithm::getCheckStatus() const
 OptimizationAlgorithm OptimizationAlgorithm::GetByName(const String & solverName)
 {
   OptimizationAlgorithm solver;
-  if (PlatformInfo::HasFeature("ceres") && Ceres::GetAlgorithmNames().contains(solverName))
+  if (solverName == "AbdoRackwitz")
+  {
+    solver = AbdoRackwitz();
+  }
+  else if (PlatformInfo::HasFeature("ceres") && Ceres::GetAlgorithmNames().contains(solverName))
   {
     solver = Ceres(solverName);
   }
@@ -250,6 +268,10 @@ OptimizationAlgorithm OptimizationAlgorithm::GetByName(const String & solverName
   {
     solver = Cobyla();
   }
+  else if (solverName == "SQP")
+  {
+    solver = SQP();
+  }
   else if (solverName == "TNC")
   {
     solver = TNC();
@@ -281,12 +303,6 @@ OptimizationAlgorithm OptimizationAlgorithm::GetByName(const String & solverName
 }
 
 
-OptimizationAlgorithm OptimizationAlgorithm::Build(const String & solverName)
-{
-  LOGWARN("OptimizationAlgorithm.Build is deprecated in favor of GetByName");
-  return GetByName(solverName);
-}
-
 OptimizationAlgorithm OptimizationAlgorithm::Build(const OptimizationProblem & problem)
 {
   // return the first algorithm that accepts the problem
@@ -311,6 +327,7 @@ OptimizationAlgorithm OptimizationAlgorithm::Build(const OptimizationProblem & p
 Description OptimizationAlgorithm::GetAlgorithmNames()
 {
   Description names;
+  names.add("AbdoRackwitz");
   if (PlatformInfo::HasFeature("bonmin"))
     names.add(Bonmin::GetAlgorithmNames());
   if (PlatformInfo::HasFeature("ipopt"))
@@ -322,6 +339,7 @@ Description OptimizationAlgorithm::GetAlgorithmNames()
   names.add("Cobyla");
   if (PlatformInfo::HasFeature("dlib"))
     names.add(Dlib::GetAlgorithmNames());
+  names.add("SQP");
   names.add("TNC");
   if (PlatformInfo::HasFeature("nlopt"))
     names.add(NLopt::GetAlgorithmNames());
@@ -338,7 +356,7 @@ Description OptimizationAlgorithm::GetAlgorithmNames(const OptimizationProblem &
   Description result;
   for (UnsignedInteger i = 0; i < names.getSize(); ++ i)
   {
-    OptimizationAlgorithm algorithm(Build(names[i]));
+    OptimizationAlgorithm algorithm(GetByName(names[i]));
     try
     {
       algorithm.setProblem(problem);
