@@ -2,7 +2,7 @@
 /**
  *  @brief OptimizationProblem implements an algorithm for finding the
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -178,6 +178,31 @@ Bool OptimizationProblem::hasResidualFunction() const
   return getImplementation()->hasResidualFunction();
 }
 
+
+/* Linear function accessor */
+Point OptimizationProblem::getLinearCost() const
+{
+  return getImplementation()->getLinearCost();
+}
+
+
+Matrix OptimizationProblem::getLinearConstraintCoefficients() const
+{
+  return getImplementation()->getLinearConstraintCoefficients();
+}
+
+
+Interval OptimizationProblem::getLinearConstraintBounds() const
+{
+  return getImplementation()->getLinearConstraintBounds();
+}
+
+
+Bool OptimizationProblem::isLinear() const
+{
+  return getImplementation()->isLinear();
+}
+
 /* Dimension accessor */
 UnsignedInteger OptimizationProblem::getDimension() const
 {
@@ -208,7 +233,7 @@ Indices OptimizationProblem::getVariablesType() const
   return getImplementation()->getVariablesType();
 }
 
-bool OptimizationProblem::isContinuous() const
+Bool OptimizationProblem::isContinuous() const
 {
   return getImplementation()->isContinuous();
 }
