@@ -2,7 +2,7 @@
 /**
  *  @brief OptimizationResult stores the result of a OptimizationAlgorithmImplementation
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -349,7 +349,7 @@ void OptimizationResult::store(const Point & x,
   {
     Bool isNormal = true;
     for (UnsignedInteger j = 0; j < x.getDimension(); ++ j)
-      if (!SpecFunc::IsNormal(x[j]))
+      if (!std::isfinite(x[j]))
         isNormal = false;
     for (UnsignedInteger j = 0; j < y.getDimension(); ++ j)
       if (std::isnan(y[j]))
