@@ -21,7 +21,6 @@
 
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/RungeKutta.hxx"
-#include "openturns/SpecFunc.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -76,7 +75,7 @@ Sample RungeKutta::solve(const Point & initialState,
     const Scalar timeStep = newT - t;
     const Point phi(computeStep(transitionFunction, t, state, timeStep));
     for (UnsignedInteger j = 0; j < phi.getDimension(); ++ j)
-      if (!SpecFunc::IsNormal(phi[j]))
+      if (!std::isfinite(phi[j]))
         throw InvalidArgumentException(HERE) << "RungeKutta: Step is " << phi.__str__() << " at " << state.__str__() << " with t=" << t << " h=" << timeStep;
     state += timeStep * phi;
     result[i] = state;
