@@ -2,7 +2,7 @@
 /**
  *  @brief Interface class for a nonlinear scalar solver
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -90,6 +90,21 @@ Scalar Solver::solve(const Function & function,
   return getImplementation()->solve(function, value, infPoint, supPoint, infValue, supValue);
 }
 
+/** Solve attempt to find one root to a system of equations function(x) = 0 given a starting point x_0 */
+Point Solver::solve(const Function & function,
+                    const Point & startingPoint) const
+{
+  return getImplementation()->solve(function, startingPoint);
+}
+
+/** Solve attempt to find one root to a system of equations function(x) = 0 given a starting point x_0 and bounds */
+Point Solver::solve(const Function & function,
+                    const Point & startingPoint,
+                    const Interval & bounds) const
+{
+  return getImplementation()->solve(function, startingPoint, bounds);
+}
+
 /* Absolute error accessor */
 void Solver::setAbsoluteError(const Scalar absoluteError)
 {
