@@ -2,7 +2,7 @@
 /**
  *  @brief
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -23,7 +23,6 @@
 #include "openturns/SolverImplementation.hxx"
 #include "openturns/Exception.hxx"
 #include "openturns/Point.hxx"
-#include "openturns/ResourceMap.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
@@ -143,29 +142,11 @@ UnsignedInteger SolverImplementation::getMaximumCallsNumber() const
   return maximumCallsNumber_;
 }
 
-void SolverImplementation::setMaximumFunctionEvaluation(const UnsignedInteger maximumFunctionEvaluation)
-{
-  LOGWARN("Solver.setMaximumFunctionEvaluation is deprecated, use setMaximumCallsNumber");
-  setMaximumCallsNumber(maximumFunctionEvaluation);
-}
-
-UnsignedInteger SolverImplementation::getMaximumFunctionEvaluation() const
-{
-  LOGWARN("Solver.getMaximumFunctionEvaluation is deprecated, use setMaximumCallsNumber");
-  return getMaximumCallsNumber();
-}
-
 UnsignedInteger SolverImplementation::getCallsNumber() const
 {
   return callsNumber_;
 }
 
-UnsignedInteger SolverImplementation::getUsedFunctionEvaluation() const
-{
-  LOGWARN("Solver.getUsedFunctionEvaluation is deprecated, use getCallsNumber");
-  return getCallsNumber();
-}
-
 namespace
 {
 class UniVariateFunctionFromFunction: public UniVariateFunctionImplementation
@@ -178,7 +159,12 @@ public:
     // Nothing to do
   }
 
-  Scalar operator() (const Scalar x) const
+  UniVariateFunctionFromFunction * clone() const override
+  {
+    return new UniVariateFunctionFromFunction(*this);
+  }
+
+  Scalar operator() (const Scalar x) const override
   {
     return function_(Point(1, x))[0];
   }
@@ -236,4 +222,18 @@ Scalar SolverImplementation::solve(const UniVariateFunction &,
   throw NotYetImplementedException(HERE) << "In SolverImplementation::solve(const UniVariateFunction & function, const Scalar value, const Scalar infPoint, const Scalar supPoint, const Scalar infValue, const Scalar supValue) const";
 }
 
+/** Solve attempt to find one root to a system of equations function(x) = 0 given a starting point x_0 */
+Point SolverImplementation::solve(const Function &,
+                                  const Point &) const
+{
+  throw NotYetImplementedException(HERE) << "In SolverImplementation::solve(const Function &, const Point &)";
+}
+
+Point SolverImplementation::solve(const Function &,
+                                  const Point &,
+                                  const Interval &) const
+{
+  throw NotYetImplementedException(HERE) << "In SolverImplementation::solve(const Function &, const Point &, const Interval&)";
+}
+
 END_NAMESPACE_OPENTURNS
