@@ -2,7 +2,7 @@
 /**
  *  @brief RandomGenerator implements methods to control the random generator
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -87,13 +87,15 @@ RandomGeneratorState RandomGenerator::GetState()
   return state;
 }
 
+void RandomGenerator::Reset()
+{
+  SetSeed(ResourceMap::GetAsUnsignedInteger("RandomGenerator-InitialSeed"));
+}
+
 void RandomGenerator::Initialize()
 {
   if (!IsInitialized_)
-  {
-    SetSeed(ResourceMap::GetAsUnsignedInteger("RandomGenerator-InitialSeed"));
-    IsInitialized_ = true;
-  }
+    Reset();
 }
 
 /* Generate a pseudo-random number uniformly distributed over ]0, 1[ */
