@@ -2,7 +2,7 @@
 /**
  *  @brief MatrixImplementation implements the classical mathematical MatrixImplementation
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -647,18 +647,15 @@ Bool MatrixImplementation::isTriangular(Bool lower) const
 }
 
 /* Comparison operator */
-Bool MatrixImplementation::operator == (const MatrixImplementation & rhs) const
+Bool MatrixImplementation::operator == (const MatrixImplementation & other) const
 {
-  const MatrixImplementation &lhs(*this);
   Bool equality = true;
-
-  if (&lhs != &rhs)   // Not the same object
+  if (this != &other)
   {
-    const Collection<Scalar> & refLhs(static_cast<const Collection<Scalar> >(lhs));
-    const Collection<Scalar> & refRhs(static_cast<const Collection<Scalar> >(rhs));
-    equality = ( lhs.nbRows_ == rhs.nbRows_ && lhs.nbColumns_ == rhs.nbColumns_ && refLhs == refRhs);
+    const Collection<Scalar> & refLhs(*this);
+    const Collection<Scalar> & refRhs(other);
+    equality = (nbRows_ == other.nbRows_ && nbColumns_ == other.nbColumns_ && (refLhs == refRhs));
   }
-
   return equality;
 }
 
@@ -1302,7 +1299,7 @@ Bool MatrixImplementation::computeLargestEigenValueModuleSquare(Scalar & maximum
   Point currentEigenVector(dimension, 1.0);
   Point nextEigenVector(genVectProd(currentEigenVector));
   Scalar nextEigenValue = nextEigenVector.norm();
-  if (!SpecFunc::IsNormal(nextEigenValue))
+  if (!std::isfinite(nextEigenValue))
     throw InvalidArgumentException(HERE) << "Cannot compute eigen value due to nan/inf values";
   maximumModule = nextEigenValue / std::sqrt(1.0 * dimension);
   Bool found = false;
@@ -1330,7 +1327,7 @@ Bool MatrixImplementation::computeLargestEigenValueModuleSym(Scalar & maximumMod
   Point currentEigenVector(dimension, 1.0);
   Point nextEigenVector(symVectProd(currentEigenVector));
   Scalar nextEigenValue = nextEigenVector.norm();
-  if (!SpecFunc::IsNormal(nextEigenValue))
+  if (!std::isfinite(nextEigenValue))
     throw InvalidArgumentException(HERE) << "Cannot compute eigen value due to nan/inf values";
   maximumModule = nextEigenValue / std::sqrt(1.0 * dimension);
   Bool found = false;
@@ -1365,7 +1362,7 @@ Point MatrixImplementation::computeSingularValuesInPlace()
   // check for nans, cf https://github.com/Reference-LAPACK/lapack/issues/469
   for (UnsignedInteger j = 0; j < getNbColumns(); ++ j)
     for (UnsignedInteger i = 0; i < getNbRows(); ++ i)
-      if (!SpecFunc::IsNormal(operator()(i, j)))
+      if (!std::isfinite(operator()(i, j)))
         throw InvalidArgumentException(HERE) << "Cannot compute singular values due to nan/inf values";
 
   char jobz = 'N';
@@ -1549,7 +1546,7 @@ MatrixImplementation MatrixImplementation::computeRegularizedCholesky() const
     throw InvalidArgumentException(HERE) << "In MatrixImplementation::computeRegularizedCholesky, could not compute the Cholesky factor."
                                          << " Scaling up to "  << cumulatedScaling << " was not enough";
   if (cumulatedScaling > 0.0)
-    LOGWARN(OSS() <<  "Warning! Scaling up to " << cumulatedScaling << " was needed in order to factorize the matrix.");
+    LOGINFO(OSS() <<  "Scaling up to " << cumulatedScaling << " was needed in order to factorize the matrix.");
   return choleskyFactor;
 }
 
