@@ -2,7 +2,7 @@
 /**
  *  @brief Analytical implements an algorithm to find the design point
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -21,9 +21,10 @@
 #include <cmath>
 
 #include "openturns/Analytical.hxx"
-#include "openturns/Distribution.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/NearestPointProblem.hxx"
+#include "openturns/ResourceMap.hxx"
+#include "openturns/StandardEvent.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -39,15 +40,29 @@ Analytical::Analytical(const OptimizationAlgorithm & nearestPointAlgorithm,
                        const Point & physicalStartingPoint)
   : PersistentObject(),
     nearestPointAlgorithm_(nearestPointAlgorithm),
-    event_(event),
-    physicalStartingPoint_(physicalStartingPoint)
+    event_(event)
 {
+  if (physicalStartingPoint.getSize())
+  {
+    LOGWARN("FORM/SORM physicalStartingPoint argument is deprecated");
+    nearestPointAlgorithm_.setStartingPoint(physicalStartingPoint);
+  }
+
   const UnsignedInteger dimension = event.getImplementation()->getFunction().getInputDimension();
-  if (physicalStartingPoint.getDimension() != dimension)
-    throw InvalidArgumentException(HERE) << "Starting point dimension (" << physicalStartingPoint.getDimension() << ") does not match event dimension (" << dimension << ").";
+
+  try
+  {
+    if (nearestPointAlgorithm_.getStartingPoint().getDimension() != dimension)
+      throw InvalidArgumentException(HERE) << "Starting point dimension (" << nearestPointAlgorithm_.getStartingPoint().getDimension() << ") does not match event dimension (" << dimension << ").";
+  }
+  catch (const NotDefinedException &) // MultiStart algorithm
+  {
+    if (nearestPointAlgorithm_.getStartingSample().getDimension() != dimension)
+      throw InvalidArgumentException(HERE) << "Starting sample dimension (" << nearestPointAlgorithm_.getStartingSample()[0].getDimension() << ") does not match event dimension (" << dimension << ").";
+  }
+
   if (!event_.getImplementation()->getAntecedent().getDistribution().isContinuous())
     throw InvalidArgumentException(HERE) << "FORM/SORM only allows for continuous distributions";
-  result_ = AnalyticalResult(event_.getImplementation()->getAntecedent().getDistribution().getIsoProbabilisticTransformation().operator()(physicalStartingPoint_), event, true);
 }
 
 
@@ -60,13 +75,15 @@ Analytical * Analytical::clone() const
 /* Physical starting point accessor */
 Point Analytical::getPhysicalStartingPoint() const
 {
-  return physicalStartingPoint_;
+  LOGWARN("Analytical.getPhysicalStartingPoint is deprecated");
+  return nearestPointAlgorithm_.getStartingPoint();
 }
 
 /* Physical starting point accessor */
 void Analytical::setPhysicalStartingPoint(const Point & physicalStartingPoint)
 {
-  physicalStartingPoint_ = physicalStartingPoint;
+  LOGWARN("Analytical.setPhysicalStartingPoint is deprecated");
+  nearestPointAlgorithm_.setStartingPoint(physicalStartingPoint);
 }
 
 /* Event accessor */
@@ -100,7 +117,7 @@ String Analytical::__repr__() const
   oss << "class=" << Analytical::GetClassName()
       << " nearestPointAlgorithm=" << nearestPointAlgorithm_.__repr__()
       << " event=" << event_
-      << " physicalstartingPoint=" << physicalStartingPoint_;
+      << " physicalstartingPoint=" << nearestPointAlgorithm_.getStartingPoint();
   return oss;
 }
 
@@ -111,26 +128,53 @@ void Analytical::run()
   StandardEvent standardEvent(event_);
 
   /* set the level function of the algorithm */
-  nearestPointAlgorithm_.setProblem(NearestPointProblem(standardEvent.getImplementation()->getFunction(), standardEvent.getThreshold()));
+  OptimizationAlgorithm nearestPointAlgorithm(nearestPointAlgorithm_);
+  nearestPointAlgorithm.setProblem(NearestPointProblem(standardEvent.getImplementation()->getFunction(), standardEvent.getThreshold()));
 
-  /* set the starting point of the algorithm in the standard space  */
-  nearestPointAlgorithm_.setStartingPoint(event_.getImplementation()->getAntecedent().getDistribution().getIsoProbabilisticTransformation().operator()(physicalStartingPoint_));
+  try
+  {
+    /* set the starting point of the algorithm in the standard space */
+    nearestPointAlgorithm.setStartingPoint(event_.getImplementation()->getAntecedent().getDistribution().getIsoProbabilisticTransformation().operator()(nearestPointAlgorithm.getStartingPoint()));
+  }
+  catch (const NotDefinedException &) // MultiStart algorithm
+  {
+    /* set the starting sample of the algorithm in the standard space */
+    nearestPointAlgorithm.setStartingSample(event_.getImplementation()->getAntecedent().getDistribution().getIsoProbabilisticTransformation().operator()(nearestPointAlgorithm.getStartingSample()));
+  }
 
   /* solve the nearest point problem */
-  nearestPointAlgorithm_.run();
+  nearestPointAlgorithm.run();
+
+  /* set standard space design point in Result */
+  Point standardSpaceDesignPoint(nearestPointAlgorithm.getResult().getOptimalPoint());
+  standardSpaceDesignPoint.setName("Standard Space Design Point");
+
+  result_ = AnalyticalResult(standardSpaceDesignPoint, event_, true);
 
   /* store the optimization result into the analytical result */
-  result_.setOptimizationResult(nearestPointAlgorithm_.getResult());
-  /* set standard space design point in Result */
-  Point standardSpaceDesignPoint(nearestPointAlgorithm_.getResult().getOptimalPoint());
-  standardSpaceDesignPoint.setName("Standard Space Design Point");
-  result_.setStandardSpaceDesignPoint(standardSpaceDesignPoint);
+  result_.setOptimizationResult(nearestPointAlgorithm.getResult());
 
   /* set isStandardPointOriginInFailureSpace in Result */
-  Point origin(standardSpaceDesignPoint.getDimension(), 0.0);
-  Point value(standardEvent.getImplementation()->getFunction().operator()(origin));
+  const Point origin(standardSpaceDesignPoint.getDimension(), 0.0);
+  const Point value(standardEvent.getImplementation()->getFunction().operator()(origin));
 
   result_.setIsStandardPointOriginInFailureSpace(event_.getOperator().compare(value[0], event_.getThreshold()));
+
+  /* check if result is valid */
+  const Point physicalSpaceDesignPoint(event_.getImplementation()->getAntecedent().getDistribution().getInverseIsoProbabilisticTransformation().operator()(standardSpaceDesignPoint));
+
+  const Point valuePhysicalSpaceDesignPoint(event_.getImplementation()->getFunction().operator()(physicalSpaceDesignPoint));
+
+  const Scalar residual = result_.getOptimizationResult().getConstraintError();
+
+  const Scalar limitStateTolerance = nearestPointAlgorithm.getMaximumConstraintError();
+
+  // to prevent numerical approximation made in Cobyla for constraint satisfaction tolerance
+  const Scalar toleranceFactor = ResourceMap::GetAsScalar("Analytical-LimitStateToleranceFactor");
+
+  if (!(residual <= toleranceFactor * limitStateTolerance))
+    throw Exception(HERE) << "Obtained design point is not on the limit state: its image by the limit state function is " << valuePhysicalSpaceDesignPoint[0] << ", which is incompatible with the threshold: " << event_.getThreshold() << " considering the limit state tolerance of the optimization algorithm: " << limitStateTolerance;
+
 } /* Analytical::run() */
 
 /* Result accessor */
@@ -143,11 +187,9 @@ AnalyticalResult Analytical::getAnalyticalResult() const
 /* Method save() stores the object through the StorageManager */
 void Analytical::save(Advocate & adv) const
 {
-
   PersistentObject::save(adv);
   adv.saveAttribute("nearestPointAlgorithm_", nearestPointAlgorithm_);
   adv.saveAttribute("event_", event_);
-  adv.saveAttribute("physicalStartingPoint_", physicalStartingPoint_);
   adv.saveAttribute("result_", result_);
 }
 
@@ -157,7 +199,13 @@ void Analytical::load(Advocate & adv)
   PersistentObject::load(adv);
   adv.loadAttribute("nearestPointAlgorithm_", nearestPointAlgorithm_);
   adv.loadAttribute("event_", event_);
-  adv.loadAttribute("physicalStartingPoint_", physicalStartingPoint_);
+  if (adv.hasAttribute("physicalStartingPoint_"))
+  {
+    // OT < 1.25
+    Point physicalStartingPoint;
+    adv.loadAttribute("physicalStartingPoint_", physicalStartingPoint);
+    nearestPointAlgorithm_.setStartingPoint(physicalStartingPoint);
+  }
   adv.loadAttribute("result_", result_);
 }
 
