@@ -24,6 +24,7 @@
 #include "openturns/SymbolicFunction.hxx"
 #include "openturns/Normal.hxx"
 #include "openturns/NearestPointProblem.hxx"
+#include "openturns/StandardEvent.hxx"
 
 
 BEGIN_NAMESPACE_OPENTURNS
@@ -132,7 +133,7 @@ void MultiFORM::run()
     {
       ++ designPointNumber;
       // the symmetric of the design point is the next starting point
-      setPhysicalStartingPoint(getEvent().getImplementation()->getAntecedent().getDistribution().getInverseIsoProbabilisticTransformation().operator()(formResult.getStandardSpaceDesignPoint() * -1.0));
+      nearestPointAlgorithm_.setStartingPoint(getEvent().getImplementation()->getAntecedent().getDistribution().getInverseIsoProbabilisticTransformation().operator()(formResult.getStandardSpaceDesignPoint() * -1.0));
       formResultCollection.add(formResult);
     }
 
