@@ -2,7 +2,7 @@
 /**
  *  @brief The result of a chaos expansion
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -20,16 +20,11 @@
  */
 #include "openturns/FunctionalChaosResult.hxx"
 #include "openturns/OSS.hxx"
-#include "openturns/Sample.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/ComposedFunction.hxx"
 #include "openturns/DualLinearCombinationFunction.hxx"
 #include "openturns/Curve.hxx"
-#include <unordered_map>
-#include "openturns/OrthogonalProductPolynomialFactory.hxx"
-#include "openturns/LinearEnumerateFunction.hxx"
-#include "openturns/HyperbolicAnisotropicEnumerateFunction.hxx"
-#include "openturns/NormInfEnumerateFunction.hxx"
+#include "openturns/ConstantFunction.hxx"
 #include "openturns/DistributionTransformation.hxx"
 #include "openturns/Basis.hxx"
 
@@ -64,10 +59,8 @@ FunctionalChaosResult::FunctionalChaosResult(const Sample & inputSample,
     const OrthogonalBasis & orthogonalBasis,
     const Indices & I,
     const Sample & alpha_k,
-    const FunctionCollection & Psi_k,
-    const Point & residuals,
-    const Point & relativeErrors)
-  : MetaModelResult(inputSample, outputSample, Function(), residuals, relativeErrors)
+    const FunctionCollection & Psi_k)
+  : MetaModelResult(inputSample, outputSample, ConstantFunction(inputSample.getDimension(), Point(outputSample.getDimension())))
   , distribution_(distribution)
   , transformation_(transformation)
   , inverseTransformation_(inverseTransformation)
@@ -76,8 +69,19 @@ FunctionalChaosResult::FunctionalChaosResult(const Sample & inputSample,
   , alpha_k_(alpha_k)
   , Psi_k_(Psi_k)
 {
-  // The composed meta model will be a dual linear combination
-  composedMetaModel_ = DualLinearCombinationFunction(Psi_k, alpha_k);
+  if (Psi_k.getSize() > 0)
+  {
+    // The composed meta model will be a dual linear combination
+    composedMetaModel_ = DualLinearCombinationFunction(Psi_k, alpha_k);
+  }
+  else
+  {
+    // The meta model is the null function
+    composedMetaModel_ = ConstantFunction(inputSample.getDimension(), Point(outputSample.getDimension()));
+    Psi_k_.add(orthogonalBasis.build(0));
+    alpha_k_ = Sample(1, outputSample.getDimension());
+    I_.add(0);
+  }
   if (transformation.getEvaluation().getImplementation()->getClassName() == "IdentityEvaluation")
     metaModel_ = composedMetaModel_;
   else
@@ -105,8 +109,6 @@ String FunctionalChaosResult::__repr__() const
          << " indices=" << I_
          << " coefficients=" << alpha_k_
          << " reduced basis=" << Psi_k_
-         << " residuals=" << residuals_
-         << " relativeErrors=" << relativeErrors_
          << " composedMetaModel=" << composedMetaModel_
          << " metaModel=" << metaModel_
          << " isLeastSquares=" << isLeastSquares_
@@ -122,7 +124,15 @@ String FunctionalChaosResult::__repr_markdown__() const
 {
   OSS oss(false);
   const UnsignedInteger indicesSize = I_.getSize();
-  const EnumerateFunction enumerateFunction(orthogonalBasis_.getEnumerateFunction());
+  EnumerateFunction enumerateFunction;
+  try
+  {
+    enumerateFunction = orthogonalBasis_.getEnumerateFunction();
+  }
+  catch (const NotYetImplementedException &)
+  {
+  }
+
   const UnsignedInteger outputDimension = metaModel_.getOutputDimension();
   const UnsignedInteger inputDimension = distribution_.getDimension();
   oss << getClassName() << "\n"
@@ -133,8 +143,6 @@ String FunctionalChaosResult::__repr_markdown__() const
       << "- inverse transformation=" << inverseTransformation_.getInputDimension() << " -> " << inverseTransformation_.getOutputDimension() << "\n"
       << "- orthogonal basis dimension=" << orthogonalBasis_.getMeasure().getDimension() << "\n"
       << "- indices size=" << indicesSize << "\n"
-      << "- relative errors=" << relativeErrors_ << "\n"
-      << "- residuals=" << residuals_ << "\n"
       << "- is least squares=" << isLeastSquares_ << "\n"
       << "- is model selection=" << involvesModelSelection_ << "\n";
   oss << "\n";
@@ -396,9 +404,7 @@ FunctionalChaosResult FunctionalChaosResult::getConditionalExpectation(const Ind
     orthogonalBasisMarginal,
     listOfActiveReducedIndices,
     activeCoefficients,
-    activeReducedBasis,
-    residuals_,
-    relativeErrors_
+    activeReducedBasis
   );
   return conditionalPCE;
 }
@@ -543,4 +549,51 @@ Graph FunctionalChaosResult::drawErrorHistory() const
   return result;
 }
 
+FunctionalChaosResult FunctionalChaosResult::getMarginal(const UnsignedInteger indexOutput) const
+{
+  return getMarginal(Indices({indexOutput}));
+}
+
+FunctionalChaosResult FunctionalChaosResult::getMarginal(const Indices & indicesOutput) const
+{
+  const UnsignedInteger outputDimension(outputSample_.getDimension());
+  if ((indicesOutput.getSize() == outputDimension) && indicesOutput.isIncreasing())
+    return *this;
+  if (!indicesOutput.check(outputDimension))
+    throw InvalidArgumentException(HERE) << "Requested indices exceed output dimension (" << outputDimension << ")";
+  const Sample marginalOutputSample(outputSample_.getMarginal(indicesOutput));
+  const Sample marginalCoefficients(alpha_k_.getMarginal(indicesOutput));
+
+  // Extract nonzero coefficients only
+  const UnsignedInteger numberOfCoefficients(marginalCoefficients.getSize());
+  // Set nonzero coefficients
+  const UnsignedInteger numberOfMarginalOutputDimensions = indicesOutput.getSize();
+  Indices nonzeroIndices(0);
+  Sample nonzeroCoefficients(0, numberOfMarginalOutputDimensions);
+  Collection<Function> nonzeroFunctions(0);
+  for (UnsignedInteger i = 0; i < numberOfCoefficients; ++ i)
+  {
+    Point marginalCoeff = marginalCoefficients[i];
+    if (marginalCoeff.normSquare() > 0.0)
+    {
+      nonzeroCoefficients.add(marginalCoeff);
+      nonzeroIndices.add(I_[i]);
+      nonzeroFunctions.add(Psi_k_[i]);
+    }
+  }
+
+  const FunctionalChaosResult marginalPCE(
+      inputSample_,
+      marginalOutputSample,
+      distribution_,
+      transformation_,
+      inverseTransformation_,
+      orthogonalBasis_,
+      nonzeroIndices,
+      nonzeroCoefficients,
+      nonzeroFunctions
+  );
+  return marginalPCE;
+}
+
 END_NAMESPACE_OPENTURNS
