@@ -30,6 +30,7 @@
 #include "openturns/LinearCombinationFunction.hxx"
 #include "openturns/AggregatedFunction.hxx"
 #include "openturns/MemoizeFunction.hxx"
+#include "openturns/LinearFunction.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -125,16 +126,19 @@ void GaussianProcessFitter::setCovarianceModel(const CovarianceModel & covarianc
         }
     } // reducedCovarianceModel_.getDimension() == 1
   } // optimizeParameters_
-  LOGINFO(OSS() << "final active parameters=" << reducedCovarianceModel_.getActiveParameter());
+  LOGDEBUG(OSS() << "final active parameters=" << reducedCovarianceModel_.getActiveParameter());
   // Define the bounds of the optimization problem
   const UnsignedInteger optimizationDimension = reducedCovarianceModel_.getParameter().getSize();
   if (optimizationDimension > 0)
   {
-    const Scalar scaleFactor(ResourceMap::GetAsScalar( "GaussianProcessFitter-DefaultOptimizationScaleFactor"));
-    if (!(scaleFactor > 0))
-      throw InvalidArgumentException(HERE) << "Scale factor set in ResourceMap is invalid. It should be a positive value. Here, scale = " << scaleFactor ;
-    Point lowerBound(optimizationDimension, ResourceMap::GetAsScalar( "GaussianProcessFitter-DefaultOptimizationLowerBound"));
-    Point upperBound(optimizationDimension, ResourceMap::GetAsScalar( "GaussianProcessFitter-DefaultOptimizationUpperBound"));
+    const Scalar lowerBoundScaleFactor = ResourceMap::GetAsScalar("GaussianProcessFitter-OptimizationLowerBoundScaleFactor");
+    if (!(lowerBoundScaleFactor > 0.0))
+      throw InvalidArgumentException(HERE) << "GPR lower bound scale factor set in ResourceMap should be positive, got " << lowerBoundScaleFactor;
+    const Scalar upperBoundScaleFactor = ResourceMap::GetAsScalar("GaussianProcessFitter-OptimizationUpperBoundScaleFactor");
+    if (!(upperBoundScaleFactor > 0.0))
+      throw InvalidArgumentException(HERE) << "GPR upper bound scale factor set in ResourceMap should be positive, got " << upperBoundScaleFactor;
+    Point lowerBound(optimizationDimension, ResourceMap::GetAsScalar("GaussianProcessFitter-DefaultOptimizationLowerBound"));
+    Point upperBound(optimizationDimension, ResourceMap::GetAsScalar("GaussianProcessFitter-DefaultOptimizationUpperBound"));
     // We could set scale parameter if these parameters are enabled.
     // check if some scales are active
     // check if nugget factor is active
@@ -158,15 +162,15 @@ void GaussianProcessFitter::setCovarianceModel(const CovarianceModel & covarianc
       const Point inputSampleRange(inputSample_.computeRange());
       for (UnsignedInteger k = 0; k < activeScalesPositions.getSize(); ++k)
       {
-        upperBound[k] = inputSampleRange[activeScalesIndices[k]] * scaleFactor;
-        if (upperBound[k] < lowerBound[k])
-          upperBound[k] += lowerBound[k];
+        const Scalar rangeK = inputSampleRange[activeScalesIndices[k]];
+        lowerBound[k] = rangeK * lowerBoundScaleFactor;
+        upperBound[k] = rangeK * upperBoundScaleFactor;
       } // k (upper bounds setting)
     } // if active scale
     if (activeNugget.getSize() > 0)
       // Set the lower bound to 0 for nuggetFactor
-      lowerBound[activeNugget[0]] = ResourceMap::GetAsScalar( "GaussianProcessFitter-DefaultOptimizationNuggetLowerBound" );
-    LOGWARN(OSS() <<  "Warning! For coherency we set scale upper bounds = " << upperBound.__str__());
+      lowerBound[activeNugget[0]] = ResourceMap::GetAsScalar("GaussianProcessFitter-DefaultOptimizationNuggetLowerBound");
+    LOGINFO(OSS() <<  "For coherency we set scale upper bounds = " << upperBound.__str__());
 
     optimizationBounds_ = Interval(lowerBound, upperBound);
   }
@@ -222,7 +226,7 @@ void GaussianProcessFitter::computeF()
 {
   // Nothing to do if the design matrix has already been computed
   if (F_.getNbRows() != 0) return;
-  LOGINFO("Compute the design matrix");
+  LOGDEBUG("Compute the design matrix");
   // No early exit based on the sample/basis size as F_ must be initialized with the correct dimensions
   // With a multivariate basis of size similar to output dimension, each ith-basis should be applied to elements
   // of corresponding marginal
@@ -296,8 +300,8 @@ void GaussianProcessFitter::run()
   //   discretization and factorization, and it computes beta_
   Scalar optimalLogLikelihood = maximizeReducedLogLikelihood();
 
-  LOGINFO("Store the estimates");
-  LOGINFO("Build the output meta-model");
+  LOGDEBUG("Store the estimates");
+  LOGDEBUG("Build the output meta-model");
   Collection<Function> marginalCollections(basis_.getSize());
   Collection<Function> marginalFunctions(outputDimension);
   Point beta_k(basis_.getSize());
@@ -325,26 +329,11 @@ void GaussianProcessFitter::run()
     metaModel = ConstantFunction(covarianceModel_.getInputDimension(), Point(covarianceModel_.getOutputDimension(), 0.0));
   }
 
-  // compute residual, relative error
-  const Point outputVariance(outputSample_.computeVariance());
-  const Sample mY(metaModel(inputSample_));
-  const Point squaredResiduals((outputSample_ - mY).computeRawMoment(2));
-
-  Point residuals(outputDimension);
-  Point relativeErrors(outputDimension);
-
-  const UnsignedInteger size = inputSample_.getSize();
-  for ( UnsignedInteger outputIndex = 0; outputIndex < outputDimension; ++ outputIndex )
-  {
-    residuals[outputIndex] = std::sqrt(squaredResiduals[outputIndex] / size);
-    relativeErrors[outputIndex] = squaredResiduals[outputIndex] / outputVariance[outputIndex];
-  }
-
   // return optimized covmodel with the original active parameters (see analyticalAmplitude_)
   CovarianceModel reducedCovarianceModelCopy(reducedCovarianceModel_);
   reducedCovarianceModelCopy.setActiveParameter(covarianceModel_.getActiveParameter());
 
-  result_ = GaussianProcessFitterResult(inputSample_, outputSample_, metaModel, F_, basis_, beta_, reducedCovarianceModelCopy, optimalLogLikelihood, method_, residuals, relativeErrors);
+  result_ = GaussianProcessFitterResult(inputSample_, outputSample_, metaModel, F_, basis_, beta_, reducedCovarianceModelCopy, optimalLogLikelihood, method_);
   result_.setRho(rho_);
 
   // The scaling is done there because it has to be done as soon as some optimization has been done, either numerically or through an analytical formula
@@ -376,7 +365,7 @@ void GaussianProcessFitter::run()
 Scalar GaussianProcessFitter::maximizeReducedLogLikelihood()
 {
   // initial guess
-  const Point initialParameters(reducedCovarianceModel_.getParameter());
+  Point initialParameters(reducedCovarianceModel_.getParameter());
   // We use the functional form of the log-likelihood computation to benefit from the cache mechanism
   Function reducedLogLikelihoodFunction(getReducedLogLikelihoodFunction());
   const Bool noNumericalOptimization = initialParameters.getSize() == 0 || !getOptimizeParameters();
@@ -385,15 +374,42 @@ Scalar GaussianProcessFitter::maximizeReducedLogLikelihood()
   {
     // We only need to compute the log-likelihood function at the initial parameters in order to get the Cholesky factor and the trend coefficients
     const Scalar initialReducedLogLikelihood = reducedLogLikelihoodFunction(initialParameters)[0];
-    LOGINFO("No covariance parameter to optimize");
-    LOGINFO(OSS() << "initial parameters=" << initialParameters << ", log-likelihood=" << initialReducedLogLikelihood);
+    LOGDEBUG("No covariance parameter to optimize");
+    LOGDEBUG(OSS() << "initial parameters=" << initialParameters << ", log-likelihood=" << initialReducedLogLikelihood);
     return initialReducedLogLikelihood;
   }
+  // Thus here we perform an optimization. First let us check the initial point is inside the
+  // optimization bounds search, otherwise define one arbitrary inside these bounds
+  if (!optimizationBounds_.contains(initialParameters))
+  {
+    // Define starting point for the optimization as the center of the bounds
+    // We should ensure somehow that the upper/lower bounds scale are nearly the same
+    initialParameters = (optimizationBounds_.getUpperBound() + optimizationBounds_.getLowerBound())/2;
+  }
+
+  // internal normalization into (0,1)^n
+  Interval bounds(optimizationBounds_);
+  const Bool normalization = ResourceMap::GetAsBool("GaussianProcessFitter-OptimizationNormalization");
+  const UnsignedInteger parameterDimension = initialParameters.getDimension();
+  Function uToX;
+  if (normalization)
+  {
+    Matrix linear(parameterDimension, parameterDimension);
+    for (UnsignedInteger i = 0; i < parameterDimension; ++ i)
+    {
+      linear(i, i) = (optimizationBounds_.getUpperBound()[i] - optimizationBounds_.getLowerBound()[i]);
+      initialParameters[i] = (initialParameters[i] - optimizationBounds_.getLowerBound()[i]) / linear(i, i);
+    }
+    uToX = LinearFunction(Point(parameterDimension), optimizationBounds_.getLowerBound(), linear);
+    reducedLogLikelihoodFunction = ComposedFunction(reducedLogLikelihoodFunction, uToX);
+    bounds = Interval(parameterDimension);
+  }
+
   // At this point we have an optimization problem to solve
   // Define the optimization problem
   OptimizationProblem problem(reducedLogLikelihoodFunction);
   problem.setMinimization(false);
-  problem.setBounds(optimizationBounds_);
+  problem.setBounds(bounds);
   solver_.setProblem(problem);
   try
   {
@@ -402,16 +418,38 @@ Scalar GaussianProcessFitter::maximizeReducedLogLikelihood()
   }
   catch (const NotDefinedException &) // setStartingPoint is not defined for the solver
   {
-    // Nothing to do if setStartingPoint is not defined
+    // Define starting point for the optimization as the center of the bounds if necessary
+    Sample initialPoints(solver_.getStartingSample());
+    const Point center(0.5 * (optimizationBounds_.getUpperBound() + optimizationBounds_.getLowerBound()));
+    for (UnsignedInteger i = 0; i < initialPoints.getSize(); ++ i)
+    {
+      if (!optimizationBounds_.contains(initialPoints[i]))
+        initialPoints[i] = center;
+    }
+    solver_.setStartingSample(initialPoints);
+
+    if (normalization)
+    {
+      Point linear(parameterDimension);
+      for (UnsignedInteger j = 0; j < parameterDimension; ++ j)
+        linear[j] = (optimizationBounds_.getUpperBound()[j] - optimizationBounds_.getLowerBound()[j]);
+      for (UnsignedInteger i = 0; i < initialPoints.getSize(); ++ i)
+        for (UnsignedInteger j = 0; j < parameterDimension; ++ j)
+          initialPoints(i, j) = (initialPoints(i, j) - optimizationBounds_.getLowerBound()[j]) / linear[j];
+      solver_.setStartingSample(initialPoints);
+    }
   }
-  LOGINFO(OSS(false) << "Solve problem=" << problem << " using solver=" << solver_);
+  LOGDEBUG(OSS(false) << "Solve problem=" << problem << " using solver=" << solver_);
   solver_.run();
   const OptimizationAlgorithm::Result result(solver_.getResult());
   const Point optimalLogLikelihoodPoint = result.getOptimalValue();
   if (!optimalLogLikelihoodPoint.getSize())
     throw InvalidArgumentException(HERE) << "optimization in GaussianProcessFitter did not yield feasible points";
   const Scalar optimalLogLikelihood = optimalLogLikelihoodPoint[0];
-  const Point optimalParameters(result.getOptimalPoint());
+  Point optimalParameters(result.getOptimalPoint());
+  if (normalization)
+    optimalParameters = uToX(optimalParameters);
+
   const UnsignedInteger evaluationNumber = result.getCallsNumber();
   // Check if the optimal value corresponds to the last computed value, in order to
   // see if the by-products (Cholesky factor etc) are correct
@@ -422,7 +460,7 @@ Scalar GaussianProcessFitter::maximizeReducedLogLikelihood()
   }
   // Final call to reducedLogLikelihoodFunction() in order to update the amplitude
   // No additional cost since the cache mechanism is activated
-  LOGINFO(OSS() << evaluationNumber << " evaluations, optimized parameters=" << optimalParameters << ", log-likelihood=" << optimalLogLikelihood);
+  LOGDEBUG(OSS() << evaluationNumber << " evaluations, optimized parameters=" << optimalParameters << ", log-likelihood=" << optimalLogLikelihood);
 
   return optimalLogLikelihood;
 }
@@ -471,7 +509,7 @@ Point GaussianProcessFitter::computeReducedLogLikelihood(const Point & parameter
   if (epsilon <= 0) lastReducedLogLikelihood_ = SpecFunc::LowestScalar;
   // For the general multidimensional case, we have to compute the general log-likelihood (ie including marginal variances)
   else lastReducedLogLikelihood_ = constant - 0.5 * (logDeterminant + epsilon);
-  LOGINFO(OSS(false) << "Point " << parameters << " -> reduced log-likelihood=" << lastReducedLogLikelihood_);
+  LOGDEBUG(OSS(false) << "Point " << parameters << " -> reduced log-likelihood=" << lastReducedLogLikelihood_);
   return Point(1, lastReducedLogLikelihood_);
 }
 
