@@ -2,7 +2,7 @@
 /**
  *  @brief EfficientGlobalOptimization or EGO algorithm
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -26,6 +26,9 @@
 #include "openturns/MultiStart.hxx"
 #include "openturns/JointDistribution.hxx"
 #include "openturns/Uniform.hxx"
+#include "openturns/GaussianProcessFitter.hxx"
+#include "openturns/GaussianProcessRegression.hxx"
+#include "openturns/GaussianProcessConditionalCovariance.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -47,8 +50,7 @@ EfficientGlobalOptimization::EfficientGlobalOptimization()
 
 /* Constructor with parameters */
 EfficientGlobalOptimization::EfficientGlobalOptimization(const OptimizationProblem & problem,
-    const KrigingResult & krigingResult,
-    const Function & noise)
+    const KrigingResult & krigingResult)
   : OptimizationAlgorithmImplementation(problem)
   , krigingResult_(krigingResult)
   , solver_(OptimizationAlgorithm::GetByName(ResourceMap::GetAsString("EfficientGlobalOptimization-DefaultOptimizationAlgorithm")))
@@ -59,60 +61,70 @@ EfficientGlobalOptimization::EfficientGlobalOptimization(const OptimizationProbl
   , aeiTradeoff_(ResourceMap::GetAsScalar("EfficientGlobalOptimization-DefaultAEITradeoff"))
 {
   checkProblem(problem);
-  if (krigingResult_.getMetaModel().getOutputDimension() != 1) throw InvalidArgumentException(HERE) << "Metamodel must be 1-d";
-  if (noise.getEvaluation().getImplementation()->isActualImplementation())
-  {
-    setMetamodelNoise(noise);
-    setNoiseModel(noise);
-  }
+  if (krigingResult_.getMetaModel().getOutputDimension() != 1) throw InvalidArgumentException(HERE) << "Kriging metamodel must be 1-d";
 }
 
+EfficientGlobalOptimization::EfficientGlobalOptimization(const OptimizationProblem & problem,
+    const GaussianProcessRegressionResult & gprResult)
+  : OptimizationAlgorithmImplementation(problem)
+  , gprResult_(gprResult)
+  , isGPR_(true)
+  , solver_(OptimizationAlgorithm::GetByName(ResourceMap::GetAsString("EfficientGlobalOptimization-DefaultOptimizationAlgorithm")))
+  , multiStartExperimentSize_(ResourceMap::GetAsUnsignedInteger("EfficientGlobalOptimization-DefaultMultiStartExperimentSize"))
+  , multiStartNumber_(ResourceMap::GetAsUnsignedInteger("EfficientGlobalOptimization-DefaultMultiStartNumber"))
+  , parameterEstimationPeriod_(ResourceMap::GetAsUnsignedInteger("EfficientGlobalOptimization-DefaultParameterEstimationPeriod"))
+  , correlationLengthFactor_(ResourceMap::GetAsScalar("EfficientGlobalOptimization-DefaultCorrelationLengthFactor"))
+  , aeiTradeoff_(ResourceMap::GetAsScalar("EfficientGlobalOptimization-DefaultAEITradeoff"))
+{
+  checkProblem(problem);
+  if (gprResult_.getMetaModel().getOutputDimension() != 1) throw InvalidArgumentException(HERE) << "GPR metamodel must be 1-d";
+}
 
 class ExpectedImprovementEvaluation : public EvaluationImplementation
 {
 public:
   ExpectedImprovementEvaluation (const Scalar optimalValue,
-                                 const KrigingResult & metaModelResult,
-                                 const Function & noiseModel,
+                                 const KrigingResult & krigingResult,
+                                 const GaussianProcessRegressionResult & gprResult,
+                                 const Bool isGPR,
                                  const Bool isMinimization)
     : EvaluationImplementation()
     , optimalValue_(optimalValue)
-    , metaModelResult_(metaModelResult)
-    , noiseModel_(noiseModel)
+    , krigingResult_(krigingResult)
+    , gprResult_(gprResult)
+    , gprCov_(gprResult)
+    , isGPR_(isGPR)
     , isMinimization_(isMinimization)
   {
   }
 
-  virtual ExpectedImprovementEvaluation * clone() const
+  ExpectedImprovementEvaluation * clone() const override
   {
     return new ExpectedImprovementEvaluation(*this);
   }
 
-  Point operator()(const Point & x) const
+  Point operator()(const Point & x) const override
   {
     return Point(1, computeAsScalar(x));
   }
 
   Scalar computeAsScalar(const Point & x) const
   {
-    const Scalar mx = metaModelResult_.getConditionalMean(x)[0];
+    const Scalar mx = isGPR_ ? gprCov_.getConditionalMean(x)[0] : krigingResult_.getConditionalMean(x)[0];
     const Scalar fmMk = isMinimization_ ? optimalValue_ - mx : mx - optimalValue_;
-    const Scalar sk2 = metaModelResult_.getConditionalMarginalVariance(x);
+    const Scalar sk2 = isGPR_ ? gprCov_.getConditionalMarginalVariance(x) : krigingResult_.getConditionalMarginalVariance(x);
     const Scalar sk = sqrt(sk2);
-    if (!SpecFunc::IsNormal(sk))
+    if (!std::isfinite(sk))
       return SpecFunc::LowestScalar;
     const Scalar ratio = fmMk / sk;
     Scalar ei = fmMk * DistFunc::pNormal(ratio) + sk * DistFunc::dNormal(ratio);
-    if (noiseModel_.getOutputDimension() == 1) // if provided
-    {
-      const Scalar noiseVariance = noiseModel_(x)[0];
-      if (!(noiseVariance >= 0.0)) throw InvalidArgumentException(HERE) << "Noise model must be positive";
-      ei *= (1.0 - sqrt(noiseVariance) / sqrt(noiseVariance + sk2));
-    }
+    const Scalar nuggetFactor = isGPR_ ? gprResult_.getCovarianceModel().getNuggetFactor() : krigingResult_.getCovarianceModel().getNuggetFactor();
+    if (nuggetFactor > ResourceMap::GetAsScalar("CovarianceModel-DefaultNuggetFactor"))
+      ei *= (1.0 - sqrt(nuggetFactor) / sqrt(nuggetFactor + sk2));
     return ei;
   }
 
-  Sample operator()(const Sample & theta) const
+  Sample operator()(const Sample & theta) const override
   {
     const UnsignedInteger size = theta.getSize();
     // avoid creating size points
@@ -127,29 +139,25 @@ public:
     return outS;
   }
 
-  UnsignedInteger getInputDimension() const
+  UnsignedInteger getInputDimension() const override
   {
-    return metaModelResult_.getMetaModel().getInputDimension();
+    if (isGPR_)
+      return gprResult_.getMetaModel().getInputDimension();
+    else
+      return krigingResult_.getMetaModel().getInputDimension();
   }
 
-  UnsignedInteger getOutputDimension() const
+  UnsignedInteger getOutputDimension() const override
   {
     return 1;
   }
 
-  Description getInputDescription() const
-  {
-    return metaModelResult_.getMetaModel().getInputDescription();
-  }
-
-  Description getOutputDescription() const
-  {
-    return metaModelResult_.getMetaModel().getOutputDescription();
-  }
-
 protected:
   Scalar optimalValue_;
-  KrigingResult metaModelResult_;
+  KrigingResult krigingResult_;
+  GaussianProcessRegressionResult gprResult_;
+  GaussianProcessConditionalCovariance gprCov_;
+  Bool isGPR_ = false;
   Function noiseModel_;
 
   // whether the global problem is a miminization (the improvement criterion is always maximized)
@@ -157,27 +165,28 @@ protected:
 };
 
 
-
-
 void EfficientGlobalOptimization::run()
 {
   const OptimizationProblem problem(getProblem());
   const UnsignedInteger dimension = problem.getDimension();
   const Function model(problem.getObjective());
-  Sample inputSample(krigingResult_.getInputSample());
-  Sample outputSample(krigingResult_.getOutputSample());
-  UnsignedInteger size = inputSample.getSize();
-  Point noise(size);
-  const Bool hasNoise = metamodelNoise_.getEvaluation().getImplementation()->isActualImplementation();
-  if (hasNoise)
+  Sample inputSample;
+  Sample outputSample;
+  if (isGPR_)
   {
-    Sample noiseSample(metamodelNoise_(inputSample));
-    for (UnsignedInteger i = 0; i < size; ++ i)
-    {
-      noise[i] = noiseSample(i, 0);
-      if (!(noise[i] >= 0.0)) throw InvalidArgumentException(HERE) << "Noise model must be positive";
-    }
+    inputSample = gprResult_.getInputSample();
+    outputSample = gprResult_.getOutputSample();
   }
+  else
+  {
+    inputSample = krigingResult_.getInputSample();
+    outputSample = krigingResult_.getOutputSample();
+  }
+  UnsignedInteger size = inputSample.getSize();
+
+
+  const Scalar nuggetFactor = isGPR_ ? gprResult_.getCovarianceModel().getNuggetFactor() : krigingResult_.getCovarianceModel().getNuggetFactor();
+  const Bool hasNoise = nuggetFactor > ResourceMap::GetAsScalar("CovarianceModel-DefaultNuggetFactor");
   UnsignedInteger evaluationNumber = 0;
   Bool exitLoop = false;
 
@@ -212,7 +221,9 @@ void EfficientGlobalOptimization::run()
 
   UnsignedInteger iterationNumber = 0;
   // use the provided kriging result at first iteration
-  KrigingResult metaModelResult(krigingResult_);
+
+  GaussianProcessRegressionResult gprResult(gprResult_);
+  KrigingResult krigingResult(krigingResult_);
 
   while ((!exitLoop) && (evaluationNumber < getMaximumCallsNumber()))
   {
@@ -222,11 +233,12 @@ void EfficientGlobalOptimization::run()
       // with noisy objective we don't have access to the real current optimal value
       // so consider a quantile of the kriging prediction: argmin_xi mk(xi) + c * sk(xi)
       optimalValueSubstitute = problem.isMinimization() ? SpecFunc::Infinity : SpecFunc::LowestScalar;
-      const Sample mx(metaModelResult.getConditionalMean(inputSample));
+      GaussianProcessConditionalCovariance gpcCov(gprResult_);
+      const Sample mx(isGPR_ ? gpcCov.getConditionalMean(inputSample) : krigingResult.getConditionalMean(inputSample));
       for (UnsignedInteger i = 0; i < size; ++ i)
       {
         const Point x(inputSample[i]);
-        const Scalar sk2 = metaModelResult.getConditionalMarginalVariance(x);
+        const Scalar sk2 = isGPR_ ? gpcCov.getConditionalMarginalVariance(x) : krigingResult.getConditionalMarginalVariance(x);
         const Scalar u = mx(i, 0) + aeiTradeoff_ * sqrt(sk2);
         if ((problem.isMinimization() && (u < optimalValueSubstitute))
             || (!problem.isMinimization() && (u > optimalValueSubstitute)))
@@ -236,7 +248,7 @@ void EfficientGlobalOptimization::run()
       }
     }
 
-    Function improvementObjective(new ExpectedImprovementEvaluation(optimalValueSubstitute, metaModelResult, noiseModel_, problem.isMinimization()));
+    Function improvementObjective(new ExpectedImprovementEvaluation(optimalValueSubstitute, krigingResult, gprResult, isGPR_, problem.isMinimization()));
 
     // use multi-start to optimize the improvement criterion when using the default solver
     OptimizationAlgorithm solver(solver_);
@@ -321,7 +333,7 @@ void EfficientGlobalOptimization::run()
 
       // when a correlation length becomes smaller than the minimal distance between design point for a single component
       // that means the model tends to be noisy, and the original EGO formulation is not adapted anymore
-      const Point scale(metaModelResult.getCovarianceModel().getScale());
+      const Point scale(isGPR_ ? gprResult.getCovarianceModel().getScale() : krigingResult.getCovarianceModel().getScale());
       for (UnsignedInteger j = 0; j < dimension; ++ j)
       {
         const Bool minDistStop = scale[j] < minimumDistance[j] / correlationLengthFactor_;
@@ -334,14 +346,6 @@ void EfficientGlobalOptimization::run()
     inputSample.add(newPoint);
     outputSample.add(newValue);
     ++ size;
-
-    if (hasNoise)
-    {
-      const Point newNoise(metamodelNoise_(newPoint));
-      if (!(newNoise[0] >= 0.0)) throw InvalidArgumentException(HERE) << "Noise model must be positive";
-      noise.add(newNoise[0]);
-    }
-
     ++ iterationNumber;
 
     // callbacks
@@ -361,18 +365,38 @@ void EfficientGlobalOptimization::run()
 
     if (evaluationNumber > 0)
     {
-      KrigingAlgorithm algo(inputSample, outputSample, metaModelResult.getCovarianceModel(), metaModelResult.getBasis());
-      LOGINFO(OSS() << "Rebuilding kriging ...");
-      algo.setOptimizeParameters((parameterEstimationPeriod_ > 0) && ((evaluationNumber % parameterEstimationPeriod_) == 0));
-      if (hasNoise)
-        algo.setNoise(noise);
-      algo.run();
-      LOGINFO(OSS() << "Rebuilding kriging - done");
-      metaModelResult = algo.getResult();
+      if (isGPR_)
+      {
+        GaussianProcessRegression algo;
+        if ((parameterEstimationPeriod_ > 0) && ((evaluationNumber % parameterEstimationPeriod_) == 0))
+        {
+          GaussianProcessFitter fitter(inputSample, outputSample, gprResult.getCovarianceModel(), gprResult.getBasis());
+          fitter.run();
+          algo = GaussianProcessRegression(fitter.getResult());
+        }
+        else
+        {
+          algo = GaussianProcessRegression(inputSample, outputSample, gprResult.getCovarianceModel(), gprResult.getBasis()[0]);
+        }
+        algo.run();
+        gprResult = algo.getResult();
+      }
+      else
+      {
+        KrigingAlgorithm algo(inputSample, outputSample, krigingResult.getCovarianceModel(), krigingResult.getBasis());
+        LOGDEBUG(OSS() << "Rebuilding kriging ...");
+        algo.setOptimizeParameters((parameterEstimationPeriod_ > 0) && ((evaluationNumber % parameterEstimationPeriod_) == 0));
+        algo.run();
+        LOGDEBUG(OSS() << "Rebuilding kriging - done");
+        krigingResult = algo.getResult();
+      }
     }
   } // while
 
-  krigingResult_ = metaModelResult; // update krigingResult_ to take new points into account
+  // update result to take new points into account
+  krigingResult_ = krigingResult;
+  gprResult_ = gprResult;
+
   result.setIterationNumber(iterationNumber);
   setResult(result);
 }
@@ -477,54 +501,30 @@ Scalar EfficientGlobalOptimization::getAEITradeoff() const
   return aeiTradeoff_;
 }
 
-/* metamodel noise accessor */
-void EfficientGlobalOptimization::setMetamodelNoise(const Function & noiseModel)
+/* GP result accessor (especially useful after run() has been called) */
+GaussianProcessRegressionResult EfficientGlobalOptimization::getGaussianProcessRegressionResult() const
 {
-  const UnsignedInteger dimension = getProblem().getDimension();
-  if (noiseModel.getInputDimension() != dimension) throw InvalidArgumentException(HERE) << "Noise model must be of dimension " << dimension;
-  if (noiseModel.getOutputDimension() != 1) throw InvalidArgumentException(HERE) << "Noise model must be 1-d";
-  metamodelNoise_ = noiseModel;
+  return gprResult_;
 }
 
-Function EfficientGlobalOptimization::getMetamodelNoise() const
-{
-  return metamodelNoise_;
-}
-
-/* optimization noise accessor */
-void EfficientGlobalOptimization::setNoiseModel(const Function & noiseModel)
-{
-  const UnsignedInteger dimension = getProblem().getDimension();
-  if (noiseModel.getInputDimension() != dimension) throw InvalidArgumentException(HERE) << "Noise model must be of dimension " << dimension;
-  if (noiseModel.getOutputDimension() != 1) throw InvalidArgumentException(HERE) << "Noise model must be 1-d";
-  noiseModel_ = noiseModel;
-}
-
-Function EfficientGlobalOptimization::getNoiseModel() const
-{
-  return noiseModel_;
-}
-
-
-/* Kriging result accessor (especially useful after run() has been called) */
 KrigingResult EfficientGlobalOptimization::getKrigingResult() const
 {
   return krigingResult_;
 }
 
-
 /* Method save() stores the object through the StorageManager */
 void EfficientGlobalOptimization::save(Advocate & adv) const
 {
   OptimizationAlgorithmImplementation::save(adv);
   adv.saveAttribute("krigingResult_", krigingResult_);
+  adv.saveAttribute("gprResult_", gprResult_);
+  adv.saveAttribute("isGPR_", isGPR_);
   adv.saveAttribute("solver_", solver_);
   adv.saveAttribute("multiStartExperimentSize_", multiStartExperimentSize_);
   adv.saveAttribute("multiStartNumber_", multiStartNumber_);
   adv.saveAttribute("parameterEstimationPeriod_", parameterEstimationPeriod_);
   adv.saveAttribute("correlationLengthFactor_", correlationLengthFactor_);
   adv.saveAttribute("aeiTradeoff_", aeiTradeoff_);
-  adv.saveAttribute("noiseModel_", noiseModel_);
 }
 
 /* Method load() reloads the object from the StorageManager */
@@ -532,13 +532,17 @@ void EfficientGlobalOptimization::load(Advocate & adv)
 {
   OptimizationAlgorithmImplementation::load(adv);
   adv.loadAttribute("krigingResult_", krigingResult_);
+  if (adv.hasAttribute("gprResult_"))
+  {
+    adv.loadAttribute("gprResult_", gprResult_);
+    adv.loadAttribute("isGPR_", isGPR_);
+  }
   adv.loadAttribute("solver_", solver_);
   adv.loadAttribute("multiStartExperimentSize_", multiStartExperimentSize_);
   adv.loadAttribute("multiStartNumber_", multiStartNumber_);
   adv.loadAttribute("parameterEstimationPeriod_", parameterEstimationPeriod_);
   adv.loadAttribute("correlationLengthFactor_", correlationLengthFactor_);
   adv.loadAttribute("aeiTradeoff_", aeiTradeoff_);
-  adv.loadAttribute("noiseModel_", noiseModel_);
 }
 
 END_NAMESPACE_OPENTURNS
