@@ -2,7 +2,7 @@
 /**
  *  @brief This is the orthogonal polynomial basis
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -304,4 +304,26 @@ Sample OrthogonalProductPolynomialFactory::getNodesAndWeights(const Indices & de
   return nodes;
 }
 
+/* Get the function factory corresponding to the input marginal indices */
+OrthogonalBasis OrthogonalProductPolynomialFactory::getMarginal(const Indices & indices) const
+{
+  const UnsignedInteger size = coll_.getSize();
+  if (!indices.check(size))
+    throw InvalidArgumentException(HERE) << "The indices of a marginal sample must be in the range [0, size-1] and must be different";
+  // Create list of factories corresponding to input marginal indices
+  OrthogonalProductPolynomialFactory::PolynomialFamilyCollection polynomialMarginalCollection;
+  for (UnsignedInteger index = 0; index < size; ++ index)
+    if (indices.contains(index))
+      polynomialMarginalCollection.add(coll_[index]);
+  // Create function
+  const EnumerateFunction marginalEnumerateFunction(phi_.getMarginal(indices));
+  const OrthogonalProductPolynomialFactory marginalFactory(polynomialMarginalCollection, marginalEnumerateFunction);
+  return marginalFactory;
+}
+
+Bool OrthogonalProductPolynomialFactory::isTensorProduct() const
+{
+  return true;
+}
+
 END_NAMESPACE_OPENTURNS
