@@ -2,7 +2,7 @@
 /**
  *  @brief ADS simulation algorithm
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -64,7 +64,7 @@ AdaptiveDirectionalStratification * AdaptiveDirectionalStratification::clone() c
 void AdaptiveDirectionalStratification::run()
 {
   // First, reset the convergence history
-  convergenceStrategy_.setDimension(2);
+  convergenceStrategy_.setDimension(3);
   result_ = ProbabilitySimulationResult();
   result_.setEvent(getEvent());
   result_.setBlockSize(1);
@@ -161,7 +161,7 @@ void AdaptiveDirectionalStratification::run()
         }
 
       } // if pf > 0
-      Log::Debug(OSS() << "AdaptiveDirectionalStratification::run n=" << n << " i=" << i << " ni=" << ni << " pf=" << pf << " sigma=" << sigma[i]);
+      LOGDEBUG(OSS() << "AdaptiveDirectionalStratification::run n=" << n << " i=" << i << " ni=" << ni << " pf=" << pf << " sigma=" << sigma[i]);
 
     } // for i
 
@@ -187,7 +187,7 @@ void AdaptiveDirectionalStratification::run()
           if ((1 << k) & i)
             T_[k] += std::abs(T0(k, i) - T1(k, i));
 
-        Log::Debug(OSS() << "AdaptiveDirectionalStratification::run T[" << k << "]=" << T_[k]);
+        LOGDEBUG(OSS() << "AdaptiveDirectionalStratification::run T[" << k << "]=" << T_[k]);
       }
 
       // sort variables according to T statistic
@@ -202,7 +202,7 @@ void AdaptiveDirectionalStratification::run()
             order[j + 1] = swap;
           }
       for (UnsignedInteger k = 0; k < dimension; ++ k)
-        Log::Debug(OSS() << "AdaptiveDirectionalStratification::run #" << k << " T[" << order[k] << "]=" << T_[order[k]]);
+        LOGDEBUG(OSS() << "AdaptiveDirectionalStratification::run #" << k << " T[" << order[k] << "]=" << T_[order[k]]);
 
       // retrieve the p' variables contributing the most
       strataIndices = Indices();
