@@ -2,7 +2,7 @@
 /**
  *  @brief class for NAISResult
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -28,7 +28,7 @@ BEGIN_NAMESPACE_OPENTURNS
  */
 
 
-CLASSNAMEINIT(NAISResult);
+CLASSNAMEINIT(NAISResult)
 
 static const Factory<NAISResult> Factory_NAISResult;
 
