@@ -2,7 +2,7 @@
 /**
  *  @brief Class for the Nataf transformation evaluation for elliptical
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -24,8 +24,6 @@
 #include "openturns/ResourceMap.hxx"
 #include "openturns/SpecFunc.hxx"
 #include "openturns/SymbolicFunction.hxx"
-#include "openturns/JointDistribution.hxx"
-#include "openturns/Os.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -74,19 +72,30 @@ void MarginalTransformationEvaluation::initialize(const Bool simplify)
     if (inputDistributionCollection_[i].getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: a MarginalTransformationEvaluation cannot be built using distributions with dimension > 1.";
     if (outputDistributionCollection_[i].getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: a MarginalTransformationEvaluation cannot be built using distributions with dimension > 1.";
   }
+
   // Second, build the description of the transformation
-  Description description(Description::BuildDefault(size, "x"));
-  description.add(Description::BuildDefault(size, "y"));
+  Description description;
+  for (UnsignedInteger i = 0; i < size; ++i)
+    description.add(inputDistributionCollection_[i].getDescription()[0]);
+  for (UnsignedInteger i = 0; i < size; ++i)
+    description.add(outputDistributionCollection_[i].getDescription()[0]);
+  const auto iter = std::unique(description.begin(), description.end());
+  if (iter < description.end())
+  {
+    description = Description::BuildDefault(size, "x");
+    description.add(Description::BuildDefault(size, "y"));
+  }
   setDescription(description);
+
   if (simplify)
   {
+    const Description xNames(Description::BuildDefault(size, "x"));
     // Third, look for possible simplifications
     for (UnsignedInteger i = 0; i < size; ++i)
     {
       const Distribution inputDistribution(inputDistributionCollection_[i]);
       const Distribution outputDistribution(outputDistributionCollection_[i]);
-      const String xName(getInputDescription()[i]);
-      const String yName(getOutputDescription()[i]);
+      const String xName(xNames[i]);
       const String inputClass(inputDistribution.getImplementation()->getClassName());
       const String outputClass(outputDistribution.getImplementation()->getClassName());
       const Point inputParameters(inputDistribution.getParametersCollection()[0]);
@@ -110,7 +119,7 @@ void MarginalTransformationEvaluation::initialize(const Bool simplify)
           const Scalar q75Output = outputDistribution.computeScalarQuantile(0.75);
           const Scalar a = 0.5 * (q75Output + q25Output);
           // Here, b > 0 by construction
-          const Scalar b = (q75Output - q25Output) / (q75Input - q25Input);
+          const Scalar b = (q75Input == q25Input ? 1.0 : (q75Output - q25Output) / (q75Input - q25Input));
           const Scalar c = -0.5 * (q75Input + q25Input);
           OSS oss;
           oss.setPrecision(20);
