@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level view of an Smolyak experiment
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -264,7 +264,17 @@ Sample SmolyakExperiment::generateWithWeights(Point & weights) const
   {
     WeightedExperimentCollection collection(collection_);
     for (UnsignedInteger j = 0; j < dimension; ++ j)
-      collection[j].setSize(combinationIndicesCollection(i, j));
+    {
+      try
+      {
+        collection[j].setLevels(Indices{combinationIndicesCollection(i, j)});
+      }
+      catch (const NotYetImplementedException &)
+      {
+        // does not support nesting level
+        collection[j].setSize(combinationIndicesCollection(i, j));
+      }
+    }
     TensorProductExperiment elementaryExperiment(collection);
     Point elementaryWeights(0);
     const Sample elementaryNodes(elementaryExperiment.generateWithWeights(elementaryWeights));
