@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level class for all space filling criteria implementations
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -82,7 +82,7 @@ Sample SpaceFillingImplementation::normalize(const Sample & sample) const
   }
   if (!toNormalize) return sample;
 
-  LOGWARN(OSS() << "Sample must be normalized");
+  LOGDEBUG(OSS() << "Sample must be normalized");
   const Point delta(maxPoint - minPoint);
   Sample result(sample - minPoint);
   return result / delta;
