@@ -2,7 +2,7 @@
 /**
  *  @brief Default GaussianNonLinearCalibration
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -23,16 +23,11 @@
 #include "openturns/NonLinearLeastSquaresCalibration.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/Normal.hxx"
-#include "openturns/NormalFactory.hxx"
 #include "openturns/KernelSmoothing.hxx"
 #include "openturns/CenteredFiniteDifferenceHessian.hxx"
 #include "openturns/BootstrapExperiment.hxx"
-#include "openturns/LowDiscrepancyExperiment.hxx"
-#include "openturns/SobolSequence.hxx"
 #include "openturns/OptimizationAlgorithm.hxx"
 #include "openturns/LeastSquaresProblem.hxx"
-#include "openturns/MultiStart.hxx"
-#include "openturns/TNC.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -107,12 +102,12 @@ public:
     if (globalErrorInverseCholesky_ && (errorInverseCholesky.getDimension() != model.getOutputDimension() * outputObservations.getSize())) throw InvalidArgumentException(HERE) << "Error: expected error inverse Cholesky of dimension=" << model.getOutputDimension() << ", got dimension=" << errorInverseCholesky.getDimension();
   }
 
-  CalibrationModelEvaluation * clone() const
+  CalibrationModelEvaluation * clone() const override
   {
     return new CalibrationModelEvaluation(*this);
   }
 
-  Point operator() (const Point & point) const
+  Point operator() (const Point & point) const override
   {
     Function localModel(model_);
     localModel.setParameter(point);
@@ -124,22 +119,22 @@ public:
     return result;
   }
 
-  UnsignedInteger getInputDimension() const
+  UnsignedInteger getInputDimension() const override
   {
     return model_.getParameterDimension();
   }
 
-  UnsignedInteger getOutputDimension() const
+  UnsignedInteger getOutputDimension() const override
   {
     return model_.getOutputDimension() * inputObservations_.getSize() + getInputDimension();
   }
 
-  Description getInputDescription() const
+  Description getInputDescription() const override
   {
     return model_.getParameterDescription();
   }
 
-  Description getOutputDescription() const
+  Description getOutputDescription() const override
   {
     const Description atomicOutputDescription(model_.getOutputDescription());
     Description outputDescription(0);
@@ -150,21 +145,21 @@ public:
     return outputDescription;
   }
 
-  Description getDescription() const
+  Description getDescription() const override
   {
     Description description(getInputDescription());
     description.add(getOutputDescription());
     return description;
   }
 
-  String __repr__() const
+  String __repr__() const override
   {
     OSS oss;
     oss << "CalibrationModelEvaluation(" << model_.__str__() << ", " << inputObservations_ << ")";
     return oss;
   }
 
-  String __str__(const String & ) const
+  String __str__(const String & ) const override
   {
     OSS oss;
     oss << "CalibrationModelEvaluation(" << model_.__str__() << ", " << inputObservations_ << ")";
@@ -226,12 +221,12 @@ public:
     // Nothing to do
   }
 
-  CalibrationModelGradient * clone() const
+  CalibrationModelGradient * clone() const override
   {
     return new CalibrationModelGradient(*this);
   }
 
-  Matrix gradient(const Point & point) const
+  Matrix gradient(const Point & point) const override
   {
     const UnsignedInteger parameterDimension = point.getDimension();
     const UnsignedInteger outputDimension = evaluation_.getModel().getOutputDimension();
@@ -275,39 +270,24 @@ public:
     return gradientObservations;
   }
 
-  UnsignedInteger getInputDimension() const
+  UnsignedInteger getInputDimension() const override
   {
     return evaluation_.getInputDimension();
   }
 
-  UnsignedInteger getOutputDimension() const
+  UnsignedInteger getOutputDimension() const override
   {
     return evaluation_.getOutputDimension();
   }
 
-  Description getInputDescription() const
-  {
-    return evaluation_.getInputDescription();
-  }
-
-  Description getOutputDescription() const
-  {
-    return evaluation_.getOutputDescription();
-  }
-
-  Description getDescription() const
-  {
-    return evaluation_.getDescription();
-  }
-
-  String __repr__() const
+  String __repr__() const override
   {
     OSS oss;
     oss << "CalibrationModelGradient(" << evaluation_ << ")";
     return oss;
   }
 
-  String __str__(const String & ) const
+  String __str__(const String & ) const override
   {
     OSS oss;
     oss << "CalibrationModelGradient(" << evaluation_ << ")";
@@ -339,8 +319,8 @@ void GaussianNonLinearCalibration::run()
     error.setMu(residuals);
   else
   {
-    SampleImplementation residualsAsSample(outputObservations_.getSize(), outputObservations_.getDimension());
-    residualsAsSample.setData(residuals);
+    Sample residualsAsSample(outputObservations_.getSize(), outputObservations_.getDimension());
+    residualsAsSample.getImplementation()->setData(residuals);
     error.setMu(residualsAsSample.computeMean());
   }
   // Compute the posterior distribution
@@ -365,9 +345,36 @@ void GaussianNonLinearCalibration::run()
   }
   else
   {
-    GaussianLinearCalibration algo(model_, inputObservations_, outputObservations_, thetaStar, getParameterPrior().getCovariance(), error.getCovariance());
-    algo.run();
-    parameterPosterior = algo.getResult().getParameterPosterior();
+    // Compute the linearization
+    Function parametrizedModel(model_);
+    parametrizedModel.setParameter(thetaStar);
+    // Flatten everything related to the model evaluations over the input observations
+    const UnsignedInteger parameterDimension = getParameterPrior().getDimension();
+    const UnsignedInteger outputDimension = getOutputObservations().getDimension();
+    const UnsignedInteger size = getOutputObservations().getSize();
+    Matrix gradientObservations = MatrixImplementation(parameterDimension, size * outputDimension);
+    UnsignedInteger shift = 0;
+    UnsignedInteger skip = parameterDimension * outputDimension;
+    for (UnsignedInteger i = 0; i < size; ++i)
+    {
+      const Matrix parameterGradient(parametrizedModel.parameterGradient(getInputObservations()[i]));
+      std::copy(parameterGradient.getImplementation()->begin(), parameterGradient.getImplementation()->end(), gradientObservations.getImplementation()->begin() + shift);
+      shift += skip;
+    }
+    gradientObservations = gradientObservations.transpose();
+
+    TriangularMatrix dummy;
+    const Matrix Abar(GaussianLinearCalibration::ComputeDesignMatrix(parameterDimension, outputDimension, size, getParameterPrior(), gradientObservations,
+                      globalErrorCovariance_, errorCovariance_, dummy));
+
+    // Compute the inverse Gram of the design matrix
+    const String methodName(ResourceMap::GetAsString("GaussianLinearCalibration-Method"));
+    LeastSquaresMethod method(LeastSquaresMethod::Build(methodName, Abar));
+    // Call solve only to insure that the decomposition (QR, Cholesky, SVD...) are up to date.
+    (void) method.solve(Point(Abar.getNbRows()));
+    const CovarianceMatrix covarianceThetaStar(method.getGramInverse().getImplementation());
+    // Create the result object
+    parameterPosterior = Normal(thetaStar, covarianceThetaStar);
   }
   parameterPosterior.setDescription(parameterPrior_.getDescription());
   result_ = CalibrationResult(parameterPrior_, parameterPosterior, thetaStar, error, inputObservations_, outputObservations_, residualFunction, true);
