@@ -2,7 +2,7 @@
 /**
  *  @brief The CompositeDistribution distribution
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -29,7 +29,7 @@
 #include "openturns/MethodBoundEvaluation.hxx"
 #include "openturns/Brent.hxx"
 #include "openturns/SobolSequence.hxx"
-#include "openturns/SymbolicFunction.hxx"
+#include "openturns/IdentityFunction.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -40,7 +40,7 @@ static const Factory<CompositeDistribution> Factory_CompositeDistribution;
 /* Default constructor */
 CompositeDistribution::CompositeDistribution()
   : DistributionImplementation()
-  , function_(SymbolicFunction("x", "x"))
+  , function_(IdentityFunction(1))
   , antecedent_(Uniform(0.0, 1.0))
   , bounds_(0)
   , values_(0)
@@ -48,7 +48,6 @@ CompositeDistribution::CompositeDistribution()
   , increasing_(0)
   , solver_(Brent(ResourceMap::GetAsScalar("CompositeDistribution-SolverEpsilon"), ResourceMap::GetAsScalar("CompositeDistribution-SolverEpsilon"), ResourceMap::GetAsScalar("CompositeDistribution-SolverEpsilon")))
 {
-  // We don't know if the function is thread-safe and it could be called in parallel in computePDF()
   setParallel(false);
   setName("CompositeDistribution");
   setDimension(1);
@@ -68,8 +67,6 @@ CompositeDistribution::CompositeDistribution(const Function & function,
   , increasing_(0)
   , solver_(Brent(ResourceMap::GetAsScalar("CompositeDistribution-SolverEpsilon") * (antecedent.getRange().getUpperBound()[0] - antecedent.getRange().getLowerBound()[0]), ResourceMap::GetAsScalar("CompositeDistribution-SolverEpsilon"), ResourceMap::GetAsScalar("CompositeDistribution-SolverEpsilon")))
 {
-  // We don't know if the function is thread-safe and it could be called in parallel in computePDF()
-  setParallel(false);
   setName("CompositeDistribution");
   // This method check everything and call the update() method.
   setFunctionAndAntecedent(function, antecedent);
@@ -129,6 +126,7 @@ void CompositeDistribution::setFunctionAndAntecedent(const Function & function,
   antecedent_ = antecedent;
   isAlreadyComputedMean_ = false;
   isAlreadyComputedCovariance_ = false;
+  setParallel(function.getImplementation()->isParallel() && antecedent.getImplementation()->isParallel());
   update();
 }
 
@@ -181,7 +179,7 @@ void CompositeDistribution::update()
   {
     throw NotDefinedException(HERE) << "Error: cannot evaluate the function at x=" << xMin;
   }
-  if (!SpecFunc::IsNormal(values_[0])) throw NotDefinedException(HERE) << "Error: cannot evaluate the function at x=" << xMin;
+  if (!std::isfinite(values_[0])) throw NotDefinedException(HERE) << "Error: cannot evaluate the function at x=" << xMin;
   probabilities_ = Point(1, antecedent_.computeCDF(xMin));
   increasing_ = Indices(0);
   Scalar fMin = values_[0];
@@ -198,7 +196,7 @@ void CompositeDistribution::update()
   {
     throw NotDefinedException(HERE) << "Error: cannot evaluate the derivative at x=" << a;
   }
-  if (!SpecFunc::IsNormal(fpA)) throw NotDefinedException(HERE) << "Error: cannot evaluate the derivative at x=" << a;
+  if (!std::isfinite(fpA)) throw NotDefinedException(HERE) << "Error: cannot evaluate the derivative at x=" << a;
   Scalar b = a;
   Scalar fpB = fpA;
   for (UnsignedInteger i = 0; i < n; ++i)
@@ -214,7 +212,7 @@ void CompositeDistribution::update()
     {
       throw NotDefinedException(HERE) << "Error: cannot evaluate the derivative at x=" << b;
     }
-    if (!SpecFunc::IsNormal(fpB)) throw NotDefinedException(HERE) << "Error: cannot evaluate the derivative at x=" << b;
+    if (!std::isfinite(fpB)) throw NotDefinedException(HERE) << "Error: cannot evaluate the derivative at x=" << b;
     try
     {
       const Scalar root = solver_.solve(derivative, 0.0, a, b, fpA, fpB);
@@ -228,7 +226,7 @@ void CompositeDistribution::update()
       {
         throw NotDefinedException(HERE) << "Error: cannot evaluate the function at x=" << root;
       }
-      if (!SpecFunc::IsNormal(root)) throw NotDefinedException(HERE) << "Error: cannot evaluate the derivative at x=" << root;
+      if (!std::isfinite(root)) throw NotDefinedException(HERE) << "Error: cannot evaluate the derivative at x=" << root;
       increasing_.add(value > values_[values_.getSize() - 1]);
       values_.add(value);
       probabilities_.add(antecedent_.computeCDF(root));
@@ -250,7 +248,7 @@ void CompositeDistribution::update()
   {
     throw NotDefinedException(HERE) << "Error: cannot evaluate the function at x=" << xMax;
   }
-  if (!SpecFunc::IsNormal(value)) throw NotDefinedException(HERE) << "Error: cannot evaluate the function at x=" << xMax;
+  if (!std::isfinite(value)) throw NotDefinedException(HERE) << "Error: cannot evaluate the function at x=" << xMax;
   increasing_.add(value > values_[values_.getSize() - 1]);
   values_.add(value);
   probabilities_.add(Point(1, antecedent_.computeCDF(xMax)));
@@ -370,7 +368,7 @@ Scalar CompositeDistribution::computePDF(const Point & point) const
         const Matrix gradient(function_.gradient(fInvX));
         if (!(gradient.getNbRows() == 1 && gradient.getNbColumns() == 1)) throw InternalException(HERE) << "Error: the given function has no actual gradient. Consider using finite differences.";
         const Scalar denominator = std::abs(function_.gradient(fInvX)(0, 0));
-        if (SpecFunc::IsNormal(denominator)) pdf += numerator / denominator;
+        if (std::isfinite(denominator)) pdf += numerator / denominator;
         LOGDEBUG(OSS() << "i=" << i << ", a=" << a << ", fA=" << fA << ", x=" << x << ", b=" << b << ", fB=" << fB << ", fInvX=" << fInvX << ", numerator=" << numerator << ", denominator=" << denominator << ", pdf=" << pdf);
       }
     }
