@@ -20,7 +20,6 @@
  */
 #include <cmath>
 #include "openturns/Dirac.hxx"
-#include "openturns/SpecFunc.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/Exception.hxx"
 #include "openturns/Distribution.hxx"
@@ -323,7 +322,7 @@ void Dirac::setPoint(const Point & point)
   if (point.getDimension() != dimension)
     throw InvalidArgumentException(HERE) << "Expected a point of dimension " << dimension;
   for (UnsignedInteger i = 0; i < dimension; ++ i)
-    if (!SpecFunc::IsNormal(point[i])) throw InvalidArgumentException(HERE) << "Cannot build a Dirac from nan/inf values";
+    if (!std::isfinite(point[i])) throw InvalidArgumentException(HERE) << "Cannot build a Dirac from nan/inf values";
   point_ = point;
   isAlreadyComputedMean_ = false;
   isAlreadyComputedCovariance_ = false;
