@@ -2,7 +2,7 @@
 /**
  *  @brief The Dirichlet distribution
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -214,8 +214,15 @@ Scalar Dirichlet::computeCDF(const Point & point) const
     for (UnsignedInteger i = 0; i < dimension; ++i) logFactor += theta_[i] * std::log(point[i]) - std::log(theta_[i]);
     // Initialize the integration data
     initializeIntegration();
+    const UnsignedInteger maxUInt = std::numeric_limits<UnsignedInteger>::max();
     UnsignedInteger size = 1;
-    for (UnsignedInteger i = 0; i < dimension; ++i) size *= integrationNodes_[i].getSize();
+    for (UnsignedInteger i = 0; i < dimension; ++i)
+    {
+      const UnsignedInteger nI = integrationNodes_[i].getSize();
+      if (size > maxUInt / nI)
+        throw InvalidArgumentException(HERE) << "Dirichlet integration nodes size would overflow integer limit " << maxUInt;
+      size *= nI;
+    }
     // Loop over the integration nodes
     for (UnsignedInteger flatIndex = 0; flatIndex < size; ++flatIndex)
     {
@@ -274,7 +281,7 @@ Scalar Dirichlet::computeCDF(const Point & point) const
     return value;
   }
   // Use crude Monte Carlo for now, with a fixed sampling size
-  static const UnsignedInteger samplingSize(ResourceMap::GetAsUnsignedInteger("DefaultSamplingSize"));
+  static const UnsignedInteger samplingSize(ResourceMap::GetAsUnsignedInteger("Dirichlet-DefaultSamplingSize"));
   RandomGeneratorState initialState(RandomGenerator::GetState());
   RandomGenerator::SetSeed(samplingSize);
   static const Sample sample(getSample(samplingSize));
@@ -531,23 +538,6 @@ Point Dirichlet::getTheta() const
   return theta_;
 }
 
-/* Get the i-th marginal distribution */
-Distribution Dirichlet::getMarginal(const UnsignedInteger i) const
-{
-  const UnsignedInteger dimension = getDimension();
-  if (i >= dimension) throw InvalidArgumentException(HERE) << "The index of a marginal distribution must be in the range [0, dim-1]";
-  if (dimension == 1) return clone();
-  Beta marginal(theta_[i], sumTheta_ - theta_[i], 0.0, 1.0);
-  /*
-  Point thetaMarginal(2);
-  thetaMarginal[0] = theta_[i];
-  thetaMarginal[1] = sumTheta_ - theta_[i];
-  Dirichlet::Implementation marginal(new Dirichlet(thetaMarginal));
-  */
-  marginal.setDescription({getDescription()[i]});
-  return marginal;
-}
-
 /* Get the distribution of the marginal distribution corresponding to indices dimensions */
 Distribution Dirichlet::getMarginal(const Indices & indices) const
 {
@@ -555,6 +545,13 @@ Distribution Dirichlet::getMarginal(const Indices & indices) const
   if (!indices.check(dimension)) throw InvalidArgumentException(HERE) << "The indices of a marginal distribution must be in the range [0, dim-1] and must be different";
   if (dimension == 1) return clone();
   const UnsignedInteger outputDimension = indices.getSize();
+  if (outputDimension == 1)
+  {
+    const UnsignedInteger index_i = indices[0];
+    Beta marginal(theta_[index_i], sumTheta_ - theta_[index_i], 0.0, 1.0);
+    marginal.setDescription({getDescription()[index_i]});
+    return marginal;
+  }
   Point thetaMarginal(outputDimension + 1);
   Scalar sumMarginal = 0.0;
   for (UnsignedInteger i = 0; i < outputDimension; ++i)
