@@ -2,7 +2,7 @@
 /**
  *  @brief Discrete compound distribution
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -161,7 +161,8 @@ void DiscreteCompoundDistribution::setBaseAndCompoundDistributions(const Distrib
   baseDistribution_ = baseDistribution;
   compoundDistribution_ = compoundDistribution;
 
-  const UnsignedInteger m = computeIntegerUpperBound();
+  // include last value
+  const UnsignedInteger m = computeIntegerUpperBound() + 1;
 
   const Point weights(computeProbabilities(m));
   Sample points(m, 1);
