@@ -2,7 +2,7 @@
 /**
  *  @brief OpenTURNS wrapper to a library of special functions
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -29,6 +29,7 @@
 #include "openturns/RandomGenerator.hxx"
 #include "openturns/Log.hxx"
 #include "openturns/KFactorFunctions.hxx"
+#include "openturns/KolmogorovFunctions.hxx"
 #include "openturns/Normal2DCDF.hxx"
 #include "openturns/Normal3DCDF.hxx"
 #include "openturns/Exception.hxx"
@@ -36,13 +37,10 @@
 #ifdef OPENTURNS_HAVE_BOOST
 
 #include <boost/math/distributions/hypergeometric.hpp>
+#include <boost/math/distributions/poisson.hpp>
 
 #endif
 
-// The following implementation of the Kolmogorov CDF and tail CDF is used in a LGPL context with written permission of the author.
-#include "KolmogorovSmirnovDist.h"
-// The following implementation of the Poisson quantile is used in a LGPL context with written permission of the author.
-#include "poissinv_cpu.h"
 #include "openturns/StudentFunctions.hxx"
 #include "openturns/OTconfig.hxx"
 
@@ -70,9 +68,9 @@ Scalar DistFunc::qBeta(const Scalar p1,
 /* Random number generation
    We use the algorithm of Cheng (1978), Johnk, Atkinson and Whittaker (1979) 1 & 2 described in:
    Luc Devroye, "Non-Uniform RandomVariate Generation", Springer-Verlag, 1986, available online at:
-   http://cg.scs.carleton.ca/~luc/nonuniformrandomvariates.zip
+   http://www.nrbook.com/devroye/Devroye_files/
    and with the important errata at:
-   http://cg.scs.carleton.ca/~luc/errors.pdf
+   http://www.nrbook.com/devroye/Devroye_files/errors.pdf
 */
 Scalar DistFunc::rBeta(const Scalar p1,
                        const Scalar p2)
@@ -570,7 +568,7 @@ void DistFunc::rDiscreteSetup(const Point & probabilities,
   } // small and large not empty
   for (; indexLarge < largeSize; ++indexLarge)
     base[large[indexLarge]] = 1.0;
-  // The next loop accurs only due to numerical instability
+  // The next loop occurs only due to numerical instability
   for (; indexSmall < smallSize; ++indexSmall)
     base[small[indexSmall]] = 1.0;
 }
@@ -844,14 +842,12 @@ Indices DistFunc::rHypergeometric(const UnsignedInteger n,
 /* CDF
    The algorithms and the selection strategy is described in:
    Simard, R. and L'Ecuyer, P. "Computing the Two-Sided Kolmogorov-Smirnov Distribution", Journal of Statistical Software, 2010.
-   The implementation is from the first author, initially published under the GPL v3 license but used here with written permission of the author.
 */
 Scalar DistFunc::pKolmogorov(const UnsignedInteger n,
                              const Scalar x,
                              const Bool tail)
 {
-  if (tail) return KSfbar(n, x);
-  else return KScdf(n, x);
+  return KolmogorovFunctions::_kolmogn(n, x, !tail);
 }
 
 /***************************************************************************************************************/
@@ -885,7 +881,7 @@ Scalar DistFunc::dNonCentralChiSquare(const Scalar nu,
   if (x <= 0.0) return 0.0;
   const Scalar halfNu = 0.5 * nu;
   // Early exit for lambda == 0, central ChiSquare PDF
-  if (std::abs(lambda) < precision) return std::exp((halfNu - 1.0) * std::log(x) - 0.5 * x - SpecFunc::LnGamma(halfNu) - halfNu * M_LN2);
+  if (std::abs(lambda) < precision) return std::exp((halfNu - 1.0) * std::log(x) - 0.5 * x - SpecFunc::LogGamma(halfNu) - halfNu * M_LN2);
   // Case lambda <> 0
   const Scalar halfLambda = 0.5 * lambda;
   // Starting index in the sum: integral part of halfDelta2 and insure that it is at least 1
@@ -895,7 +891,7 @@ Scalar DistFunc::dNonCentralChiSquare(const Scalar nu,
   Scalar pForward = std::exp(-halfLambda - 0.5 * x + (halfNu + k - 1.0) * std::log(x) - SpecFunc::LogGamma(k + 1.0) - SpecFunc::LogGamma(halfNu + k) - (2.0 * k + halfNu) * M_LN2 + k * std::log(lambda));
   Scalar pBackward = pForward;
   Scalar value = pForward;
-  Scalar error = SpecFunc::MaxScalar;
+  Scalar error = SpecFunc::Infinity;
   UnsignedInteger kForward = k;
   UnsignedInteger kBackward = k;
 #define FORWARD_ITERATION                                               \
@@ -969,7 +965,7 @@ Scalar DistFunc::pNonCentralChiSquare(const Scalar nu,
   Scalar gammaBackward = gammaForward;
   Scalar pBackward = expBackward * gammaBackward;
   Scalar value = pForward;
-  Scalar error = SpecFunc::MaxScalar;
+  Scalar error = SpecFunc::Infinity;
   UnsignedInteger kForward = k;
   UnsignedInteger kBackward = k;
 #define FORWARD_ITERATION                       \
@@ -1187,13 +1183,13 @@ Scalar DistFunc::pNormal3D(const Scalar x1,
 
 /* CDF inverse
    It implements the algorithm of Peter John Acklam, see
-   http://home.online.no/~pjacklam/notes/invnorm/index.html
+   https://stackedboxes.org/2017/05/01/acklams-normal-quantile-function/
 */
 Scalar DistFunc::qNormal(const Scalar p,
                          const Bool tail)
 {
-  if (p == 0.0) return (tail ?  8.125890664701906 : -8.125890664701906);
-  if (p == 1.0) return (tail ? -8.125890664701906 :  8.125890664701906);
+  if (p == 0.0) return (tail ? 8.125890664701906 : -37.5193793471445);
+  if (p == 1.0) return (tail ? -37.5193793471445 :  8.125890664701906);
 
   static const Scalar a[6] =
   {
@@ -1432,21 +1428,27 @@ Scalar DistFunc::dPoisson(const Scalar lambda,
   return std::exp(-SpecFunc::Stirlerr(k) - bd0(k, lambda)) / std::sqrt(2.0 * M_PI * k);
 }
 
-/* Quantile function
-   We use the algorithm described in:
-   Mikes Giles, "Fast evaluation of the inverse Poisson cumulative distribution function", https://people.maths.ox.ac.uk/gilesm/poissinv/paper.pdf
-   It is the Author's implementation, used in OpenTURNS with his written permission, see COPYING.poissinv
-*/
+/* Poisson Quantile function */
 Scalar DistFunc::qPoisson(const Scalar lambda,
                           const Scalar p,
                           const Bool tail)
 {
-  Scalar r = tail ? 1.0 - p : p;
-  if (r <= SpecFunc::MinScalar) r = SpecFunc::MinScalar;
-  if (r >= 1.0 - SpecFunc::ScalarEpsilon) r = 1.0 - SpecFunc::ScalarEpsilon;
-  // We use the scalar version
-  return poissinv_scalar(r, lambda);
+  if ((!tail && (p <= 0.0)) || (tail && (p > 1.0 - SpecFunc::ScalarEpsilon))) return 0.0;
+  const Scalar cp = std::min(std::max(p, SpecFunc::MinScalar), 1.0 - SpecFunc::ScalarEpsilon);
+#ifdef OPENTURNS_HAVE_BOOST
+  typedef boost::math::policies::policy< boost::math::policies::discrete_quantile<boost::math::policies::integer_round_up> > integer_round_up;
+  typedef boost::math::policies::policy< boost::math::policies::discrete_quantile<boost::math::policies::integer_round_down> > integer_round_down;
+  if (tail)
+    return boost::math::quantile(complement(boost::math::poisson_distribution<Scalar, integer_round_down >(lambda), cp));
+  else
+    return boost::math::quantile(boost::math::poisson_distribution<Scalar, integer_round_up >(lambda), cp);
+#else
+  const Scalar q = std::floor(SpecFunc::RegularizedIncompleteGammaInverse(lambda, cp, tail));
+  const Scalar pq = pGamma(q + 1.0, lambda, !tail);
+  return ((!tail && (pq < p)) || (tail && (pq > p))) ? (q + 1.0) : q;
+#endif
 }
+
 /* Random number generation
    For the small values of lambda, we use the method of inversion by sequential search described in:
    Luc Devroye, "Non-Uniform RandomVariate Generation", Springer-Verlag, 1986, available online at:
@@ -1478,7 +1480,7 @@ UnsignedInteger DistFunc::rPoisson(const Scalar lambda)
   const Scalar hatCenter = lambda + 0.5;
   const Scalar mode = floor(lambda);
   const Scalar logLambda = std::log(lambda);
-  const Scalar pdfMode = mode * logLambda - SpecFunc::LnGamma(mode + 1.0);
+  const Scalar pdfMode = mode * logLambda - SpecFunc::LogGamma(mode + 1.0);
   // 2.943035529371538572764190 = 8 / e
   // 0.898916162058898740826254 = 3 - 2 sqr(3 / e)
   const Scalar hatWidth = std::sqrt(2.943035529371538572764190 * (lambda + 0.5)) + 0.898916162058898740826254;
@@ -1489,7 +1491,7 @@ UnsignedInteger DistFunc::rPoisson(const Scalar lambda)
     const Scalar x = hatCenter + hatWidth * (RandomGenerator::Generate() - 0.5) / u;
     if (x < 0 || x >= safetyBound) continue;
     const UnsignedInteger k = static_cast< UnsignedInteger >(floor(x));
-    const Scalar logPdf = k * logLambda - SpecFunc::LnGamma(k + 1.0) - pdfMode;
+    const Scalar logPdf = k * logLambda - SpecFunc::LogGamma(k + 1.0) - pdfMode;
     // Quick acceptance
     if (logPdf >= u * (4.0 - u) - 3.0) return k;
     // Quick rejection
@@ -1532,7 +1534,7 @@ Scalar DistFunc::pPearsonCorrelation(const UnsignedInteger size, const Scalar rh
 /********************************************************************************************/
 /* Spearman rho distribution: let (X_i) and (Y_i) be two samples of size n and dimension 1. */
 /* This function computes the probability that the Spearman correlation between the samples */
-/* is less or equal (tail = false) or is greater (tail = ture) than the given value under   */
+/* is less or equal (tail = false) or is greater (tail = true) than the given value under   */
 /* the assumption that the permutation that reorder the first sample in the same order as   */
 /* the second sample is uniformly distributed among the n-permutations. It is the case in   */
 /* particular when the two samples are independent and iid.                                 */
@@ -1599,6 +1601,16 @@ Point DistFunc::pStudent(const Scalar nu,
     result[i] = StudentFunctions::StudentCDF(nu, x[i], tail);
   return result;
 }
+
+Scalar DistFunc::pStudent2D(const Scalar nu,
+                            const Scalar x1,
+                            const Scalar x2,
+                            const Scalar rho,
+                            const Bool tail)
+{
+  return StudentFunctions::Student2DCDF(nu, x1, x2, rho, tail);
+}
+
 /* CDF inverse */
 Scalar DistFunc::qStudent(const Scalar nu,
                           const Scalar p,
@@ -1700,7 +1712,7 @@ Scalar DistFunc::pDickeyFullerTrend(const Scalar x,
   const Scalar p010 = 0.10;
   if (x < q001)
   {
-    LOGWARN(OSS() <<  "Warning! Result p-value is missing. The return result is the 0.01 quantile level ");
+    LOGWARN(OSS() << "Result p-value is missing. The return result is the 0.01 quantile level ");
     return (tail ? 1.0 - p001 : p001);
   }
 
@@ -1725,7 +1737,7 @@ Scalar DistFunc::pDickeyFullerTrend(const Scalar x,
   }
 
   // Arbitrary we seek values until level 0.15
-  LOGWARN(OSS() <<  "Warning! Result p-value is missing. The return result is the 0.10 quantile levels ");
+  LOGWARN(OSS() << "Result p-value is missing. The return result is the 0.10 quantile levels ");
   return (tail ? 1.0 - p010 : p010);
 }
 
@@ -1741,7 +1753,7 @@ Scalar DistFunc::pDickeyFullerConstant(const Scalar x,
   const Scalar p010 = 0.10;
   if (x < q001)
   {
-    LOGWARN(OSS() <<  "Warning! Result p-value is missing. The return result is the 0.01 quantile level ");
+    LOGWARN(OSS() << "Result p-value is missing. The return result is the 0.01 quantile level ");
     return (tail ? 1.0 - p001 : p001);
   }
 
@@ -1764,7 +1776,7 @@ Scalar DistFunc::pDickeyFullerConstant(const Scalar x,
     const Scalar b = p005 - a * q005;
     return (tail ? 1.0 - (a * x + b) : a * x + b);
   }
-  LOGWARN(OSS() <<  "Warning! Result p-value is missing. The return result is the 0.10 quantile levels ");
+  LOGWARN(OSS() << "Result p-value is missing. The return result is the 0.10 quantile levels ");
   return (tail ? 1.0 - p010 : p010);
 }
 
@@ -1780,7 +1792,7 @@ Scalar DistFunc::pDickeyFullerNoConstant(const Scalar x,
   const Scalar p010 = 0.10;
   if (x < q001)
   {
-    LOGWARN(OSS() <<  "Warning! Result p-value is missing. The return result is the 0.01 quantile level ");
+    LOGWARN(OSS() << "Result p-value is missing. The return result is the 0.01 quantile level ");
     return (tail ? 1.0 - p001 : p001);
   }
 
@@ -1804,7 +1816,7 @@ Scalar DistFunc::pDickeyFullerNoConstant(const Scalar x,
     return (tail ? 1.0 - (a * x + b) : a * x + b);
   }
 
-  LOGWARN(OSS() <<  "Warning! Result p-value is missing. The return result is the 0.10 quantile levels ");
+  LOGWARN(OSS() << "Result p-value is missing. The return result is the 0.10 quantile levels ");
   return (tail ? 1.0 - p010 : p010);
 }
 
@@ -1826,7 +1838,7 @@ Scalar DistFunc::qDickeyFullerTrend(const Scalar p,
   const Scalar x010 = -3.13;
   if (prob < 0.01)
   {
-    LOGWARN(OSS() <<  "Warning! Result quantile value is missing. The return result is for level 0.01 ");
+    LOGWARN(OSS() << "Result quantile value is missing. The return result is for level 0.01 ");
     return x001;
   }
 
@@ -1853,7 +1865,7 @@ Scalar DistFunc::qDickeyFullerTrend(const Scalar p,
   // Arbitrary we seek values until level 0.15
   if (prob <= 0.15)
   {
-    LOGWARN(OSS() <<  "Warning! Result quantile value is missing. The return result is for level 0.10 ");
+    LOGWARN(OSS() << "Result quantile value is missing. The return result is for level 0.10 ");
     return x010;
   }
   throw NotYetImplementedException(HERE) << "In DistFunc::pDickeyFullerNoConstant(const Scalar x, const Bool tail): cannot give quantile value for the level " << p << ". Value is missing in table";
@@ -1870,7 +1882,7 @@ Scalar DistFunc::qDickeyFullerConstant(const Scalar p,
   const Scalar x010 = -2.57;
   if (prob < 0.01)
   {
-    LOGWARN(OSS() <<  "Warning! Result quantile value is missing. The return result is for level 0.01 ");
+    LOGWARN(OSS() << "Result quantile value is missing. The return result is for level 0.01 ");
     return x001;
   }
 
@@ -1897,7 +1909,7 @@ Scalar DistFunc::qDickeyFullerConstant(const Scalar p,
   // Arbitrary we seek values until level 0.15
   if (prob <= 0.15)
   {
-    LOGWARN(OSS() <<  "Warning! Result quantile value is missing. The return result is for level 0.10 ");
+    LOGWARN(OSS() << "Result quantile value is missing. The return result is for level 0.10 ");
     return x010;
   }
 
@@ -1915,7 +1927,7 @@ Scalar DistFunc::qDickeyFullerNoConstant(const Scalar p,
   const Scalar x010 = -1.62;
   if (prob < 0.01)
   {
-    LOGWARN(OSS() <<  "Warning! Result quantile value is missing. The return result is for level 0.01 ");
+    LOGWARN(OSS() << "Result quantile value is missing. The return result is for level 0.01 ");
     return x001;
   }
 
@@ -1942,7 +1954,7 @@ Scalar DistFunc::qDickeyFullerNoConstant(const Scalar p,
   // Arbitrary we seek values until level 0.15
   if (prob <= 0.15)
   {
-    LOGWARN(OSS() <<  "Warning! Result quantile value is missing. The return result is for level 0.10 ");
+    LOGWARN(OSS() << "Result quantile value is missing. The return result is for level 0.10 ");
     return x010;
   }
   throw NotYetImplementedException(HERE) << "In DistFunc::qDickeyFullerNoConstant(const Scalar p, const Bool tail): cannot give quantile value for the level " << p << ". Value is missing in table";
