@@ -2,7 +2,7 @@
 /**
  *  @brief The GeneralizedExtremeValue distribution
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -334,7 +334,7 @@ Graph GeneralizedExtremeValue::drawReturnLevel() const
   drawable.setLineStyle("solid");
   drawable.setLineWidth(2);
   drawable.setColor("red");
-  graph.setDrawable(drawable, 0);
+  graph.setDrawable(0, drawable);
   graph.setXTitle("Return period");
   graph.setYTitle("Return level");
   graph.setTitle("");
