@@ -2,7 +2,7 @@
 /**
  *  @brief The Hypergeometric distribution
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -257,29 +257,24 @@ Point Hypergeometric::getProbabilities() const
 /* Parameters value accessor */
 Point Hypergeometric::getParameter() const
 {
-  Point point(3);
-  point[0] = n_;
-  point[1] = k_;
-  point[2] = m_;
-  return point;
+  return {static_cast<Scalar>(n_), static_cast<Scalar>(k_), static_cast<Scalar>(m_)};
 }
 
 void Hypergeometric::setParameter(const Point & parameter)
 {
-  if (parameter.getSize() != 3) throw InvalidArgumentException(HERE) << "Error: expected 3 values, got " << parameter.getSize();
+  if (parameter.getSize() != 3) throw InvalidArgumentException(HERE) << "Hypergeometric expected 3 parameters, got " << parameter.getSize();
   const Scalar w = getWeight();
-  *this = Hypergeometric(static_cast<UnsignedInteger>(parameter[0]), static_cast<UnsignedInteger>(parameter[1]), static_cast<UnsignedInteger>(parameter[2]));
+  if (parameter[0] != std::round(parameter[0])) throw InvalidArgumentException(HERE) << "the Hypergeometric first parameter n must be an integer, got " << parameter[0];
+  if (parameter[1] != std::round(parameter[1])) throw InvalidArgumentException(HERE) << "the Hypergeometric second parameter k must be an integer, got " << parameter[1];
+  if (parameter[2] != std::round(parameter[2])) throw InvalidArgumentException(HERE) << "the Hypergeometric third parameter m must be an integer, got " << parameter[2];
+  *this = Hypergeometric(parameter[0], parameter[1], parameter[2]);
   setWeight(w);
 }
 
 /* Parameters description accessor */
 Description Hypergeometric::getParameterDescription() const
 {
-  Description description(3);
-  description[0] = "n";
-  description[1] = "k";
-  description[2] = "m";
-  return description;
+  return {"n", "k", "m"};
 }
 
 /* Check if the distribution is elliptical */
