@@ -2,7 +2,7 @@
 /**
  *  @brief The InverseWishart distribution
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -38,7 +38,6 @@ InverseWishart::InverseWishart()
 {
   setName("InverseWishart");
   setV(CovarianceMatrix(1));
-  computeRange();
   update();
 }
 
@@ -182,6 +181,47 @@ Scalar InverseWishart::computeLogPDF(const CovarianceMatrix & m) const
 {
   if (m.getDimension() != cholesky_.getDimension()) throw InvalidArgumentException(HERE) << "Error: the given matrix must have dimension=" << cholesky_.getDimension() << ", here dimension=" << m.getDimension();
   const UnsignedInteger p = cholesky_.getDimension();
+  if (p == 1)
+  {
+    const Scalar m00 = m(0, 0);
+    if (m00 <= 0.0) return SpecFunc::LowestScalar;
+    const Scalar c00 = cholesky_(0, 0);
+    return -0.5 * ((nu_ + 2.0) * std::log(m00) + c00 * c00 / m00) + logNormalizationFactor_;
+  }
+  if (p == 2)
+  {
+    const Scalar m00 = m(0, 0);
+    if (m00 <= 0.0) return SpecFunc::LowestScalar;
+    const Scalar m10 = m(1, 0);
+    const Scalar m11 = m(1, 1);
+    const Scalar mixed = m00 * m11 - m10 * m10;
+    if (mixed <= 0.0) return SpecFunc::LowestScalar;
+    const Scalar c00 = cholesky_(0, 0);
+    const Scalar c10 = cholesky_(1, 0);
+    const Scalar c11 = cholesky_(1, 1);
+    return -0.5 * ((nu_ + 3.0) * std::log(mixed) + (c00 * c00 * m11 - 2.0 * c00 * c10 * m10 + m00 * (c10 * c10 + c11 * c11)) / mixed) + logNormalizationFactor_;
+  }
+  if (p == 3)
+  {
+    const Scalar m00 = m(0, 0);
+    if (m00 <= 0.0) return SpecFunc::LowestScalar;
+    const Scalar m10 = m(1, 0);
+    const Scalar m11 = m(1, 1);
+    const Scalar mixed = m00 * m11 - m10 * m10;
+    if (mixed <= 0.0) return SpecFunc::LowestScalar;
+    const Scalar m20 = m(2, 0);
+    const Scalar m21 = m(2, 1);
+    const Scalar m22 = m(2, 2);
+    const Scalar mixed2 = mixed * m22 - m00 * m21 * m21 + 2.0 * m10 * m20 * m21 - m11 * m20 * m20;
+    if (mixed2 <= 0.0) return SpecFunc::LowestScalar;
+    const Scalar c00 = cholesky_(0, 0);
+    const Scalar c10 = cholesky_(1, 0);
+    const Scalar c20 = cholesky_(2, 0);
+    const Scalar c11 = cholesky_(1, 1);
+    const Scalar c21 = cholesky_(2, 1);
+    const Scalar c22 = cholesky_(2, 2);
+    return -0.5 * ((nu_ + 4.0) * std::log(mixed2) + (((c20 * c20 + c21 * c21 + c22 * c22) * m11 + (-2.0 * c10 * c20 - 2.0 * c11 * c21) * m21 + m22 * (c10 * c10 + c11 * c11)) * m00 + (-c20 * c20 - c21 * c21 - c22 * c22) * m10 * m10 + ((2.0 * c10 * c20 + 2.0 * c11 * c21) * m20 + 2.0 * c00 * (-c10 * m22 + c20 * m21)) * m10 + (-c10 * c10 - c11 * c11) * m20 * m20 + 2.0 * c00 * (c10 * m21 - c20 * m11) * m20 - c00 * c00 * (-m22 * m11 + m21 * m21)) / ((m22 * m11 - m21 * m21) * m00 - m11 * m20 * m20 + 2.0 * m10 * m20 * m21 - m10 * m10 * m22)) + logNormalizationFactor_;
+  }
   try
   {
     // If the Cholesky factor is not defined, it means that M is not symmetric positive definite (an exception is thrown) and the PDF is zero
@@ -196,7 +236,12 @@ Scalar InverseWishart::computeLogPDF(const CovarianceMatrix & m) const
     // Trace(V M^{-1}) = Trace(C C' X'^{-1} X^{-1}) = Trace(C'X'^{-1} X^{-1}C)
     //                 = Trace(A'A) with A = X^{-1}C
     const TriangularMatrix A(X.solveLinearSystemInPlace(cholesky_).getImplementation());
-    logPDF -= 0.5 * A.computeGram(true).computeTrace();
+    for (UnsignedInteger j = 0; j < p; ++j)
+      for (UnsignedInteger i = j; i < p; ++i)
+      {
+        const Scalar aij = A(i, j);
+        logPDF -= 0.5 * aij * aij;
+      }
     return logPDF;
   }
   catch (...)
@@ -209,24 +254,43 @@ Scalar InverseWishart::computeLogPDF(const CovarianceMatrix & m) const
 Scalar InverseWishart::computeCDF(const Point & point) const
 {
   if (point.getDimension() != getDimension()) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=" << getDimension() << ", here dimension=" << point.getDimension();
-  if (point[0] < getRange().getLowerBound()[0])
-    return 0.0;
-  if (point[0] > getRange().getUpperBound()[0])
-    return 1.0;
-  return DistributionImplementation::computeCDF(point);
+  const UnsignedInteger p = cholesky_.getDimension();
+  if (p == 1)
+  {
+    if (point[0] <= 0.0) return 0.0;
+    return DistFunc::pGamma(0.5 * nu_, 0.5 * cholesky_(0, 0) * cholesky_(0, 0) / point[0], true);
+  }
+  // Here we compute an ad-hoc scale and location as the distribution may not have
+  // a mean or a standard deviation
+  const Scalar a = ResourceMap::GetAsScalar("InverseWishart-CDFScaleFactor");
+  const CovarianceMatrix V(getV());
+  Point location(getDimension());
+  Point scale(getDimension());
+  UnsignedInteger index = 0;
+  for (UnsignedInteger i = 0; i < p; ++i)
+    for (UnsignedInteger j = 0; j <= i; ++j)
+    {
+      location[index] = V(i, j);
+      scale[index] = a * std::sqrt(V(i, j) * V(i, j) + V(i, i) * V(j, j));
+      ++index;
+    }
+
+  return DistributionImplementation::computeCDFUnimodal(point, location, scale, IteratedQuadrature(), std::pow(cdfEpsilon_, dimension_));
 }
 
 /* Compute the mean of the distribution */
 void InverseWishart::computeMean() const
 {
-  const CovarianceMatrix V(getV());
   const UnsignedInteger p = cholesky_.getDimension();
+  const Scalar den = nu_ - p - 1.0;
+  if (!(den > 0.0)) throw NotDefinedException(HERE) << "Error: the mean of the inverse Wishart distribution is defined only if nu > p+1, here nu = " << nu_ << " and p = " << p;
+  const CovarianceMatrix V(getV());
   mean_ = Point(getDimension());
   UnsignedInteger index = 0;
   for (UnsignedInteger i = 0; i < p; ++i)
     for (UnsignedInteger j = 0; j <= i; ++j)
     {
-      mean_[index] = V(i, j) / (nu_ - p - 1.0);
+      mean_[index] = V(i, j) / den;
       ++index;
     }
   isAlreadyComputedMean_ = true;
@@ -270,6 +334,9 @@ void InverseWishart::computeCovariance() const
 /* Get the standard deviation of the distribution */
 Point InverseWishart::getStandardDeviation() const
 {
+  const UnsignedInteger p = cholesky_.getDimension();
+  const Scalar den = (nu_ - p) * std::pow(nu_ - p - 1.0, 2) * (nu_ - p - 3.0);
+  if (!(den > 0.0)) throw NotDefinedException(HERE) << "Error: the standard deviation of the inverse Wishart distribution is defined only if nu > p+3, here nu = " << nu_ << " and p = " << p;
   Point sigma(getDimension());
   // If the covariance has already been computed, use it
   if (isAlreadyComputedCovariance_)
@@ -278,20 +345,33 @@ Point InverseWishart::getStandardDeviation() const
     return sigma;
   }
   // else compute only the standard deviation as the covariance may be huge
-  const UnsignedInteger p = cholesky_.getDimension();
-  const Scalar den = (nu_ - p) * std::pow(nu_ - p - 1.0, 2) * (nu_ - p - 3.0);
-  if (!(den > 0.0)) throw NotDefinedException(HERE) << "Error: the standard deviation of the inverse Wishart distribution is defined only if nu > p+3";
   const CovarianceMatrix V(getV());
   UnsignedInteger index = 0;
   for (UnsignedInteger i = 0; i < p; ++i)
     for (UnsignedInteger j = 0; j <= i; ++j)
     {
-      sigma[index] = std::sqrt((2.0 * V(i, j) * V(i, j) + (nu_ - p - 1.0) * (V(i, i) * V(j, j) + V(i, j) * V(i, j))) / den);
+      sigma[index] = std::sqrt(((nu_ - p + 1) * V(i, j) * V(i, j) + (nu_ - p - 1) * V(i, i) * V(j, j)) / den);
       ++index;
     }
   return sigma;
 }
 
+/* Get the skewness of the distribution */
+Point InverseWishart::getSkewness() const
+{
+  const UnsignedInteger p = cholesky_.getDimension();
+  if (!(nu_ - p - 5.0 > 0.0)) throw NotDefinedException(HERE) << "Error: the skewness of the inverse Wishart distribution is defined only if nu > p+5, here nu = " << nu_ << " and p = " << p;
+  return DistributionImplementation::getSkewness();
+}
+
+/* Get the kurtosis of the distribution */
+Point InverseWishart::getKurtosis() const
+{
+  const UnsignedInteger p = cholesky_.getDimension();
+  if (!(nu_ - p - 7.0 > 0.0)) throw NotDefinedException(HERE) << "Error: the kurtosis of the inverse Wishart distribution is defined only if nu > p+7, here nu = " << nu_ << " and p = " << p;
+  return DistributionImplementation::getKurtosis();
+}
+
 
 Point InverseWishart::getParameter() const
 {
@@ -360,11 +440,12 @@ void InverseWishart::setV(const CovarianceMatrix & v)
   {
     throw InvalidArgumentException(HERE) << "Error: V must be positive definite";
   }
-  const TriangularMatrix T(cholesky_.solveLinearSystem(IdentityMatrix(p)).getImplementation());
+  const TriangularMatrix T(cholesky_.inverse().getImplementation());
   // vInverse = T'.T, non const because we compute its Cholesky factor
   CovarianceMatrix vInverse(T.computeGram(true));
   // Flag false means that vInverse is not preserved, non const because we solve a linear system with this matrix
   TriangularMatrix vInverseCholesky(vInverse.computeCholeskyInPlace());
+  // Keep this as we don't have an in-place inverse
   inverseCholeskyInverse_ = vInverseCholesky.solveLinearSystemInPlace(IdentityMatrix(p)).getImplementation();
   setDimension((p * (p + 1)) / 2);
   isAlreadyComputedMean_ = false;
