@@ -410,7 +410,7 @@ struct ComposedDistributionComputeSamplePolicy
 }; /* end struct ComposedDistributionComputeSamplePolicy */
 
 /* Get a sample of the distribution */
-Sample JointDistribution::getSampleParallel(const UnsignedInteger size) const
+Sample JointDistribution::getSample(const UnsignedInteger size) const
 {
   const UnsignedInteger dimension = getDimension();
   if (!core_.isCopula() || !hasIndependentCopula())
@@ -419,8 +419,8 @@ Sample JointDistribution::getSampleParallel(const UnsignedInteger size) const
     // of possible parallelism of the getSample() method of the core
     const Sample coreSample(core_.getSample(size));
     Sample result(size, dimension);
-    const ComposedDistributionComputeSamplePolicy policy( coreSample, result, distributionCollection_ );
-    TBBImplementation::ParallelFor( 0, size, policy );
+    const ComposedDistributionComputeSamplePolicy policy(coreSample, result, distributionCollection_);
+    TBBImplementation::ParallelForIf(isParallel_, 0, size, policy);
     result.setName(getName());
     result.setDescription(getDescription());
     return result;
@@ -440,19 +440,13 @@ Sample JointDistribution::getSampleParallel(const UnsignedInteger size) const
       shift += dimension;
     }
   }
-  SampleImplementation result(size, dimension);
-  result.setData(data);
+  Sample result(size, dimension);
+  result.getImplementation()->setData(data);
   result.setName(getName());
   result.setDescription(getDescription());
   return result;
 }
 
-Sample JointDistribution::getSample(const UnsignedInteger size) const
-{
-  if (isParallel_) return getSampleParallel(size);
-  return DistributionImplementation::getSample(size);
-}
-
 /* Get the DDF of the JointDistribution */
 Point JointDistribution::computeDDF(const Point & point) const
 {
