@@ -2,7 +2,7 @@
 /**
  *  @brief The LogNormal distribution
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -22,7 +22,6 @@
 #include "openturns/LogNormal.hxx"
 #include "openturns/DistFunc.hxx"
 #include "openturns/SpecFunc.hxx"
-#include "openturns/RandomGenerator.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/Normal.hxx"
 #include "openturns/HermiteFactory.hxx"
@@ -35,7 +34,7 @@ static const Factory<LogNormal> Factory_LogNormal;
 
 /* Default constructor */
 LogNormal::LogNormal()
-  : ContinuousDistribution()
+  : DistributionImplementation()
   , muLog_(0.0)
   , sigmaLog_(0.0)
   , gamma_(0.0)
@@ -56,7 +55,7 @@ LogNormal::LogNormal()
 LogNormal::LogNormal(const Scalar muLog,
                      const Scalar sigmaLog,
                      const Scalar gamma)
-  : ContinuousDistribution()
+  : DistributionImplementation()
   , muLog_(0.0)
   , sigmaLog_(0.0)
   , gamma_(gamma)
@@ -479,7 +478,7 @@ Scalar LogNormal::getGamma() const
 /* Method save() stores the object through the StorageManager */
 void LogNormal::save(Advocate & adv) const
 {
-  ContinuousDistribution::save(adv);
+  DistributionImplementation::save(adv);
   adv.saveAttribute( "muLog_", muLog_ );
   adv.saveAttribute( "sigmaLog_", sigmaLog_ );
   adv.saveAttribute( "gamma_", gamma_ );
@@ -490,7 +489,7 @@ void LogNormal::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void LogNormal::load(Advocate & adv)
 {
-  ContinuousDistribution::load(adv);
+  DistributionImplementation::load(adv);
   adv.loadAttribute( "muLog_", muLog_ );
   adv.loadAttribute( "sigmaLog_", sigmaLog_ );
   adv.loadAttribute( "gamma_", gamma_ );
