@@ -2,7 +2,7 @@
 /**
  *  @brief The class that implements a generic mechanism to extract marginal distributions
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -42,18 +42,6 @@ MarginalDistribution::MarginalDistribution()
   setDistribution(Uniform());
 }
 
-/* Parameters constructor */
-MarginalDistribution::MarginalDistribution(const Distribution & distribution,
-    const UnsignedInteger & index)
-  : DistributionImplementation()
-  , distribution_()
-  , indices_()
-{
-  setName("MarginalDistribution");
-  setParallel(distribution.getImplementation()->isParallel());
-  setDistributionAndIndices(distribution, Indices(1, index));
-}
-
 /* Parameters constructor */
 MarginalDistribution::MarginalDistribution(const Distribution & distribution,
     const Indices & indices)
@@ -205,7 +193,7 @@ Scalar MarginalDistribution::computePDF(const Point & point) const
     if (isContinuous())
     {
       // Build the relevant parametric function to be integrated over the remaining parameters
-      const ParametricFunction kernel(PDFWrapper(distribution_.getImplementation()->clone()), indices_, point);
+      const ParametricFunction kernel(distribution_.getPDF(), indices_, point);
       const Interval marginalInterval(distribution_.getRange().getMarginal(indices_.complement(distribution_.getDimension())));
       return integrationAlgorithm_.integrate(kernel, marginalInterval)[0];
     }
@@ -344,18 +332,6 @@ Distribution MarginalDistribution::getMarginal(const Indices & indices) const
   return marginal.clone();
 }
 
-/* Get the isoprobabilistic transformation */
-MarginalDistribution::IsoProbabilisticTransformation MarginalDistribution::getIsoProbabilisticTransformation() const
-{
-  return distribution_.getIsoProbabilisticTransformation().getMarginal(indices_);
-}
-
-/* Get the inverse isoprobabilist transformation */
-MarginalDistribution::InverseIsoProbabilisticTransformation MarginalDistribution::getInverseIsoProbabilisticTransformation() const
-{
-  return distribution_.getInverseIsoProbabilisticTransformation().getMarginal(indices_);
-}
-
 /* Get the standard distribution */
 Distribution MarginalDistribution::getStandardDistribution() const
 {
