@@ -2,7 +2,7 @@
 /**
  *  @brief The NonCentralChiSquare distribution
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -20,8 +20,6 @@
  */
 #include <cmath>
 #include "openturns/NonCentralChiSquare.hxx"
-#include "openturns/RandomGenerator.hxx"
-#include "openturns/SpecFunc.hxx"
 #include "openturns/DistFunc.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 
@@ -35,7 +33,7 @@ static const Factory<NonCentralChiSquare> Factory_NonCentralChiSquare;
 /* Default constructor */
 NonCentralChiSquare::NonCentralChiSquare(const Scalar nu,
     const Scalar lambda)
-  : ContinuousDistribution()
+  : DistributionImplementation()
   , nu_(0.0)
   , lambda_(0.0)
   , maximumIteration_(ResourceMap::GetAsUnsignedInteger("DistFunc-MaximumIteration"))
@@ -266,7 +264,7 @@ UnsignedInteger NonCentralChiSquare::getMaximumIteration() const
 /* Method save() stores the object through the StorageManager */
 void NonCentralChiSquare::save(Advocate & adv) const
 {
-  ContinuousDistribution::save(adv);
+  DistributionImplementation::save(adv);
   adv.saveAttribute( "nu_", nu_ );
   adv.saveAttribute( "lambda_", lambda_ );
   adv.saveAttribute( "maximumIteration_", maximumIteration_ );
@@ -275,7 +273,7 @@ void NonCentralChiSquare::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void NonCentralChiSquare::load(Advocate & adv)
 {
-  ContinuousDistribution::load(adv);
+  DistributionImplementation::load(adv);
   adv.loadAttribute( "nu_", nu_ );
   adv.loadAttribute( "lambda_", lambda_ );
   adv.loadAttribute( "maximumIteration_", maximumIteration_ );
