@@ -2,7 +2,7 @@
 /**
  *  @brief The Normal distribution
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -29,7 +29,6 @@
 #include "openturns/OSS.hxx"
 #include "openturns/DistFunc.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
-#include "openturns/Matrix.hxx"
 #include "openturns/MatrixImplementation.hxx"
 #include "openturns/NormalCopula.hxx"
 #include "openturns/ResourceMap.hxx"
@@ -80,7 +79,6 @@ Normal::Normal(const Point & mean,
                            , R
                            , 1.0)
   , logNormalizationFactor_((-1.0 * mean.getDimension()) * SpecFunc::LOGSQRT2PI)
-  , hasIndependentCopula_(false)
 {
   setName("Normal");
   // Compute the range, the upper class cannot do it.
@@ -102,7 +100,6 @@ Normal::Normal(const Point & mean,
                            , CorrelationMatrix(mean.getDimension())
                            , 1.0)
   , logNormalizationFactor_((-1.0 * mean.getDimension()) * SpecFunc::LOGSQRT2PI)
-  , hasIndependentCopula_(false)
 {
   setName("Normal");
   UnsignedInteger dimension = mean.getDimension();
@@ -114,10 +111,17 @@ Normal::Normal(const Point & mean,
   {
     const Scalar cii = C(i, i);
     if (!(cii > 0.0))
-      throw InvalidArgumentException(HERE) << "Diagonal elements of covariance matrix must be strictly positive";
-    sigma[i] = std::sqrt(cii);
-    for (UnsignedInteger j = 0; j < i; ++ j)
-      R(i, j) = C(i, j) / (sigma[i] * sigma[j]);
+    {
+      sigma[i] = 0.0;
+      // throw InvalidArgumentException(HERE) << "Diagonal elements of covariance matrix must be strictly positive";
+    }
+    else
+    {
+      sigma[i] = std::sqrt(cii);
+      for (UnsignedInteger j = 0; j < i; ++ j)
+        if (sigma[j] > 0.0)
+          R(i, j) = C(i, j) / (sigma[i] * sigma[j]);
+    }
   }
   *this = Normal(mean, sigma, R);
 }
@@ -147,7 +151,7 @@ String Normal::__str__(const String & offset) const
   OSS oss;
   oss << getClassName();
   if (getDimension() == 1) oss << "(mu = " << getMean()[0] << ", sigma = " << getSigma()[0] << ")";
-  else oss << "(mu = " << getMean().__str__() << ", sigma = " << getSigma().__str__() << ", R = " << getCorrelation().__str__(offset) << ")";
+  else oss << "(mu = " << getMean().__str__() << ", sigma = " << getSigma().__str__() << ", R = " << getR().__str__(offset) << ")";
   return oss;
 }
 
@@ -162,10 +166,9 @@ Point Normal::getRealization() const
 {
   const UnsignedInteger dimension = getDimension();
   if (dimension == 1) return Point(1, mean_[0] + sigma_[0] * DistFunc::rNormal());
-  Point value(dimension);
   // First, a realization of independent standard coordinates
-  for (UnsignedInteger i = 0; i < dimension; i++) value[i] = DistFunc::rNormal();
-  // Then, transform the independent standard coordinates into the needed ones */
+  Point value(DistFunc::rNormal(dimension));
+  // Then, transform the independent standard coordinates into the needed ones
   if (hasIndependentCopula_)
   {
     for (UnsignedInteger i = 0; i < dimension; i++)
@@ -187,8 +190,7 @@ Sample Normal::getSample(const UnsignedInteger size) const
     result.getImplementation()->setData(sigma_[0] * DistFunc::rNormal(size));
   else
   {
-    for (UnsignedInteger i = 0; i < size; ++i)
-      for (UnsignedInteger j = 0; j < dimension; ++j) result(i, j) = DistFunc::rNormal();
+    result.getImplementation()->setData(DistFunc::rNormal(size * dimension));
     if (hasIndependentCopula_) result *= sigma_;
     else
     {
@@ -237,7 +239,8 @@ Scalar Normal::computePDF(const Scalar x) const
 Scalar Normal::computePDF(const Point & point) const
 {
   const UnsignedInteger dimension = getDimension();
-  if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point has a dimension incompatible with the distribution.";
+  if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point has a dimension (" << point.getDimension()
+        << ") incompatible with the distribution (" << dimension << ").";
   // Special case for dimension 1
   if (dimension == 1) return computePDF(point[0]);
   return EllipticalDistribution::computePDF(point);
@@ -252,7 +255,8 @@ Scalar Normal::computeCDF(const Scalar x) const
 Scalar Normal::computeCDF(const Point & point) const
 {
   const UnsignedInteger dimension = getDimension();
-  if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point has a dimension incompatible with the distribution.";
+  if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point has a dimension (" << point.getDimension()
+        << ") incompatible with the distribution (" << dimension << ").";
   // Special case for dimension 1
   if (dimension == 1) return computeCDF(point[0]);
   // Normalize the point to use the standard form of the multivariate normal distribution
@@ -399,7 +403,8 @@ Scalar Normal::computeComplementaryCDF(const Scalar x) const
 Scalar Normal::computeComplementaryCDF(const Point & point) const
 {
   const UnsignedInteger dimension = getDimension();
-  if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point has a dimension incompatible with the distribution.";
+  if (point.getDimension() != dimension) throw InvalidArgumentException(HERE) << "Error: the given point has a dimension (" << point.getDimension()
+        << ") incompatible with the distribution (" << dimension << ").";
   // Special case for dimension 1
   if (dimension == 1) return computeComplementaryCDF(point[0]);
   return EllipticalDistribution::computeComplementaryCDF(point);
@@ -408,6 +413,10 @@ Scalar Normal::computeComplementaryCDF(const Point & point) const
 /* Compute the entropy of the distribution */
 Scalar Normal::computeEntropy() const
 {
+  // The entropy is equal to (see https://statproofbook.github.io/P/mvn-dent):
+  // (dim/2)*(log(2pi))+(1/2)*log(det(Sigma))+(1/2)*dim
+  // We reuse the normalization factors to avoid the recomputation of
+  // the most costly parts:
   // EllipticalDistribution::normalizationFactor_ == 1/sqrt(det(Sigma))
   // logNormalizationFactor_ == log(1/sqrt(2*Pi)^dim)
   return 0.5 * getDimension() - std::log(EllipticalDistribution::normalizationFactor_) - logNormalizationFactor_;
@@ -426,6 +435,7 @@ Complex Normal::computeCharacteristicFunction(const Point & x) const
 
 Complex Normal::computeLogCharacteristicFunction(const Scalar x) const
 {
+  if (dimension_ != 1) throw InvalidDimensionException(HERE) << "Normal: cannot use computeCharacteristicFunction with dimension > 1";
   return Complex(-0.5 * sigma_[0] * sigma_[0] * x * x, mean_[0] * x);
 }
 
@@ -440,8 +450,12 @@ Scalar Normal::computeProbability(const Interval & interval) const
 {
   if (interval.isEmpty()) return 0.0;
   const UnsignedInteger dimension = getDimension();
-  // The generic implementation provided by the DistributionImplementation upper class is more accurate than the generic implementation provided by the ContinuousDistribution upper class for dimension = 1
-  if (dimension == 1) return DistributionImplementation::computeProbability(interval);
+  if (interval.getDimension() != dimension)
+    throw InvalidArgumentException(HERE) << "computeProbability expected an interval of dimension=" << dimension_ << ", got dimension=" << interval.getDimension();
+
+  if (dimension == 1)
+    return computeProbabilityGeneral1D(interval.getLowerBound()[0], interval.getUpperBound()[0]);
+
   // Decompose and normalize the interval
   Point lower(normalize(interval.getLowerBound()));
   Point upper(normalize(interval.getUpperBound()));
@@ -472,9 +486,9 @@ Scalar Normal::computeProbability(const Interval & interval) const
     // Reduce the default integration point number for CDF computation in the range 3 < dimension <= Normal-SmallDimension
     const UnsignedInteger maximumNumber = static_cast< UnsignedInteger > (round(std::pow(ResourceMap::GetAsUnsignedInteger( "Normal-MaximumNumberOfPoints" ), 1.0 / getDimension())));
     const UnsignedInteger candidateNumber = ResourceMap::GetAsUnsignedInteger( "Normal-MarginalIntegrationNodesNumber" );
-    if (candidateNumber > maximumNumber) LOGWARN(OSS() << "Warning! The requested number of marginal integration nodes=" << candidateNumber << " would lead to an excessive number of PDF evaluations. It has been reduced to " << maximumNumber << ". You should increase the ResourceMap key \"Normal-MaximumNumberOfPoints\"");
+    if (candidateNumber > maximumNumber) LOGWARN(OSS() << "The requested number of marginal integration nodes=" << candidateNumber << " would lead to an excessive number of PDF evaluations. It has been reduced to " << maximumNumber << ". You should increase the ResourceMap key \"Normal-MaximumNumberOfPoints\"");
     setIntegrationNodesNumber(std::min(maximumNumber, candidateNumber));
-    return ContinuousDistribution::computeProbability(interval);
+    return DistributionImplementation::computeProbability(interval);
   }
   // For very large dimension, use a MonteCarlo algorithm
   LOGWARN(OSS() << "Warning, in Normal::computeProbability(), the dimension is very high. We will use a Monte Carlo method for the computation with a relative precision of 0.1% at 99% confidence level and a maximum of " << 10 * ResourceMap::GetAsUnsignedInteger( "Normal-MaximumNumberOfPoints" ) << " realizations. Expect a long running time and a poor accuracy for low values of the CDF...");
@@ -530,6 +544,8 @@ Scalar Normal::computeScalarQuantile(const Scalar prob,
                                      const Bool tail) const
 {
   if (dimension_ != 1) throw InvalidDimensionException(HERE) << "Error: the method computeScalarQuantile is only defined for 1D distributions";
+  if (!((prob >= 0.0) && (prob <= 1.0)))
+    throw InvalidArgumentException(HERE) << "computeScalarQuantile expected prob to belong to [0,1], but is " << prob;
   return mean_[0] + sigma_[0] * DistFunc::qNormal(prob, tail);
 } // computeScalarQuantile
 
@@ -550,18 +566,15 @@ Scalar Normal::computeConditionalPDF(const Scalar x,
   if ((conditioningDimension == 0) || (hasIndependentCopula()))
   {
     const Scalar z = (x - mean_[conditioningDimension]) / sigma_[conditioningDimension];
-    // Interest is to compute \sqrt{\frac{1}{2 \pi}} exp(-z*z)
-    // With x = \sqrt{2} z, we use the Gaussian density function
-    return DistFunc::dNormal(z * std::sqrt(2.0)) / sigma_[conditioningDimension];
+    // Interest is to compute \sqrt{\frac{1}{2 \pi}} exp(-z*z/2)
+    return DistFunc::dNormal(z) / sigma_[conditioningDimension];
   }
   // General case
   Scalar meanRos = 0.0;
   const Scalar sigmaRos = 1.0 / inverseCholesky_(conditioningDimension, conditioningDimension);
   for (UnsignedInteger i = 0; i < conditioningDimension; ++i)
-  {
-    meanRos += inverseCholesky_(conditioningDimension, i) / std::sqrt(sigma_[i]) * (y[i] - mean_[i]);
-  }
-  meanRos = mean_[conditioningDimension] - sigmaRos * std::sqrt(sigma_[conditioningDimension]) * meanRos;
+    meanRos += inverseCholesky_(conditioningDimension, i) * (y[i] - mean_[i]);
+  meanRos = mean_[conditioningDimension] - sigmaRos * meanRos;
   const Scalar z = (x - meanRos) / sigmaRos;
   return DistFunc::dNormal(z) / sigmaRos;
 }
@@ -598,10 +611,8 @@ Scalar Normal::computeConditionalCDF(const Scalar x,
   Scalar meanRos = 0.0;
   const Scalar sigmaRos = 1.0 / inverseCholesky_(conditioningDimension, conditioningDimension);
   for (UnsignedInteger i = 0; i < conditioningDimension; ++i)
-  {
-    meanRos += inverseCholesky_(conditioningDimension, i) / std::sqrt(sigma_[i]) * (y[i] - mean_[i]);
-  }
-  meanRos = mean_[conditioningDimension] - sigmaRos * std::sqrt(sigma_[conditioningDimension]) * meanRos;
+    meanRos += inverseCholesky_(conditioningDimension, i) * (y[i] - mean_[i]);
+  meanRos = mean_[conditioningDimension] - sigmaRos * meanRos;
   return DistFunc::pNormal((x - meanRos) / sigmaRos);
 }
 
@@ -620,21 +631,24 @@ Point Normal::computeSequentialConditionalCDF(const Point & x) const
 
 /* Compute the quantile of Xi | X1, ..., Xi-1, i.e. x such that CDF(x|y) = q with x = Xi, y = (X1,...,Xi-1) */
 Scalar Normal::computeConditionalQuantile(const Scalar q,
+
     const Point & y) const
+
 {
+
   const UnsignedInteger conditioningDimension = y.getDimension();
+
   if (conditioningDimension >= getDimension()) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional quantile with a conditioning point of dimension greater or equal to the distribution dimension.";
   if ((q < 0.0) || (q > 1.0)) throw InvalidArgumentException(HERE) << "Error: cannot compute a conditional quantile for a probability level outside of [0, 1]";
-  // Special case when no contitioning or independent copula
+  // Special case when no conditioning or independent copula
   if ((conditioningDimension == 0) || hasIndependentCopula()) return mean_[conditioningDimension] + sigma_[conditioningDimension] * DistFunc::qNormal(q);
   // General case
   Scalar meanRos = 0.0;
   const Scalar sigmaRos = 1.0 / inverseCholesky_(conditioningDimension, conditioningDimension);
   for (UnsignedInteger i = 0; i < conditioningDimension; ++i)
-  {
-    meanRos += inverseCholesky_(conditioningDimension, i) / std::sqrt(sigma_[i]) * (y[i] - mean_[i]);
-  }
-  meanRos = mean_[conditioningDimension] - sigmaRos * std::sqrt(sigma_[conditioningDimension]) * meanRos;
+    meanRos += inverseCholesky_(conditioningDimension, i) * (y[i] - mean_[i]);
+
+  meanRos = mean_[conditioningDimension] - sigmaRos * meanRos;
   return meanRos + sigmaRos * DistFunc::qNormal(q);
 }
 
@@ -751,11 +765,11 @@ Scalar Normal::computeRadialDistributionCDF(const Scalar radius,
 }
 
 /* Correlation matrix accessor */
-void Normal::setCorrelation(const CorrelationMatrix & R)
+void Normal::setR(const CorrelationMatrix & R)
 {
   // Perform checks at the upper level
   // This call set also the range
-  EllipticalDistribution::setCorrelation(R);
+  EllipticalDistribution::setR(R);
   // Then check for independence
   checkIndependentCopula();
 }
