@@ -2,7 +2,7 @@
 /**
  *  @brief A class that implements a normal copula
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -139,7 +139,7 @@ struct NormalCopulaComputeSamplePolicy
 }; /* end struct NormalCopulaComputeSamplePolicy */
 
 /* Get a sample of the distribution */
-Sample NormalCopula::getSampleParallel(const UnsignedInteger size) const
+Sample NormalCopula::getSample(const UnsignedInteger size) const
 {
   if (hasIndependentCopula())
   {
@@ -156,20 +156,14 @@ Sample NormalCopula::getSampleParallel(const UnsignedInteger size) const
     const UnsignedInteger dimension = getDimension();
     const Sample normalSample(normal_.getSample(size));
     Sample result(size, dimension);
-    const NormalCopulaComputeSamplePolicy policy( normalSample, result );
-    TBBImplementation::ParallelFor( 0, size, policy );
+    const NormalCopulaComputeSamplePolicy policy(normalSample, result);
+    TBBImplementation::ParallelForIf(isParallel_, 0, size, policy);
     result.setName(getName());
     result.setDescription(getDescription());
     return result;
   } // Non independent copula
 }
 
-Sample NormalCopula::getSample(const UnsignedInteger size) const
-{
-  if (isParallel_) return getSampleParallel(size);
-  return DistributionImplementation::getSample(size);
-}
-
 /* Get the DDF of the distribution */
 Point NormalCopula::computeDDF(const Point & point) const
 {
@@ -363,7 +357,12 @@ CorrelationMatrix NormalCopula::getKendallTau() const
 /* Compute the entropy of the distribution */
 Scalar NormalCopula::computeEntropy() const
 {
-  return normal_.computeEntropy() - getDimension() * (SpecFunc::LOGSQRT2PI + 0.5);
+  // The entroy of the normal copula is the entropy of
+  // the associated standard normal distribution minus
+  // dim times the entropy of a standard univariate normal
+  // distribution, thus it is equal to (1/2)*log(|
+  //return normal_.computeEntropy() - getDimension() * (SpecFunc::LOGSQRT2PI + 0.5);
+  return -std::log(normal_.EllipticalDistribution::normalizationFactor_);
 }
 
 /* Get the Shape matrix of the copula */
