@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level class for Parametrized distributions
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -44,6 +44,7 @@ ParametrizedDistribution::ParametrizedDistribution(const DistributionParameters
   , distributionParameters_(distParam)
   , distribution_(distParam.getDistribution())
 {
+  setParallel(distribution_.getImplementation()->isParallel());
   // Update the range
   computeRange();
 }
@@ -227,6 +228,12 @@ String ParametrizedDistribution::__repr__() const
   return oss;
 }
 
+String ParametrizedDistribution::__str__(const String & ) const
+{
+  OSS oss(false);
+  oss << getClassName() << "(parameters = " << distributionParameters_.__str__() << ")";
+  return oss;
+}
 
 /* Get the roughness, i.e. the L2-norm of the PDF */
 Scalar ParametrizedDistribution::getRoughness() const
@@ -317,5 +324,10 @@ void ParametrizedDistribution::load(Advocate & adv)
   distribution_ = distributionParameters_.getDistribution();
 }
 
+/** Distribution parameters accessor */
+DistributionParameters ParametrizedDistribution::getDistributionParameters() const
+{
+  return distributionParameters_;
+}
 
 END_NAMESPACE_OPENTURNS
