@@ -2,7 +2,7 @@
 /**
  *  @brief The ProductDistribution distribution
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -135,12 +135,12 @@ public:
     // Nothing to do
   }
 
-  PDFKernelProductDistribution * clone() const
+  PDFKernelProductDistribution * clone() const override
   {
     return new PDFKernelProductDistribution(*this);
   }
 
-  Scalar operator() (const Scalar u) const
+  Scalar operator() (const Scalar u) const override
   {
     const Scalar value = p_left_->computePDF(u);
     if (value == 0.0) return 0.0;
@@ -188,12 +188,12 @@ public:
     // Nothing to do
   }
 
-  CDFKernelProductDistribution * clone() const
+  CDFKernelProductDistribution * clone() const override
   {
     return new CDFKernelProductDistribution(*this);
   }
 
-  Scalar operator() (const Scalar u) const
+  Scalar operator() (const Scalar u) const override
   {
     const Scalar value = p_left_->computePDF(u);
     if (value == 0.0) return 0.0;
@@ -230,12 +230,12 @@ public:
     // Nothing to do
   }
 
-  ComplementaryCDFKernelProductDistributionProductDistribution * clone() const
+  ComplementaryCDFKernelProductDistributionProductDistribution * clone() const override
   {
     return new ComplementaryCDFKernelProductDistributionProductDistribution(*this);
   }
 
-  Scalar operator() (const Scalar u) const
+  Scalar operator() (const Scalar u) const override
   {
     const Scalar value = p_left_->computePDF(u);
     if (value == 0.0) return 0.0;
@@ -269,12 +269,12 @@ public:
     // Nothing to do
   };
 
-  CFKernelProductDistribution * clone() const
+  CFKernelProductDistribution * clone() const override
   {
     return new CFKernelProductDistribution(*this);
   }
 
-  Point operator() (const Point & point) const
+  Point operator() (const Point & point) const override
   {
     Point value(2);
     const Scalar u = point[0];
@@ -285,12 +285,12 @@ public:
     return value;
   };
 
-  UnsignedInteger getInputDimension() const
+  UnsignedInteger getInputDimension() const override
   {
     return 1;
   }
 
-  UnsignedInteger getOutputDimension() const
+  UnsignedInteger getOutputDimension() const override
   {
     return 2;
   }
@@ -855,7 +855,7 @@ void ProductDistribution::setLeft(const Distribution & left)
   isAlreadyComputedMean_ = false;
   isAlreadyComputedCovariance_ = false;
   isAlreadyCreatedGeneratingFunction_ = false;
-  isParallel_ = p_left_->isParallel();
+  setParallel(p_left_->isParallel() && p_right_->isParallel());
   computeRange();
 }
 
@@ -873,7 +873,7 @@ void ProductDistribution::setRight(const Distribution & right)
   isAlreadyComputedMean_ = false;
   isAlreadyComputedCovariance_ = false;
   isAlreadyCreatedGeneratingFunction_ = false;
-  isParallel_ = p_right_->isParallel();
+  setParallel(p_left_->isParallel() && p_right_->isParallel());
   computeRange();
 }
 
