@@ -2,7 +2,7 @@
 /**
  *  @brief The Rice distribution
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -21,7 +21,6 @@
 #include <cmath>
 #include "openturns/Rice.hxx"
 #include "openturns/SpecFunc.hxx"
-#include "openturns/RandomGenerator.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/DistFunc.hxx"
 #include "openturns/SpecFunc.hxx"
@@ -35,7 +34,7 @@ static const Factory<Rice> Factory_Rice;
 
 /* Default constructor */
 Rice::Rice()
-  : ContinuousDistribution()
+  : DistributionImplementation()
   , beta_(-1.0)
   , nu_(-1.0)
   , maximumIteration_(ResourceMap::GetAsUnsignedInteger("DistFunc-MaximumIteration"))
@@ -50,7 +49,7 @@ Rice::Rice()
 /* Parameters constructor */
 Rice::Rice(const Scalar beta,
            const Scalar nu)
-  : ContinuousDistribution()
+  : DistributionImplementation()
   , beta_(0.0)
   , nu_(nu)
   , maximumIteration_(ResourceMap::GetAsUnsignedInteger("DistFunc-MaximumIteration"))
@@ -316,7 +315,7 @@ UnsignedInteger Rice::getMaximumIteration() const
 /* Method save() stores the object through the StorageManager */
 void Rice::save(Advocate & adv) const
 {
-  ContinuousDistribution::save(adv);
+  DistributionImplementation::save(adv);
   adv.saveAttribute( "beta_", beta_ );
   adv.saveAttribute( "nu_", nu_ );
   adv.saveAttribute( "maximumIteration_", maximumIteration_ );
@@ -325,7 +324,7 @@ void Rice::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void Rice::load(Advocate & adv)
 {
-  ContinuousDistribution::load(adv);
+  DistributionImplementation::load(adv);
   if (adv.hasAttribute("sigma_")) // old parameters
     adv.loadAttribute( "sigma_", beta_ );
   else
