@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for StudentCopula distribution
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -88,7 +88,7 @@ StudentCopula StudentCopulaFactory::buildAsStudentCopula(const Sample & sample)
   values.erase(0);
   Indices indices(values.getSize());
   indices.fill(1);
-  factory.setKnownParameter(values, indices);
+  factory.setKnownParameter(indices, values);
 
   factory.setOptimizationAlgorithm(solver_);
   const Scalar nuMin = ResourceMap::GetAsScalar("StudentCopulaFactory-NuMin");
