@@ -2,7 +2,7 @@
 /**
  *  @brief The TruncatedDistribution distribution
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -31,6 +31,8 @@
 #include "openturns/JointDistribution.hxx"
 #include "openturns/BlockIndependentDistribution.hxx"
 #include "openturns/BlockIndependentCopula.hxx"
+#include "openturns/Dirichlet.hxx"
+#include "openturns/Beta.hxx"
 
 BEGIN_NAMESPACE_OPENTURNS
 
@@ -296,6 +298,13 @@ Bool TruncatedDistribution::hasSimplifiedVersion(Distribution & simplified) cons
       simplified = Exponential(lambda, alpha);
       return true;
     }
+    if (kind == "Dirichlet")
+    {
+      const Dirichlet * dirichlet(dynamic_cast< const Dirichlet * >(localDistribution.getImplementation().get()));
+      const Point theta(dirichlet->getTheta());
+      simplified = Beta(theta[0], theta[1], alpha, beta);
+      return true;
+    }
   }
   if (level > 1)
   {
