@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for TruncatedNormal distribution
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -70,7 +70,7 @@ TruncatedNormal TruncatedNormalFactory::buildMethodOfMoments(const Sample & samp
   const Scalar xMin = sample.getMin()[0];
   const Scalar xMax = sample.getMax()[0];
   const Scalar mean = sample.computeMean()[0];
-  if (!SpecFunc::IsNormal(mean)) throw InvalidArgumentException(HERE) << "Error: cannot build a TruncatedNormal distribution if data contains NaN or Inf";
+  if (!std::isfinite(mean)) throw InvalidArgumentException(HERE) << "Error: cannot build a TruncatedNormal distribution if data contains NaN or Inf";
   if (xMin == xMax) throw InvalidArgumentException(HERE) << "Error: cannot estimate a TruncatedNormal distribution from a constant sample.";
   Scalar delta = xMax - xMin;
   const Scalar a = xMin - delta / (size + 2);
@@ -82,7 +82,7 @@ TruncatedNormal TruncatedNormalFactory::buildMethodOfMoments(const Sample & samp
   // Set the bounds as known parameters
   const Point knownParameterValues = {a, b};
   const Indices knownParameterIndices = {2, 3};
-  factory.setKnownParameter(knownParameterValues, knownParameterIndices);
+  factory.setKnownParameter(knownParameterIndices, knownParameterValues);
 
   // Compute the mean and std and set it as initial values
   const Scalar sampleMean = sample.computeMean()[0];
@@ -109,7 +109,7 @@ TruncatedNormal TruncatedNormalFactory::buildMethodOfLikelihoodMaximization(cons
   const Scalar xMin = sample.getMin()[0];
   const Scalar xMax = sample.getMax()[0];
   const Scalar mean = sample.computeMean()[0];
-  if (!SpecFunc::IsNormal(mean)) throw InvalidArgumentException(HERE) << "Error: cannot build a TruncatedNormal distribution if data contains NaN or Inf";
+  if (!std::isfinite(mean)) throw InvalidArgumentException(HERE) << "Error: cannot build a TruncatedNormal distribution if data contains NaN or Inf";
   if (xMin == xMax) throw InvalidArgumentException(HERE) << "Error: cannot estimate a TruncatedNormal distribution from a constant sample.";
 
   // X_norm = alpha * (X - beta)
@@ -134,7 +134,7 @@ TruncatedNormal TruncatedNormalFactory::buildMethodOfLikelihoodMaximization(cons
   knownParameterValues[0] = -oneEps;
   Indices knownParameterIndices(2);
   knownParameterIndices.fill(2);
-  factory.setKnownParameter(knownParameterValues, knownParameterIndices);
+  factory.setKnownParameter(knownParameterIndices, knownParameterValues);
 
   // override starting point
   OptimizationAlgorithm solver(factory.getOptimizationAlgorithm());
@@ -165,7 +165,7 @@ TruncatedNormal TruncatedNormalFactory::buildMethodOfLikelihoodMaximization(cons
   TruncatedNormal result(buildAsTruncatedNormal({mu, sigma, a, b}));
 
   // abort if distribution is not valid
-  if (!SpecFunc::IsNormal(result.getMean()[0]))
+  if (!std::isfinite(result.getMean()[0]))
     throw InvalidArgumentException(HERE) << "Likelihood-optimized TruncatedNormal is not valid";
 
   result.setDescription(sample.getDescription());
