@@ -110,8 +110,8 @@ Point Uniform::getRealization() const
 /* Get a sample of the distribution */
 Sample Uniform::getSample(const UnsignedInteger size) const
 {
-  SampleImplementation result(size, 1);
-  result.setData(RandomGenerator::Generate(size));
+  Sample result(size, 1);
+  result.getImplementation()->setData(RandomGenerator::Generate(size));
   result *= Point(1, b_ - a_);
   result += Point(1, a_);
   result.setName(getName());
