@@ -2,7 +2,7 @@
 /**
  *  @brief The UserDefined distribution
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -406,6 +406,51 @@ void UserDefined::computeCovariance() const
   isAlreadyComputedCovariance_ = true;
 }
 
+/* Compute the Spearman correlation of the distribution */
+CorrelationMatrix UserDefined::getSpearmanCorrelation() const
+{
+  const UnsignedInteger size = points_.getSize();
+  const UnsignedInteger dimension = getDimension();
+  Sample rank(size, dimension);
+  // Build the correct weighted ranks and compute its mean along the way
+  Point meanRank(dimension);
+  for (UnsignedInteger i = 0; i < dimension; ++i)
+  {
+    const Distribution marginalI(getMarginal(i));
+    for (UnsignedInteger k = 0; k < size; ++k)
+    {
+      rank(k, i) = marginalI.computeCDF(points_(k, i));
+      meanRank[i] += probabilities_[k] * rank(k, i);
+    } // k
+  } // i
+  // Then, the covariance of the rank
+  CorrelationMatrix spearman(dimension);
+  for (UnsignedInteger k = 0; k < size; ++k)
+  {
+    const Point xK(rank[k] - meanRank);
+    const Scalar pK = probabilities_[k];
+    for (UnsignedInteger i = 0; i < dimension; ++i)
+      for (UnsignedInteger j = 0; j <= i; ++j)
+        spearman(i, j) += pK * xK[i] * xK[j];
+  }  // k
+  // Then, the correlation
+  Point std(dimension);
+  for (UnsignedInteger i = 0; i < dimension; ++i)
+  {
+    std[i] = std::sqrt(spearman(i, i));
+    for (UnsignedInteger j = 0; j < i; ++j)
+      spearman(i, j) /= std[i] * std[j];
+    spearman(i, i) = 1.0;
+  }
+  return spearman;
+}
+
+/* Compute the Kendall concordance of the distribution */
+CorrelationMatrix UserDefined::getKendallTau() const
+{
+  return DistributionImplementation::getKendallTau();
+}
+
 /* Parameters value and description accessor */
 UserDefined::PointWithDescriptionCollection UserDefined::getParametersCollection() const
 {
@@ -610,9 +655,12 @@ Scalar UserDefined::computeScalarQuantile(const Scalar prob,
   if (dimension_ != 1) throw InvalidDimensionException(HERE) << "Error: the method computeScalarQuantile is only defined for 1D distributions";
   if (!((prob >= 0.0) && (prob <= 1.0)))
     throw InvalidArgumentException(HERE) << "computeScalarQuantile expected prob to belong to [0,1], but is " << prob;
-  UnsignedInteger index = 0;
-  const Scalar p = tail ? 1 - prob : prob;
-  while (cumulativeProbabilities_[index] < p) ++index;
+  UnsignedInteger index = tail ? cumulativeProbabilities_.getSize() - 1 : 0;
+  const Scalar p = tail ? 0.5 - (prob - 0.5) : prob;
+  if (tail)
+    while (p < 1.0 && index > 0 && cumulativeProbabilities_[index] > p) --index;
+  else
+    while (cumulativeProbabilities_[index] < p) ++index;
   return points_(index, 0);
 }
 
