@@ -2,7 +2,7 @@
 /**
  *  @brief The VonMises distribution
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -201,7 +201,7 @@ Scalar VonMises::computePDF(const Point & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const Scalar x = point[0];
-  if (std::abs(x - mu_) > M_PI) return 0.0;
+  if (std::abs(x - mu_) >= M_PI) return 0.0;
   return std::exp(computeLogPDF(point));
 }
 
@@ -210,7 +210,7 @@ Scalar VonMises::computeLogPDF(const Point & point) const
   if (point.getDimension() != 1) throw InvalidArgumentException(HERE) << "Error: the given point must have dimension=1, here dimension=" << point.getDimension();
 
   const Scalar x = point[0];
-  if (std::abs(x - mu_) > M_PI) return SpecFunc::LowestScalar;
+  if (std::abs(x - mu_) >= M_PI) return SpecFunc::LowestScalar;
   return normalizationFactor_ + kappa_ * std::cos(x - mu_);
 }
 
