@@ -2,7 +2,7 @@
 /**
  *  @brief Factory for WeibullMax distribution
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -67,7 +67,7 @@ WeibullMax WeibullMaxFactory::buildAsWeibullMax(const Sample & sample) const
     for (UnsignedInteger i = 0; i < knownParameterIndices_.getSize(); ++i)
       if (knownParameterIndices_[i] == 2)
         minParametersValues[i] *= -1.0;
-    minFactory.setKnownParameter(minParametersValues, knownParameterIndices_);
+    minFactory.setKnownParameter(knownParameterIndices_, minParametersValues);
   }
   const Distribution weibullMin(minFactory.build(-1.0 * sample));
   Point parameter(weibullMin.getParameter());
