@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level class for archimedean copulas
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -185,4 +185,43 @@ Distribution ArchimedeanCopula::getMarginal(const Indices & indices) const
   return result;
 }
 
+/* Upper tail dependence matrix */
+CorrelationMatrix ArchimedeanCopula::computeUpperTailDependenceMatrix() const
+{
+  CorrelationMatrix result(dimension_);
+  /* The upper tail dependence is given by
+     lambdaU = \lim_{x\rightarrow 1^{-}} 2 - 2\psi'(x) / \psi'(\psi^{-1}(2\psi(x)))
+             = \lim_{x\rightarrow 0^{+}} 2 - 2\psi'(2x) / \psi'(x)
+     but as one can have psi'(0)=-inf, resulting
+     into a NaN, we evaluate the expression at quantileEpsilon_.
+  */
+  const Scalar lambdaU = 2.0 - 2.0 * computeArchimedeanGeneratorDerivative(2.0 * quantileEpsilon_) / computeArchimedeanGeneratorDerivative(quantileEpsilon_);
+  /* For an archimedean copula, all the upper tail dependence indices are equal */
+  for (UnsignedInteger j = 0; j < dimension_; ++j)
+    for (UnsignedInteger i = j + 1; i < dimension_; ++i)
+      result(i, j) = lambdaU;
+  return result;
+}
+
+/* Lower tail dependence matrix */
+CorrelationMatrix ArchimedeanCopula::computeLowerTailDependenceMatrix() const
+{
+  CorrelationMatrix result(dimension_);
+  /* The lower tail dependence is given by
+     lambdaU = \lim_{x\rightarrow 0^{+}} 2\psi'(x) / \psi'(\psi^{-1}(2\psi(x)))
+     but as one can have psi'(0)=0=psi'(psi^{-1}(2psi(0))), resulting
+     into a NaN, we evaluate the expression at quantileEpsilon_.
+  */
+  const Scalar dphi0 = computeArchimedeanGeneratorDerivative(quantileEpsilon_);
+  const Scalar phi0 = computeArchimedeanGenerator(quantileEpsilon_);
+  const Scalar phiInv = computeInverseArchimedeanGenerator(2.0 * phi0);
+  const Scalar dphiDen = computeArchimedeanGeneratorDerivative(phiInv);
+  const Scalar lambdaL = 2.0 * dphi0 / dphiDen;
+  /* For an archimedean copula, all the lower tail dependence indices are equal */
+  for (UnsignedInteger j = 0; j < dimension_; ++j)
+    for (UnsignedInteger i = j + 1; i < dimension_; ++i)
+      result(i, j) = lambdaL;
+  return result;
+}
+
 END_NAMESPACE_OPENTURNS
