@@ -2,7 +2,7 @@
 /**
  * @brief Top-level class for all distribution factories
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -245,13 +245,18 @@ DistributionFactoryResult DistributionFactory::buildEstimator(const Sample & sam
   return getImplementation()->buildEstimator(sample, parameters);
 }
 
-void DistributionFactory::setKnownParameter(const Point & values,
-    const Indices & indices)
+void DistributionFactory::setKnownParameter(const Point & values, const Indices & indices)
 {
   copyOnWrite();
   getImplementation()->setKnownParameter(values, indices);
 }
 
+void DistributionFactory::setKnownParameter(const Indices & indices, const Point & values)
+{
+  copyOnWrite();
+  getImplementation()->setKnownParameter(indices, values);
+}
+
 Indices DistributionFactory::getKnownParameterIndices() const
 {
   return getImplementation()->getKnownParameterIndices();
