@@ -2,7 +2,7 @@
 /**
  *  @brief Abstract top-level class for elliptical distributions
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -70,7 +70,7 @@ EllipticalDistribution::EllipticalDistribution(const Point & mu,
         << " mu dimension=" << mu.getDimension();
   // We check that the marginal standard deviations are > 0
   for(UnsignedInteger i = 0; i < dimension; ++i)
-    if (!(sigma[i] > 0.0)) throw InvalidArgumentException(HERE) << "The marginal standard deviations must be > 0 sigma=" << sigma[i];
+    if (!(sigma[i] >= 0.0)) throw InvalidArgumentException(HERE) << "The marginal standard deviations must be >= 0 sigma=" << sigma[i];
   // Then we set the dimension of the Elliptical distribution
   setDimension(dimension);
   // The mean attribute is stored at an upper level
@@ -328,7 +328,7 @@ Scalar EllipticalDistribution::computeLogPDF(const Point & point) const
       const Scalar iLx = (point[0] - mean_[0]) / sigma_[0];
       const Scalar betaSquare = iLx * iLx;
       const Scalar logDensityGenerator = computeLogDensityGenerator(betaSquare);
-      if (!SpecFunc::IsNormal(logDensityGenerator)) return SpecFunc::LowestScalar;
+      if (!std::isfinite(logDensityGenerator)) return SpecFunc::LowestScalar;
       return std::log(normalizationFactor_) + logDensityGenerator;
     }
     break;
@@ -349,7 +349,7 @@ Scalar EllipticalDistribution::computeLogPDF(const Point & point) const
       }
       const Scalar betaSquare = iLx * iLx + iLy * iLy;
       const Scalar logDensityGenerator = computeLogDensityGenerator(betaSquare);
-      if (!SpecFunc::IsNormal(logDensityGenerator)) return SpecFunc::LowestScalar;
+      if (!std::isfinite(logDensityGenerator)) return SpecFunc::LowestScalar;
       return std::log(normalizationFactor_) + logDensityGenerator;
     }
     break;
@@ -373,7 +373,7 @@ Scalar EllipticalDistribution::computeLogPDF(const Point & point) const
       }
       const Scalar betaSquare = iLx * iLx + iLy * iLy + iLz * iLz;
       const Scalar logDensityGenerator = computeLogDensityGenerator(betaSquare);
-      if (!SpecFunc::IsNormal(logDensityGenerator)) return SpecFunc::LowestScalar;
+      if (!std::isfinite(logDensityGenerator)) return SpecFunc::LowestScalar;
       return std::log(normalizationFactor_) + logDensityGenerator;
     }
     break;
@@ -381,7 +381,7 @@ Scalar EllipticalDistribution::computeLogPDF(const Point & point) const
       const Point iLx(inverseCholesky_ * (point - mean_));
       const Scalar betaSquare = iLx.normSquare();
       const Scalar logDensityGenerator = computeLogDensityGenerator(betaSquare);
-      if (!SpecFunc::IsNormal(logDensityGenerator)) return SpecFunc::LowestScalar;
+      if (!std::isfinite(logDensityGenerator)) return SpecFunc::LowestScalar;
       return std::log(normalizationFactor_) + logDensityGenerator;
   }
 }
@@ -486,7 +486,7 @@ void EllipticalDistribution::update()
   {
     // Try to compute the Cholesky factor of the shape matrix
     TriangularMatrix cholesky(getCholesky());
-    inverseCholesky_ = cholesky.solveLinearSystem(IdentityMatrix(dimension)).getImplementation();
+    inverseCholesky_ = cholesky.inverse().getImplementation();
     normalizationFactor_ = 1.0;
     for (UnsignedInteger i = 0; i < dimension; ++i) normalizationFactor_ /= cholesky(i, i);
   } // dimension > 1
@@ -585,7 +585,7 @@ void EllipticalDistribution::setR(const CorrelationMatrix & R)
     for (UnsignedInteger j = 0; j <= i; ++j)
       shape(i, j) *= sigma_[i] * sigma_[j];
   TriangularMatrix cholesky(shape.computeRegularizedCholesky());
-  inverseCholesky_ = cholesky.solveLinearSystem(IdentityMatrix(dimension)).getImplementation();
+  inverseCholesky_ = cholesky.inverse().getImplementation();
   R_ = R;
   normalizationFactor_ = 1.0;
   for (UnsignedInteger i = 0; i < dimension; ++ i)
@@ -738,7 +738,7 @@ void EllipticalDistribution::setParametersCollection(const PointCollection & par
   setDimension(dimension);
   mean_ = Point(dimension);
   sigma_ = Point(dimension);
-  R_ = CorrelationMatrix(dimension);
+  CorrelationMatrix R(dimension);
   if (dimension == 1)
   {
     mean_[0] = parametersCollection[0][0];
@@ -758,11 +758,11 @@ void EllipticalDistribution::setParametersCollection(const PointCollection & par
     {
       for (UnsignedInteger j = 0; j < i; ++j)
       {
-        R_(i, j) = parametersCollection[size - 1][parameterIndex];
+        R(i, j) = parametersCollection[size - 1][parameterIndex];
         ++parameterIndex;
       }
     }
-    if ( !R_.isPositiveDefinite()) throw InvalidArgumentException(HERE) << "The correlation matrix must be definite positive R=" << R_;
+    setR(R);
   }
   update();
   computeRange();
@@ -818,8 +818,7 @@ void EllipticalDistribution::setParameter(const Point & parameters)
         ++ index;
       }
     }
-    if (!R.isPositiveDefinite())
-      throw InvalidArgumentException(HERE) << "The correlation matrix must be definite positive R=" << R;
+    setR(R);
   }
   // commit all changes at once
   mean_ = mean;
