@@ -2,7 +2,7 @@
 /**
  *  @brief The class that implements all random vectors
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -27,9 +27,6 @@
 #include "openturns/Domain.hxx"
 #include "openturns/Less.hxx"
 #include "openturns/Greater.hxx"
-#ifdef OPENTURNS_HAVE_ANALYTICAL_PARSER
-#include "openturns/SymbolicFunction.hxx"
-#endif
 #include "openturns/ComposedFunction.hxx"
 #include "openturns/IntersectionEvent.hxx"
 #include "openturns/UnionEvent.hxx"
