@@ -2,7 +2,7 @@
 /**
  *  @brief The test file of FORM class
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -24,18 +24,6 @@
 using namespace OT;
 using namespace OT::Test;
 
-String printPoint(const Point & point, const UnsignedInteger digits)
-{
-  OSS oss;
-  oss << "[";
-  Scalar eps = pow(0.1, 1.0 * digits);
-  for (UnsignedInteger i = 0; i < point.getDimension(); i++)
-  {
-    oss << std::fixed << std::setprecision(digits) << (i == 0 ? "" : ",") << Bulk<double>((std::abs(point[i]) < eps) ? std::abs(point[i]) : point[i]);
-  }
-  oss << "]";
-  return oss;
-}
 
 int main(int, char *[])
 {
@@ -86,6 +74,7 @@ int main(int, char *[])
 
     /* We create a NearestPoint algorithm */
     Cobyla myCobyla;
+    myCobyla.setStartingPoint(mean);
     myCobyla.setMaximumCallsNumber(200);
     myCobyla.setMaximumAbsoluteError(1.0e-10);
     myCobyla.setMaximumRelativeError(1.0e-10);
@@ -97,7 +86,7 @@ int main(int, char *[])
     /* The first parameter is an OptimizationAlgorithm */
     /* The second parameter is an event */
     /* The third parameter is a starting point for the design point research */
-    FORM myAlgo(myCobyla, myEvent, mean);
+    FORM myAlgo(myCobyla, myEvent);
 
     fullprint << "FORM=" << myAlgo << std::endl;
 
@@ -106,9 +95,8 @@ int main(int, char *[])
 
     /* Stream out the result */
     FORMResult result(myAlgo.getResult());
-    UnsignedInteger digits = 5;
-    fullprint << "importance factors=" << printPoint(result.getImportanceFactors(), digits) << std::endl;
-    fullprint << "importance factors (classical)=" << printPoint(result.getImportanceFactors(AnalyticalResult::CLASSICAL), digits) << std::endl;
+    fullprint << "importance factors=" << result.getImportanceFactors() << std::endl;
+    fullprint << "importance factors (classical)=" << result.getImportanceFactors(AnalyticalResult::CLASSICAL) << std::endl;
 
     /* Graph 1 : Importance Factors graph */
     result.drawImportanceFactors();
