@@ -2,7 +2,7 @@
 /**
  *  @brief The test file of FunctionalChaosAlgorithm class
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -20,55 +20,31 @@
  */
 #include "openturns/OT.hxx"
 #include "openturns/OTtestcode.hxx"
+#include "openturns/GSobolUseCase.hxx"
 
 using namespace OT;
 using namespace OT::Test;
 
-Scalar sobol(const Indices & indices,
-             const Point & a)
-{
-  Scalar value = 1.0;
-  for (UnsignedInteger i = 0; i < indices.getSize(); ++i)
-  {
-    value *= 1.0 / (3.0 * pow(1.0 + a[indices[i]], 2.0));
-  }
-  return value;
-}
-
 int main(int, char *[])
 {
   TESTPREAMBLE;
   OStream fullprint(std::cout);
-  setRandomGenerator();
 
   try
   {
 
     // Problem parameters
     UnsignedInteger dimension = 5;
-
-    // Reference analytical values
-    Scalar meanTh = 1.0;
-    Scalar covTh = 1.0;
     Point a(dimension);
-    // Create the gSobol function
-    Description inputVariables(dimension);
-    Description formula(1);
-    formula[0] = "1.0";
     for (UnsignedInteger i = 0; i < dimension; ++i)
     {
       a[i] = 0.5 * i;
-      covTh *= 1.0 + 1.0 / (3.0 * pow(1.0 + a[i], 2.0));
-      inputVariables[i] = (OSS() << "xi" << i);
-      formula[0] = (OSS() << formula[0] << " * ((abs(4.0 * xi" << i << " - 2.0) + " << a[i] << ") / (1.0 + " << a[i] << "))");
     }
-    --covTh;
-
-    SymbolicFunction model(inputVariables, formula);
-
-    // Create the input distribution
-    Collection<Distribution> marginals(dimension, Uniform(0.0, 1.0));
-    ComposedDistribution distribution(marginals);
+    GSobolUseCase gsobol(dimension, a);
+    Function model(gsobol.getModel());
+    Scalar meanTh = gsobol.getMean();
+    Scalar covTh = gsobol.getVariance();
+    JointDistribution distribution(gsobol.getInputDistribution());
 
     // Create the orthogonal basis
     Collection<OrthogonalUniVariatePolynomialFamily> polynomialCollection(dimension);
@@ -87,7 +63,7 @@ int main(int, char *[])
     UnsignedInteger indexMax = enumerateFunction.getStrataCumulatedCardinal(degree);
     UnsignedInteger basisDimension = enumerateFunction.getStrataCumulatedCardinal(degree / 2);
     Scalar threshold = 1.0e-6;
-    listAdaptiveStrategy.add(CleaningStrategy(productBasis, indexMax, basisDimension, threshold, false));
+    listAdaptiveStrategy.add(CleaningStrategy(productBasis, indexMax, basisDimension, threshold));
     // Second, the most used (and most basic!) strategy
     listAdaptiveStrategy.add(FixedStrategy(productBasis, enumerateFunction.getStrataCumulatedCardinal(degree)));
     //
@@ -128,10 +104,6 @@ int main(int, char *[])
           fullprint << "//////////////////////////////////////////////////////////////////////" << std::endl;
           fullprint << algo.getAdaptiveStrategy() << std::endl;
           fullprint << algo.getProjectionStrategy() << std::endl;
-          Point residuals(result.getResiduals());
-          fullprint << "residuals=" << std::fixed << std::setprecision(5) << residuals << std::endl;
-          Point relativeErrors(result.getRelativeErrors());
-          fullprint << "relative errors=" << std::fixed << std::setprecision(5) << relativeErrors << std::endl;
 
           // Post-process the results
           FunctionalChaosRandomVector vector(result);
@@ -145,7 +117,7 @@ int main(int, char *[])
           {
             indices[0] = i;
             Scalar value = sensitivity.getSobolIndex(i);
-            fullprint << "Sobol index " << i << " = " << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << std::abs(value - sobol(indices, a) / covTh) << std::endl;
+            fullprint << "Sobol index " << i << " = " << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << std::abs(value - gsobol.computeSobolIndex(indices)) << std::endl;
           }
           indices = Indices(2);
           UnsignedInteger k = 0;
@@ -156,14 +128,14 @@ int main(int, char *[])
             {
               indices[1] = j;
               Scalar value = sensitivity.getSobolIndex(indices);
-              fullprint << "Sobol index " << indices << " =" << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << std::abs(value - sobol(indices, a) / covTh) << std::endl;
+              fullprint << "Sobol index " << indices << " =" << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << std::abs(value - gsobol.computeSobolIndex(indices)) << std::endl;
               k = k + 1;
             }
           }
           indices = Indices(3);
           indices.fill();
           Scalar value = sensitivity.getSobolIndex(indices);
-          fullprint << "Sobol index " << indices << " =" << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << std::abs(value - sobol(indices, a) / covTh) << std::endl;
+          fullprint << "Sobol index " << indices << " =" << std::fixed << std::setprecision(5) << value << " absolute error=" << std::scientific << std::setprecision(1) << std::abs(value - gsobol.computeSobolIndex(indices)) << std::endl;
 
         }
       }
