@@ -2,7 +2,7 @@
 /**
  *  @brief The test file of class LeastSquaresMetaModelSelection for standard methods
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -99,8 +99,6 @@ int main(int, char *[])
 
     FunctionalChaosResult result(algo.getResult());
     fullprint << "coeffs = " << result.getCoefficients() << std::endl;
-    fullprint << "residuals = " << result.getResiduals() << std::endl;
-    fullprint << "relative errors = " << result.getRelativeErrors() << std::endl;
   }
 
 
