@@ -2,7 +2,7 @@
 /**
  *  @brief The test file of FunctionalChaosAlgoritm class
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -29,7 +29,6 @@ int main(int, char *[])
 {
   TESTPREAMBLE;
   OStream fullprint(std::cout);
-  setRandomGenerator();
 
   try
   {
@@ -106,10 +105,6 @@ int main(int, char *[])
           fullprint << "//////////////////////////////////////////////////////////////////////" << std::endl;
           fullprint << algo.getAdaptiveStrategy() << std::endl;
           fullprint << algo.getProjectionStrategy() << std::endl;
-          Point residuals(result.getResiduals());
-          fullprint << "residuals=" << std::fixed << std::setprecision(5) << residuals << std::endl;
-          Point relativeErrors(result.getRelativeErrors());
-          fullprint << "relative errors=" << std::fixed << std::setprecision(5) << relativeErrors << std::endl;
           Bool isLeastSquaresPCE = result.isLeastSquares();
           Bool isLeastSquaresProjection = projectionStrategy.isLeastSquares();
           assert_equal(isLeastSquaresProjection, isLeastSquaresPCE);
