@@ -2,7 +2,7 @@
 /**
  *  @brief The test file of class GalambosCopula for standard methods
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -29,7 +29,6 @@ int main(int, char *[])
   TESTPREAMBLE;
   Log::Show(Log::NONE);
   OStream fullprint(std::cout);
-  setRandomGenerator();
 
   try
   {
@@ -82,7 +81,7 @@ int main(int, char *[])
     fullprint << "Survival      =" << Survival << std::endl;
     fullprint << "Survival (ref)=" << copula.computeSurvivalFunction(point) << std::endl;
     Point InverseSurvival = copula.computeInverseSurvivalFunction(0.95);
-    fullprint << "Inverse survival=" << InverseSurvival << std::endl;
+    assert_almost_equal(InverseSurvival, {0.025832, 0.025832}, 1e-4, 0.0);
     fullprint << "Survival(inverse survival)=" << copula.computeSurvivalFunction(InverseSurvival) << std::endl;
     // Get 50% quantile
     Point quantile = copula.computeQuantile( 0.5 );
