@@ -2,7 +2,7 @@
 /**
  *  @brief The test file of class GaussKronrod
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -39,12 +39,12 @@ public:
     // Nothing to do
   }
 
-  UniVariateSymbolicFunction * clone() const
+  UniVariateSymbolicFunction * clone() const override
   {
     return new UniVariateSymbolicFunction(*this);
   }
 
-  Scalar operator()(const Scalar x) const
+  Scalar operator()(const Scalar x) const override
   {
     return f_(Point(1, x))[0];
   }
@@ -60,7 +60,6 @@ int main(int, char *[])
 {
   TESTPREAMBLE;
   OStream fullprint(std::cout);
-  setRandomGenerator();
 
   try
   {
