@@ -72,7 +72,7 @@ int main(int, char *[])
       Sample dataOut(myFunc(data));
       LinearLeastSquares myLeastSquares(data, dataOut);
       myLeastSquares.run();
-      Function responseSurface(myLeastSquares.getMetaModel());
+      Function responseSurface(myLeastSquares.getResult().getMetaModel());
       fullprint << "myLeastSquares=" << myLeastSquares << std::endl;
       fullprint << "responseSurface=" << responseSurface << std::endl;
       Point in(myFunc.getInputDimension(), 0.1);
