@@ -2,7 +2,7 @@
 /**
  *  @brief The test file of class PersistentObject for standard methods
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -29,7 +29,7 @@ class TestObject : public PersistentObject
 public:
   TestObject() : PersistentObject() {}
   virtual ~TestObject() {}
-  virtual TestObject * clone() const
+  TestObject * clone() const override
   {
     return new TestObject(*this);
   }
