@@ -2,7 +2,7 @@
 /**
  *  @brief The test file of PostAnalyticalImportanceSampling class
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -28,7 +28,6 @@ int main(int, char *[])
 {
   TESTPREAMBLE;
   OStream fullprint(std::cout);
-  setRandomGenerator();
 
   try
   {
@@ -67,7 +66,8 @@ int main(int, char *[])
     /* The third parameter is a starting point for the design point research */
     Cobyla myCobyla;
     myCobyla.setMaximumCallsNumber(400);
-    FORM myAlgo(myCobyla, myEvent, mean);
+    myCobyla.setStartingPoint(mean);
+    FORM myAlgo(myCobyla, myEvent);
 
     /* Perform the simulation */
     myAlgo.run();
