@@ -2,7 +2,7 @@
 /**
  *  @brief The test file of class PosteriorDistribution for standard methods
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,6 +18,7 @@
  *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
+//#include <iomanip>
 #include "openturns/OT.hxx"
 #include "openturns/OTtestcode.hxx"
 
@@ -28,13 +29,14 @@ int main(int, char *[])
 {
   TESTPREAMBLE;
   OStream fullprint(std::cout);
-  setRandomGenerator();
 
   try
   {
     // Test basic functionnalities
     //checkClassWithClassName<TestObject>();
 
+    ResourceMap::SetAsUnsignedInteger("CompoundDistribution-MarginalIntegrationNodesNumber", 24);
+
     UnsignedInteger observationsSize = 5;
     // Create a collection of distribution
     Normal conditionedDistribution;
@@ -44,38 +46,39 @@ int main(int, char *[])
       Collection< Distribution > atoms;
       atoms.add(Uniform(0.0, 1.0));
       atoms.add(Uniform(1.0, 2.0));
-      conditioningDistributionCollection.add(ComposedDistribution(atoms));
+      conditioningDistributionCollection.add(JointDistribution(atoms));
     }
     // Second conditioning distribution: discrete/continuous
     {
       Collection< Distribution > atoms;
       atoms.add(Binomial(3, 0.5));
       atoms.add(Uniform(1.0, 2.0));
-//       conditioningDistributionCollection.add(ComposedDistribution(atoms));
+//       conditioningDistributionCollection.add(JointDistribution(atoms));
     }
     // Third conditioning distribution: dirac/continuous
     {
       Collection< Distribution > atoms;
       atoms.add(Dirac(0.0));
       atoms.add(Uniform(1.0, 2.0));
-      conditioningDistributionCollection.add(ComposedDistribution(atoms));
+//      conditioningDistributionCollection.add(JointDistribution(atoms));
     }
     for (UnsignedInteger i = 0; i < conditioningDistributionCollection.getSize(); ++i)
     {
+      fullprint << "\n==========================================================================================\n" << std::endl;
       fullprint << "conditioning distribution=" << conditioningDistributionCollection[i].__str__() << std::endl;
       Distribution observationsDistribution(conditionedDistribution);
       observationsDistribution.setParameter(conditioningDistributionCollection[i].getMean());
       Sample observations(observationsDistribution.getSample(observationsSize));
-      PosteriorDistribution distribution(ConditionalDistribution(conditionedDistribution, conditioningDistributionCollection[i]), observations);
+      PosteriorDistribution distribution(CompoundDistribution(conditionedDistribution, conditioningDistributionCollection[i]), observations);
       UnsignedInteger dim = distribution.getDimension();
       fullprint << "Distribution " << distribution << std::endl;
       std::cout << "Distribution " << distribution << std::endl;
-      fullprint << "range=" << distribution.getRange() << std::endl;
-      // fullprint << "entropy=" << distribution.computeEntropy() << std::endl;
-      // fullprint << "entropy (MC)=" << -distribution.computeLogPDF(distribution.getSample(1000000)).computeMean()[0] << std::endl;
+      fullprint << "range=" << distribution.getRange().__str__() << std::endl;
+      fullprint << "entropy=" << std::setprecision(4) << distribution.computeEntropy() << std::endl;
+      fullprint << "entropy (MC)=" << std::setprecision(4) << -distribution.computeLogPDF(distribution.getSample(10000)).computeMean()[0] << std::endl;
       Point mean(distribution.getMean());
-      fullprint << "Mean " << mean << std::endl;
-      fullprint << "Covariance " << distribution.getCovariance() << std::endl;
+      fullprint << "Mean " << mean.__str__() << std::endl;
+      fullprint << "Covariance " << distribution.getCovariance().__str__() << std::endl;
       // Is this distribution an elliptical distribution?
       fullprint << "Elliptical distribution= " << (distribution.isElliptical() ? "true" : "false") << std::endl;
 
@@ -85,44 +88,25 @@ int main(int, char *[])
       // Has this distribution an independent copula?
       fullprint << "Independent copula= " << (distribution.hasIndependentCopula() ? "true" : "false") << std::endl;
 
-      // Test for realization of distribution
-      Point oneRealization = distribution.getRealization();
-      fullprint << "oneRealization=" << oneRealization << std::endl;
-
-      // Test for sampling
-      UnsignedInteger size = 10;
-      Sample oneSample = distribution.getSample(size);
-      fullprint << "oneSample=" << oneSample << std::endl;
-
-      // Test for sampling
-//       size = 10000;
-//       Sample anotherSample = distribution.getSample(size);
-//       fullprint << "anotherSample mean=" << anotherSample.computeMean() << std::endl;
-//       fullprint << "anotherSample covariance=" << anotherSample.computeCovariance() << std::endl;
-
-      // Define a point
-      Point zero(dim, 0.0);
-
-      // Show PDF and CDF of zero point
-      Scalar zeroPDF = distribution.computePDF(zero);
-      Scalar zeroCDF = distribution.computeCDF(zero);
-      fullprint << "Zero point= " << zero
-                << " pdf=" << zeroPDF
-                << " cdf=" << zeroCDF
+      // Show PDF and CDF of mean point
+      Scalar meanPDF = distribution.computePDF(mean);
+      Scalar meanCDF = distribution.computeCDF(mean);
+      fullprint << "Mean point= " << mean
+                << " pdf=" << meanPDF
+                << " cdf=" << meanCDF
                 << std::endl;
       // Get 95% quantile
       Point quantile = distribution.computeQuantile(0.95);
-      fullprint << "Quantile=" << quantile << std::endl;
+      fullprint << "Quantile=" << quantile.__str__() << std::endl;
       fullprint << "CDF(quantile)=" << distribution.computeCDF(quantile) << std::endl;
       // Extract the marginals
       for (UnsignedInteger j = 0; j < dim; ++ j)
       {
         Distribution margin(distribution.getMarginal(j));
-        fullprint << "margin=" << margin << std::endl;
-        fullprint << "margin PDF=" << margin.computePDF(Point(1)) << std::endl;
-        fullprint << "margin CDF=" << margin.computeCDF(Point(1)) << std::endl;
+        fullprint << "margin=" << margin.__str__() << std::endl;
+        fullprint << "margin PDF=" << margin.computePDF(mean[j]) << std::endl;
+        fullprint << "margin CDF=" << margin.computeCDF(mean[j]) << std::endl;
         fullprint << "margin quantile=" << margin.computeQuantile(0.95) << std::endl;
-        fullprint << "margin realization=" << margin.getRealization() << std::endl;
       }
     }
   }
