@@ -2,7 +2,7 @@
 /**
  *  @brief The test file of class ProductDistribution for standard methods
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -36,7 +36,6 @@ int main(int, char *[])
 {
   TESTPREAMBLE;
   OStream fullprint(std::cout);
-  setRandomGenerator();
 
   try
   {
@@ -101,6 +100,9 @@ int main(int, char *[])
     fullprint << "left=" << distribution.getLeft() << std::endl;
     fullprint << "right=" << distribution.getRight() << std::endl;
 
+    Interval interval(-1.0, 2.0);
+    assert_almost_equal(distribution.computeProbability(interval), 0.641, 0.01, 0.0);
+
     // For ticket 957
     {
       Distribution distribution2 = Uniform() * Uniform() * Uniform();
