@@ -2,7 +2,7 @@
 /**
  *  @brief The test file of class QuadraticLeastSquares for standard methods
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -72,7 +72,7 @@ int main(int, char *[])
       Sample dataOut(myFunc(data));
       QuadraticLeastSquares myLeastSquares(data, dataOut);
       myLeastSquares.run();
-      Function responseSurface(myLeastSquares.getMetaModel());
+      Function responseSurface(myLeastSquares.getResult().getMetaModel());
       fullprint << "myLeastSquares=" << myLeastSquares << std::endl;
       fullprint << "responseSurface=" << responseSurface << std::endl;
       Point in(myFunc.getInputDimension(), 0.2);
