@@ -2,7 +2,7 @@
 /**
  *  @brief The test file of class Function for analytical
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -28,7 +28,6 @@ int main(int, char *[])
 {
   TESTPREAMBLE;
   OStream fullprint(std::cout);
-  setRandomGenerator();
 
   try
   {
@@ -344,7 +343,7 @@ int main(int, char *[])
       f.getEvaluation().getImplementation()->setCheckOutput(false);
       fullprint << "Trying to evaluate f=" << f.__str__() << " at x=-1.0" << std::endl;
       Point x(1, -1.0);
-      fullprint << "Result is normal? " << SpecFunc::IsNormal(f(x)[0]) << std::endl;
+      fullprint << "Result is normal? " << std::isfinite(f(x)[0]) << std::endl;
     }
   }
   catch (TestFailed & ex)
