@@ -2,7 +2,7 @@
 /**
  *  @brief The test file of class UniVariatePolynomial for standard methods
  *
- *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2025 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -82,6 +82,11 @@ int main(int, char *[])
     // Multiplication of two polynomials using FFT
     fullprint << "P1*P2=" << P1 * P2 << std::endl;
 
+    // Evaluation over a sample of dimension 1
+    Sample x = Sample::BuildFromPoint({1.0, 2.0, 3.0, 4.0, 5.0});
+    Sample y = P2(x);
+    Sample yRef = Sample::BuildFromPoint({-0.2, -0.3, -2.8, -7.7, -15.0});
+    assert_almost_equal(y, yRef);
   }
   catch (TestFailed & ex)
   {
