@@ -21,13 +21,11 @@ Parameters to calibrate and observations
 The vector of parameters to calibrate is:
 
 .. math::
-
    \theta = (R,C,\gamma).
 
 We consider a data set where the number of observations is equal to:
 
 .. math::
-
    n = 10.
 
 
@@ -46,10 +44,9 @@ variables and observed output variables.
 # %%
 import openturns as ot
 import openturns.viewer as otv
-from matplotlib import pylab as plt
+from matplotlib import pyplot as plt
 from openturns.usecases import chaboche_model
 
-ot.Log.Show(ot.Log.NONE)
 
 # %%
 # Define the observations
@@ -409,6 +406,9 @@ def plotDistributionGridPDF(distribution):
             else:
                 distributionJI = distribution.getMarginal([j, i])
                 graph = distributionJI.drawPDF()
+                contour = graph.getDrawable(0).getImplementation()
+                contour.setColorBarPosition("")  # Hide color bar
+                graph.setDrawable(0, contour)
             graph.setLegends([""])
             graph.setTitle("")
             if i < dimension - 1:
@@ -891,9 +891,4 @@ plt.subplots_adjust(wspace=plot_space, hspace=plot_space)
 # parameter are close to each other, but not superimposed: the observations
 # significantly brought information to the variable :math:`\gamma` during
 # the calibration.
-
 otv.View.ShowAll()
-
-# %%
-# Reset default settings
-ot.ResourceMap.Reload()
