@@ -48,13 +48,12 @@ The observations that we use in this study are simulated with the script
 # couple made of the flowrate and the corresponding river height.
 
 from openturns.usecases import flood_model
-from matplotlib import pylab as plt
+from matplotlib import pyplot as plt
 import openturns.viewer as otv
 import numpy as np
 import openturns as ot
 
 ot.ResourceMap.SetAsUnsignedInteger("Normal-SmallDimension", 1)
-ot.Log.Show(ot.Log.NONE)
 
 # %%
 # Define the observations
@@ -203,7 +202,7 @@ graph.setLegendPosition("upper left")
 view = otv.View(graph)
 
 # %%
-# Wee see that the model does not fit to the data.
+# We see that the model does not fit to the data.
 # The goal of calibration is to find which parameter best fit to the
 # observations.
 
@@ -740,8 +739,5 @@ view = otv.View(
 )
 plt.subplots_adjust(wspace=1.0, hspace=0.5)
 
-otv.View.ShowAll()
-
 # %%
-# Reset default settings
-ot.ResourceMap.Reload()
+otv.View.ShowAll()
