@@ -9,7 +9,6 @@ Estimate a GPD on the Dow Jones Index data
 # Readers should refer to [coles2001]_ example 1.8 to get more details.
 import math as m
 import openturns as ot
-import openturns.experimental as otexp
 import openturns.viewer as otv
 from openturns.usecases import coles
 import pandas as pd
@@ -135,7 +134,7 @@ for i in range(2):  # exclude u parameter (fixed)
 # even if the other plots appear to be reasonable. This is due to the fact that
 # the excesses can not be considered as independent: the transformed series
 # :math:`\tilde{X}_i` has a rich structure of temporal dependence.
-validation = otexp.GeneralizedParetoValidation(result_LL, scalTransfDataDJ)
+validation = ot.GeneralizedParetoValidation(result_LL, scalTransfDataDJ)
 graph = validation.drawDiagnosticPlot()
 view = otv.View(graph)
 
@@ -158,7 +157,7 @@ view = otv.View(graph)
 # cluster maximum series.
 # We denote by :math:`n_c` the number of clusters and
 # by :math:`n_u` the number of exceedances above :math:`u`.
-part = otexp.SamplePartition(scalTransfDataDJ)
+part = ot.SamplePartition(scalTransfDataDJ)
 r = 3
 peaks, clusters = part.getPeakOverThreshold(u, r)
 nc = len(peaks)
@@ -201,7 +200,7 @@ print(f"x100={xm_100.getMean()} ({xm_100.getStandardDeviation()}) theta={theta:.
 # We can see the fitted model works well. However, the large return level confidence intervals
 # obtained for extreme return levels makes it difficult to make reliable
 # predictions with any degree of certainty.
-validation = otexp.GeneralizedParetoValidation(result_LL, peaks)
+validation = ot.GeneralizedParetoValidation(result_LL, peaks)
 grid = validation.drawDiagnosticPlot()
 rlPlot = grid.getGraph(1, 0)
 rlPlot.setTitle(rlPlot.getTitle() + f" (u={u} r={r})")
