@@ -56,12 +56,8 @@ Estimate a scalar ARMA process
 # %%
 import openturns as ot
 
-ot.RandomGenerator.SetSeed(0)
-ot.Log.Show(ot.Log.NONE)
-
 # %%
 # Create an ARMA process
-
 tMin = 0.0
 n = 1000
 timeStep = 0.1
