@@ -2,6 +2,7 @@
 Visualize sensitivity
 =====================
 """
+
 # %%
 # The parallel coordinates graph enables to visualize all the combinations of the input
 # variables which lead to a specific range of the output variable. It is a very simple and cheap tool to visualize sensitivity from the raw data.
@@ -29,10 +30,7 @@ Visualize sensitivity
 # %%
 from openturns.usecases.ishigami_function import IshigamiModel
 import openturns as ot
-import openturns.viewer as viewer
-from matplotlib import pylab as plt
-
-ot.Log.Show(ot.Log.NONE)
+import openturns.viewer as otv
 
 # %%
 # We load the :ref:`Ishigami model<use-case-ishigami>` from the `usecases` module :
@@ -40,14 +38,14 @@ im = IshigamiModel()
 # the Ishigami function
 model = im.model
 # the input distribution
-inputDist = im.distributionX
+inputDist = im.distribution
 
 # %%
 # We create a random vector from out input distribution :
 inputVector = ot.RandomVector(inputDist)
 
 # %%
-# And we create the output random vector Y = model(X) :
+# And we create the output random vector :math:`Y = model(X)` :
 output = ot.CompositeRandomVector(model, inputVector)
 
 # %%
@@ -61,7 +59,7 @@ Y = model(X)
 Y.setDescription("Y")
 
 # %%
-# We display the minimum, maximum and value of the 90% quantile of `Y` :
+# We display the minimum, maximum and value of the 90% quantile of :math:`Y` :
 print(Y.getMin(), Y.getMax(), Y.computeQuantilePerComponent(0.9))
 
 # %%
@@ -84,11 +82,11 @@ quantileScale = False
 graph = ot.VisualTest.DrawParallelCoordinates(
     X, Y, minValue, maxValue, "red", quantileScale
 )
-graph.setLegendPosition("bottomright")
-view = viewer.View(graph)
+graph.setLegendPosition("lower right")
+view = otv.View(graph)
 
 # %%
-# Here we would like to conclude that the highest values of `Y` are obtained from a specific input as the highlighted lines clearly follow one only path.
+# Here we would like to conclude that the highest values of :math:`Y` are obtained from a specific input as the highlighted lines clearly follow one only path.
 # However, this approach is too naive and specific to the input sample. Indeed,
 # if we set the lower bound to 80% of the maximum :
 
@@ -99,8 +97,8 @@ quantileScale = False
 graph = ot.VisualTest.DrawParallelCoordinates(
     X, Y, minValue, maxValue, "red", quantileScale
 )
-graph.setLegendPosition("bottomright")
-view = viewer.View(graph)
+graph.setLegendPosition("lower right")
+view = otv.View(graph)
 
 # %%
 # A new path is then available ! That is the reason why we chose a quantile based ranking as the value based parallel plot involves a bit of guessing.
@@ -111,7 +109,7 @@ view = viewer.View(graph)
 # ---------------------------------------------------
 #
 # In this paragraph we use quantile based bounds. We are still interested in
-# the highest values of `Y` more specifically the 95% quantile :
+# the highest values of :math:`Y` more specifically the 95% quantile :
 
 # %%
 minValue = 0.95
@@ -121,8 +119,8 @@ quantileScale = True
 graph = ot.VisualTest.DrawParallelCoordinates(
     X, Y, minValue, maxValue, "red", quantileScale
 )
-graph.setLegendPosition("bottomright")
-view = viewer.View(graph)
+graph.setLegendPosition("lower right")
+view = otv.View(graph)
 
 # %%
 # The parallel coordinates plot obtained is helpful : we see peculiar values for each marginal.
@@ -168,8 +166,8 @@ quantileScale = True
 graph = ot.VisualTest.DrawParallelCoordinates(
     X, Y, minValue, maxValue, "red", quantileScale
 )
-graph.setLegendPosition("topright")
-view = viewer.View(graph)
+graph.setLegendPosition("upper right")
+view = otv.View(graph)
 
 # %%
 # We cannot extract any useful information from this parallel plot.
@@ -180,4 +178,4 @@ view = viewer.View(graph)
 
 # %%
 # Display figures
-plt.show()
+otv.View.ShowAll()
