@@ -8,9 +8,7 @@ Visualize pairs
 
 # %%
 import openturns as ot
-import openturns.viewer as viewer
-from matplotlib import pyplot as plt
-
+import openturns.viewer as otv
 
 # %%
 # Create data to visualize
@@ -23,5 +21,8 @@ sample = distribution.getSample(200)
 # %%
 # Create cloud pairs graphs
 graph = ot.VisualTest.DrawPairs(sample)
-view = viewer.View(graph)
-plt.show()
+view = otv.View(graph)
+
+# %%
+# Display all graphs
+otv.View.ShowAll()
