@@ -69,7 +69,7 @@ Draw a survival function
 
 # %%
 import openturns as ot
-import openturns.viewer as viewer
+import openturns.viewer as otv
 
 
 # %%
@@ -102,12 +102,12 @@ p1 + p2
 # %%
 graph = distribution.drawCDF()
 graph.setTitle("CDF of a distribution")
-view = viewer.View(graph)
+view = otv.View(graph)
 
 # %%
 graph = distribution.drawSurvivalFunction()
 graph.setTitle("Survival function of a distribution")
-view = viewer.View(graph)
+view = otv.View(graph)
 
 # %%
 # In order to get finite bounds for the next graphics, we compute the `xmin`
@@ -129,7 +129,7 @@ npoints = 50
 logScaleX = True
 graph = distribution.drawSurvivalFunction(xmin, xmax, npoints, logScaleX)
 graph.setTitle("Survival function of a distribution where X axis is in log scale")
-view = viewer.View(graph)
+view = otv.View(graph)
 # graph
 
 # %%
@@ -143,7 +143,7 @@ graph.setLogScale(ot.GraphImplementation.LOGXY)
 graph.setTitle(
     "Survival function of a distribution where X and Y axes are in log scale"
 )
-view = viewer.View(graph)
+view = otv.View(graph)
 # graph
 
 # %%
@@ -190,13 +190,13 @@ p1 + p2
 userdefined = ot.UserDefined(sample)
 graph = userdefined.drawCDF()
 graph.setTitle("CDF of a sample")
-view = viewer.View(graph)
+view = otv.View(graph)
 # graph
 
 # %%
 graph = userdefined.drawSurvivalFunction()
 graph.setTitle("Empirical survival function of a sample")
-view = viewer.View(graph)
+view = otv.View(graph)
 # graph
 
 # %%
@@ -209,7 +209,7 @@ pointNumber = sample.getSize()
 logScaleX = True
 graph = userdefined.drawSurvivalFunction(xmin, xmax, pointNumber, logScaleX)
 graph.setTitle("Empirical survival function of a sample; X axis in log-scale")
-view = viewer.View(graph)
+view = otv.View(graph)
 # graph
 
 # %%
@@ -225,7 +225,7 @@ logScaleX = True
 graph = userdefined.drawSurvivalFunction(xmin, xmax, pointNumber, logScaleX)
 graph.setLogScale(ot.GraphImplementation.LOGXY)
 graph.setTitle("Empirical survival function of a sample; X and Y axes in log-scale")
-view = viewer.View(graph)
+view = otv.View(graph)
 # graph
 
 # %%
@@ -248,7 +248,7 @@ graphDistribution.setLegends(["GPD"])
 graph.add(graphDistribution)
 graph.setLegendPosition("upper right")
 graph.setTitle("GPD against the sample - n=%d" % (sample.getSize()))
-view = viewer.View(graph)
+view = otv.View(graph)
 
 
 # %%
