@@ -8,10 +8,7 @@ Draw the empirical CDF
 
 # %%
 import openturns as ot
-import openturns.viewer as viewer
-from matplotlib import pylab as plt
-
-ot.Log.Show(ot.Log.NONE)
+import openturns.viewer as otv
 
 # %%
 # Then create a sample from a Gaussian distribution.
@@ -28,7 +25,7 @@ sample = normal.getSample(size)
 # %%
 distribution = ot.UserDefined(sample)
 graph = distribution.drawCDF()
-view = viewer.View(graph)
+view = otv.View(graph)
 
 # %%
 # If required, we can specify the interval that we want to draw.
@@ -38,5 +35,7 @@ view = viewer.View(graph)
 xmin = sample.getMin()[0] - 2.0
 xmax = sample.getMax()[0] + 2.0
 graph = ot.UserDefined(sample).drawCDF(xmin, xmax)
-view = viewer.View(graph)
-plt.show()
+view = otv.View(graph)
+
+# %%
+otv.View.ShowAll()
