@@ -8,9 +8,7 @@ Draw an histogram
 
 # %%
 import openturns as ot
-import openturns.viewer as viewer
-from matplotlib import pyplot as plt
-
+import openturns.viewer as otv
 
 # %%
 # Create data to visualize
@@ -21,5 +19,7 @@ sample = normal.getSample(size)
 # %%
 # Draw histogram
 graph = ot.HistogramFactory().build(sample).drawPDF()
-view = viewer.View(graph)
-plt.show()
+view = otv.View(graph)
+
+# %%
+otv.View.ShowAll()
