@@ -10,11 +10,11 @@ Kolmogorov-Smirnov : understand the statistics
 #
 # * We generate a sample from a Normal distribution.
 # * We create a uniform distribution and estimate its parameters from the sample.
-# * Compute the Kolmogorov-Smirnov statistic and plot it on top of the empirical cumulated distribution function.
+# * Compute the Kolmogorov-Smirnov statistic and plot it on top of the empirical cumulative distribution function.
 
 # %%
 import openturns as ot
-import openturns.viewer as viewer
+import openturns.viewer as otv
 
 
 # %%
@@ -125,7 +125,7 @@ print("D=", D, ", Index=", index, ", Obs.=", observation)
 
 # %%
 graph = drawKSDistance(sample, distribution, observation, D, distFactory)
-view = viewer.View(graph)
+view = otv.View(graph)
 
 
 # %%
