@@ -2,6 +2,7 @@
 Define a function with a field output: the viscous free fall example
 ====================================================================
 """
+
 # %%
 # In this example, we define a function which has a vector input and a field output.
 # This is why we use the :class:`~openturns.PythonPointToFieldFunction` class to create the associated function and propagate the uncertainties through it.
@@ -14,11 +15,9 @@ Define a function with a field output: the viscous free fall example
 
 # %%
 import openturns as ot
-import openturns.viewer as viewer
-from matplotlib import pylab as plt
+import openturns.viewer as otv
 from openturns.usecases import viscous_free_fall
 
-ot.Log.Show(ot.Log.NONE)
 
 # %%
 # Load the viscous free fall example.
@@ -49,15 +48,11 @@ graph = outputSample.drawMarginal(0)
 graph.setTitle("Viscous free fall: %d trajectories" % (size))
 graph.setXTitle(r"$t$")
 graph.setYTitle(r"$z$")
-view = viewer.View(graph)
-plt.show()
+view = otv.View(graph)
 
 # %%
 # We see that the object first moves up and then falls down.
 # Not all objects, however, achieve the same maximum altitude.
 # We see that some trajectories reach a higher maximum altitude than others.
 # Moreover, at the final time :math:`t_{max}`, one trajectory hits the ground: :math:`z(t_{max})=0` for this trajectory.
-
-# %%
-# Reset default settings
-ot.ResourceMap.Reload()
+otv.View.ShowAll()
