@@ -8,31 +8,31 @@ Iterated Functions System
 
 # %%
 import openturns as ot
-import openturns.viewer as viewer
-from matplotlib import pylab as plt
+import openturns.viewer as otv
+
+# sphinx_gallery_thumbnail_number = 4
 import math as m
 
-ot.Log.Show(ot.Log.NONE)
-
-
 # %%
 # **Tree traversal algorithm (the chaos game)**
 
 
-# %%
 def drawIFS(f_i, skip=100, iterations=1000, batch_size=1, name="IFS", color="blue"):
     # Any set of initial points should work in theory
     initialPoints = ot.Normal(2).getSample(batch_size)
     # Compute the contraction factor of each function
     all_r = [m.sqrt(abs(f[1].computeDeterminant())) for f in f_i]
     # Find the box counting dimension, ie the value s such that r_1^s+...+r_n^s-1=0
-    equation = "-1.0"
-    for r in all_r:
-        equation += "+" + str(r) + "^s"
+    equation = "-1.0+" + "+".join([str(r) + "^s" for r in all_r])
     dim = len(f_i)
-    s = ot.Brent().solve(
-        ot.SymbolicFunction("s", equation), 0.0, 0.0, -m.log(dim) / m.log(max(all_r))
-    )
+    fs = ot.SymbolicFunction("s", equation)
+    # tweak search bounds
+    xMin, xMax = 0.0, -m.log(dim) / m.log(max(all_r))
+    fMax = fs([xMax])[0]
+    eps = ot.SpecFunc.Precision**0.5
+    if abs(fMax) < eps:
+        xMax += eps
+    s = ot.Brent().solve(fs, 0.0, xMin, xMax)
     # Add a small perturbation to sample even the degenerated transforms
     probabilities = [r**s + 1e-2 for r in all_r]
     # Build the sampling distribution
@@ -92,7 +92,7 @@ graph, s = drawIFS(
     f_i, skip=100, iterations=100000, batch_size=1, name="Spiral", color="blue"
 )
 print("Box counting dimension=%.3f" % s)
-view = viewer.View(graph)
+view = otv.View(graph)
 
 # %%
 # Fern
@@ -105,7 +105,8 @@ graph, s = drawIFS(
     f_i, skip=100, iterations=100000, batch_size=1, name="Fern", color="green"
 )
 print("Box counting dimension=%.3f" % s)
-view = viewer.View(graph)
+# sphinx_gallery_thumbnail_number = 2
+view = otv.View(graph)
 
 # %%
 # Dragon
@@ -116,7 +117,7 @@ graph, s = drawIFS(
     f_i, skip=100, iterations=100000, batch_size=1, name="Dragon", color="red"
 )
 print("Box counting dimension=%.3f" % s)
-view = viewer.View(graph)
+view = otv.View(graph)
 
 # %%
 # Sierpinski triangle
@@ -133,7 +134,8 @@ graph, s = drawIFS(
     color="magenta",
 )
 print("Box counting dimension=%.3f" % s)
-view = viewer.View(graph)
-plt.show()
+view = otv.View(graph)
 
 # %%
+# Display all figures
+otv.View.ShowAll()
