@@ -31,8 +31,6 @@ import numpy as np
 
 palette = ot.Drawable.BuildTableauPalette(5)
 
-ot.RandomGenerator.SetSeed(0)
-
 
 # %%
 #
@@ -434,3 +432,7 @@ view = otv.View(graph)
 # most of the observations.
 # The confidence interval of the observations is much larger than the
 # C.I. of the mean, as expected from the statistical model.
+
+# %%
+# Display all figures
+otv.View.ShowAll()
