@@ -2,6 +2,7 @@
 Optimization with constraints
 =============================
 """
+
 # %%
 # In this example we are going to expose methods to solve a generic optimization problem in the form
 #
@@ -13,10 +14,8 @@ Optimization with constraints
 
 # %%
 import openturns as ot
-import openturns.viewer as viewer
-from matplotlib import pylab as plt
+import openturns.viewer as otv
 
-ot.Log.Show(ot.Log.NONE)
 
 # %%
 # define the objective function
@@ -56,5 +55,8 @@ print("x^=", result.getOptimalPoint())
 # %%
 # draw optimal value history
 graph = result.drawOptimalValueHistory()
-view = viewer.View(graph)
-plt.show()
+view = otv.View(graph)
+
+# %%
+# Display all figures
+otv.View.ShowAll()
