@@ -8,10 +8,7 @@ Optimization using NLopt
 
 # %%
 import openturns as ot
-import openturns.viewer as viewer
-from matplotlib import pylab as plt
-
-ot.Log.Show(ot.Log.NONE)
+import openturns.viewer as otv
 
 # %%
 # List available algorithms
@@ -51,5 +48,8 @@ print("x^=", result.getOptimalPoint())
 # %%
 # draw optimal value history
 graph = result.drawOptimalValueHistory()
-view = viewer.View(graph)
-plt.show()
+view = otv.View(graph)
+
+# %%
+# Display all figures
+otv.View.ShowAll()
