@@ -2,15 +2,13 @@
 Create the ordinal sum of copulas
 =================================
 """
+
 # %%
 # In this example we are going to create an ordinal sum of copulas.
 
 # %%
 import openturns as ot
-import openturns.viewer as viewer
-from matplotlib import pylab as plt
-
-ot.Log.Show(ot.Log.NONE)
+import openturns.viewer as otv
 
 # %%
 # Create a collection of copulas
@@ -28,5 +26,8 @@ graph = copula.drawPDF([512] * 2)
 graph.setXTitle("x")
 graph.setYTitle("y")
 graph.setLegendPosition("")
-view = viewer.View(graph)
-plt.show()
+view = otv.View(graph)
+
+# %%
+# Display all figures
+otv.View.ShowAll()
