@@ -7,10 +7,6 @@ Create and draw multivariate distributions
 # In this example we create and draw multidimensional distributions.
 import openturns as ot
 import openturns.viewer as otv
-from matplotlib import pylab as plt
-
-ot.Log.Show(ot.Log.NONE)
-
 
 # %%
 # Create a multivariate model with a :class:`~openturns.JointDistribution`
@@ -47,13 +43,13 @@ distribution = ot.JointDistribution(marginals, cop)
 # First, we draw the probability density functions of each component.
 graph_PDF_0 = marginals[0].drawPDF()
 graph_PDF_0.add(distribution.getMarginal(0).drawPDF())
-graph_PDF_0.setLegends(['instrumental marg', 'marg'])
+graph_PDF_0.setLegends(["instrumental marg", "marg"])
 graph_PDF_0.setTitle("First component")
 view = otv.View(graph_PDF_0)
 
 graph_PDF_1 = marginals[1].drawPDF()
 graph_PDF_1.add(distribution.getMarginal(1).drawPDF())
-graph_PDF_1.setLegends(['instrumental marg', 'marg'])
+graph_PDF_1.setLegends(["instrumental marg", "marg"])
 graph_PDF_1.setTitle("Second component")
 view = otv.View(graph_PDF_1)
 
@@ -61,13 +57,13 @@ view = otv.View(graph_PDF_1)
 # Then, we draw the cumulative distribution functions.
 graph_CDF_0 = marginals[0].drawCDF()
 graph_CDF_0.add(distribution.getMarginal(0).drawCDF())
-graph_CDF_0.setLegends(['instrumental marg', 'marg'])
+graph_CDF_0.setLegends(["instrumental marg", "marg"])
 graph_CDF_0.setTitle("First component")
 view = otv.View(graph_CDF_0)
 
 graph_CDF_1 = marginals[1].drawCDF()
 graph_CDF_1.add(distribution.getMarginal(1).drawCDF())
-graph_CDF_1.setLegends(['instrumental marg', 'marg'])
+graph_CDF_1.setLegends(["instrumental marg", "marg"])
 graph_CDF_1.setTitle("Second component")
 view = otv.View(graph_CDF_1)
 
@@ -79,12 +75,12 @@ graph_cop = cop_dist.drawPDF()
 # Get the Contour Drawable's actual implementation from the Graph
 # produced by drawPDF in order to access all its methods
 contour_cop = cop.drawPDF().getDrawable(1).getImplementation()
-contour_cop.setLineStyle('dashed')
+contour_cop.setLineStyle("dashed")
 # Remove the colorbar
 contour_cop.setColorBarPosition("")
 graph_cop.add(contour_cop)
 # Add the contour without a colorbargraph_cop.add(cop.drawPDF())
-graph_cop.setTitle('Distribution copula and core')
+graph_cop.setTitle("Distribution copula and core")
 view = otv.View(graph_cop)
 
 # %%
@@ -121,13 +117,13 @@ distribution = ot.JointDistribution(inst_marginals, core_dir)
 # First, we draw the probability density functions of each component.
 graph_PDF_0 = inst_marginals[0].drawPDF()
 graph_PDF_0.add(distribution.getMarginal(0).drawPDF())
-graph_PDF_0.setLegends(['instrumental marg', 'marg'])
+graph_PDF_0.setLegends(["instrumental marg", "marg"])
 graph_PDF_0.setTitle("First component")
 view = otv.View(graph_PDF_0)
 
 graph_PDF_1 = inst_marginals[1].drawPDF()
 graph_PDF_1.add(distribution.getMarginal(1).drawPDF())
-graph_PDF_1.setLegends(['instrumental marg', 'marg'])
+graph_PDF_1.setLegends(["instrumental marg", "marg"])
 graph_PDF_1.setTitle("Second component")
 view = otv.View(graph_PDF_1)
 
@@ -135,13 +131,13 @@ view = otv.View(graph_PDF_1)
 # Then, we draw the cumulative distribution functions.
 graph_CDF_0 = inst_marginals[0].drawCDF()
 graph_CDF_0.add(distribution.getMarginal(0).drawCDF())
-graph_CDF_0.setLegends(['instrumental marg', 'marg'])
+graph_CDF_0.setLegends(["instrumental marg", "marg"])
 graph_CDF_0.setTitle("First component")
 view = otv.View(graph_CDF_0)
 
 graph_CDF_1 = inst_marginals[1].drawCDF()
 graph_CDF_1.add(distribution.getMarginal(1).drawCDF())
-graph_CDF_1.setLegends(['instrumental marg', 'marg'])
+graph_CDF_1.setLegends(["instrumental marg", "marg"])
 graph_CDF_1.setTitle("Second component")
 view = otv.View(graph_CDF_1)
 
@@ -155,10 +151,10 @@ graph_core = core_dir.drawPDF()
 core_draw = graph_core.getDrawable(0).getImplementation()
 core_draw.setColorBarPosition("")
 core_draw.setLevels(levels)
-core_draw.setLineStyle('dashed')
+core_draw.setLineStyle("dashed")
 
 graph_cop.add(core_draw)
-graph_cop.setTitle('Distribution copula and core')
+graph_cop.setTitle("Distribution copula and core")
 view = otv.View(graph_cop)
 
 # %%
@@ -247,4 +243,4 @@ view = otv.View(graph)
 
 # %%
 # Display all figures
-plt.show()
+otv.View.ShowAll()
