@@ -2,6 +2,7 @@
 Create your own distribution given its quantile function
 ========================================================
 """
+
 # %%
 
 # %%
@@ -11,10 +12,10 @@ Create your own distribution given its quantile function
 # %%
 # We know that the random variable :math:`X` is distributed according to :math:`F`
 # if and only if :math:`U=F(X)` is distributed according to the uniform
-# distribution in the :math:`[0,1]` interval, i.e. :math:`U=F(X) \sim \mathcal{U}(0,1)`.
+# distribution in the :math:`[0,1]` interval, i.e., :math:`U=F(X) \sim \mathcal{U}(0,1)`.
 # Hence, if :math:`U \sim  \mathcal{U}(0,1)` then :math:`X=F^{-1}(U)` is distributed according to :math:`F`.
 #
-# In this example, we want to create a distribution with CDF :math:`F: \mathbb{R} \rightarrow [0,1] `parametrized by :math:`\rho > 1`:
+# In this example, we want to create a distribution with CDF :math:`F: \mathbb{R} \rightarrow [0,1]` parametrized by :math:`\rho > 1`:
 #
 # .. math::
 #    F(x) = 1-e^{-\rho^x} \quad \forall x  \in \mathbb{R}.
@@ -40,7 +41,7 @@ Create your own distribution given its quantile function
 
 # %%
 import openturns as ot
-from openturns.viewer import View
+import openturns.viewer as otv
 
 # %%
 # Then, we create the :math:`G` function with :math:`\rho = 2.0`.
@@ -53,17 +54,17 @@ rho = 2.0
 g = ot.ParametricFunction(gWithParameter, [1], [rho])
 
 # %%
-# We define the distribution distF as the image through :math:`G` of the Uniform(0,1) distribution:
+# We define the distribution `distF` as the image through :math:`G` of the :math:`\mathcal{U}(0,1)` distribution:
 
 # %%
 distF = ot.CompositeDistribution(g, ot.Uniform(0.0, 1.0))
 
 # %%
-# Now, we can draw its pdf, cdf, sample it,...
+# Now, we can draw its PDF, CDF and generate samples.
 
 # %%
 g = distF.drawPDF()
 g.setTitle("A distribution based on the quantile function.")
 g.setLegendPosition("")
-view = View(g)
+view = otv.View(g)
 view.ShowAll()
