@@ -8,15 +8,10 @@ Transform a distribution
 
 # %%
 import openturns as ot
-import openturns.viewer as viewer
-from matplotlib import pylab as plt
-
-ot.Log.Show(ot.Log.NONE)
-
-# %%
-# We define some (classical) distributions :
+import openturns.viewer as otv
 
 # %%
+# We define some (classical) distributions
 distribution1 = ot.Uniform(0.0, 1.0)
 distribution2 = ot.Uniform(0.0, 2.0)
 distribution3 = ot.WeibullMin(1.5, 2.0)
@@ -31,7 +26,7 @@ distribution3 = ot.WeibullMin(1.5, 2.0)
 distribution = distribution1 + distribution2
 print(distribution)
 graph = distribution.drawPDF()
-view = viewer.View(graph)
+view = otv.View(graph)
 
 # %%
 # We might also use subtraction even with scalar values:
@@ -40,7 +35,7 @@ view = viewer.View(graph)
 distribution = 3.0 - distribution3
 print(distribution)
 graph = distribution.drawPDF()
-view = viewer.View(graph)
+view = otv.View(graph)
 
 # %%
 # Product & inverse
@@ -52,7 +47,7 @@ view = viewer.View(graph)
 distribution = distribution1 * distribution2
 print(distribution)
 graph = distribution.drawPDF()
-view = viewer.View(graph)
+view = otv.View(graph)
 
 # %%
 # We could also inverse a distribution :
@@ -61,7 +56,7 @@ view = viewer.View(graph)
 distribution = 1 / distribution1
 print(distribution)
 graph = distribution.drawPDF()
-view = viewer.View(graph)
+view = otv.View(graph)
 
 # %%
 # Or compute a ratio distribution :
@@ -70,7 +65,7 @@ view = viewer.View(graph)
 ratio = distribution2 / distribution1
 print(ratio)
 graph = ratio.drawPDF()
-view = viewer.View(graph)
+view = otv.View(graph)
 
 # %%
 # Transformation using functions
@@ -103,7 +98,7 @@ view = viewer.View(graph)
 
 # %%
 graph = distribution1.log().drawPDF()
-view = viewer.View(graph)
+view = otv.View(graph)
 
 # %%
 # And for the `log2` function :
@@ -112,7 +107,7 @@ view = viewer.View(graph)
 f = ot.SymbolicFunction(["x"], ["log2(x)"])
 f.setDescription(["X", "ln(X)"])
 graph = ot.CompositeDistribution(f, distribution1).drawPDF()
-view = viewer.View(graph)
+view = otv.View(graph)
 
 # %%
 # If one wants a specific method, user might rely on the :class:`~openturns.CompositeDistribution` class.
@@ -141,20 +136,20 @@ f = ot.SymbolicFunction(["x"], ["sin(x)+cos(x)"])
 # We then create the composite distribution
 distribution = ot.CompositeDistribution(f, antecedent)
 graph = distribution.drawPDF()
-view = viewer.View(graph)
+view = otv.View(graph)
 
 # %%
 # We can also build a distribution with the simplified construction
 distribution = antecedent.exp()
 graph = distribution.drawPDF()
-view = viewer.View(graph)
+view = otv.View(graph)
 
 # %%
 # and by using chained operators:
 distribution = antecedent.abs().sqrt()
 graph = distribution.drawPDF()
-view = viewer.View(graph)
+view = otv.View(graph)
 
 # %%
 # Display all figures
-plt.show()
+otv.View.ShowAll()
