@@ -1,9 +1,6 @@
 import openturns as ot
 from matplotlib import pyplot as plt
-from openturns.viewer import View
-
-ot.RandomGenerator.SetSeed(0)
-ot.ResourceMap.Reload()
+import openturns.viewer as otv
 
 # Generate sample with the given plane
 size = 20
@@ -30,4 +27,4 @@ graph.add(cloud)
 fig = plt.figure(figsize=(4, 4))
 axis = fig.add_subplot(111)
 axis.set_xlim(auto=True)
-View(graph, figure=fig, axes=[axis], add_legend=False)
+otv.View(graph, figure=fig, axes=[axis], add_legend=False)
