@@ -1,9 +1,7 @@
 import openturns as ot
-from openturns.viewer import View
+import openturns.viewer as otv
 import math as m
 
-ot.RandomGenerator.SetSeed(0)
-
 
 def flooding(X):
     L, B = 5.0e3, 300.0
@@ -18,7 +16,7 @@ Q = ot.TruncatedDistribution(ot.Gumbel(558.0, 1013.0), ot.TruncatedDistribution.
 K_s = ot.Dirac(30.0)
 Z_v = ot.Dirac(50.0)
 Z_m = ot.Dirac(55.0)
-inputRandomVector = ot.ComposedDistribution([Q, K_s, Z_v, Z_m])
+inputRandomVector = ot.JointDistribution([Q, K_s, Z_v, Z_m])
 nbobs = 100
 inputSample = inputRandomVector.getSample(nbobs)
 outputH = g(inputSample)
@@ -26,11 +24,11 @@ Hobs = outputH + ot.Normal(0.0, 0.1).getSample(nbobs)
 Qobs = inputSample[:, 0]
 thetaPrior = [20, 49, 51]
 model = ot.ParametricFunction(g, [1, 2, 3], thetaPrior)
-errorCovariance = ot.CovarianceMatrix([[0.5 ** 2]])
+errorCovariance = ot.CovarianceMatrix([[0.5**2]])
 sigma = ot.CovarianceMatrix(3)
-sigma[0, 0] = 5.0 ** 2
-sigma[1, 1] = 1.0 ** 2
-sigma[2, 2] = 1.0 ** 2
+sigma[0, 0] = 5.0**2
+sigma[1, 1] = 1.0**2
+sigma[2, 2] = 1.0**2
 algo = ot.GaussianNonLinearCalibration(
     model, Qobs, Hobs, thetaPrior, sigma, errorCovariance
 )
@@ -38,4 +36,4 @@ algo.run()
 result = algo.getResult()
 graph = result.drawObservationsVsPredictions()
 
-View(graph)
+otv.View(graph)
