@@ -1,5 +1,5 @@
 import openturns as ot
-from openturns.viewer import View
+import openturns.viewer as otv
 
 g = ot.SymbolicFunction(["x"], ["sin(x)"])
 f = ot.SymbolicFunction(["y"], ["abs(y)"])
@@ -7,4 +7,4 @@ composed = ot.ComposedFunction(f, g)
 
 graph = composed.draw(0.0, 10.0)
 graph.setTitle("y=abs(sin(x))")
-View(graph, figure_kw={"figsize": (8, 4)}, add_legend=True).ShowAll()
+otv.View(graph, figure_kw={"figsize": (8, 4)}, add_legend=True).ShowAll()
