@@ -1,5 +1,5 @@
 import openturns as ot
-from openturns.viewer import View
+import openturns.viewer as otv
 
 X = ot.RandomVector(ot.Normal())
 f = ot.SymbolicFunction(["x"], ["x^2*sin(x)"])
@@ -7,4 +7,4 @@ Y = ot.CompositeRandomVector(f, X)
 sample = Y.getSample(200)
 histogram = ot.HistogramFactory().build(sample).drawPDF()
 histogram.setTitle("Y=x^2*sin(x)")
-View(histogram, figure_kw={"figsize": (6, 4)}, add_legend=False)
+otv.View(histogram, figure_kw={"figsize": (6, 4)}, add_legend=False)
