@@ -1,7 +1,8 @@
 import openturns as ot
-from openturns.viewer import View
+import openturns.viewer as otv
 
 ot.ResourceMap.SetAsUnsignedInteger("Contour-DefaultLevelsNumber", 10)
+
 grid = ot.GridLayout(2, 2)
 pdf_graph = ot.Graph("PDFs of 1D Dirichlet distributions", "x", "", True)
 cdf_graph = ot.Graph("CDFs of 1D Dirichlet distributions", "x", "", True)
@@ -30,6 +31,6 @@ grid.setGraph(1, 0, pdf_2d_1)
 grid.setGraph(1, 1, pdf_2d_2)
 grid.setTitle("Dirichlet (theta)")
 grid.setLegendPosition("upper right")
-v = View(grid)
+v = otv.View(grid)
 fig = v.getFigure()
 fig.axes[1].legend(loc="best")
