@@ -1,7 +1,6 @@
 import openturns as ot
-from openturns.viewer import View
+import openturns.viewer as otv
 
-ot.RandomGenerator.SetSeed(0)
 
 size = 100
 normal = ot.Normal(1)
@@ -9,4 +8,4 @@ sample = normal.getSample(size)
 
 henryPlot = ot.VisualTest.DrawHenryLine(sample)
 
-View(henryPlot, figure_kw={"figsize": (4.5, 4.5)})
+otv.View(henryPlot, figure_kw={"figsize": (4.5, 4.5)})
