@@ -1,7 +1,6 @@
 import openturns as ot
-from openturns.viewer import View
+import openturns.viewer as otv
 
-ot.RandomGenerator.SetSeed(0)
 
 dimension = 2
 R = ot.CorrelationMatrix(dimension)
@@ -19,4 +18,4 @@ lmtest = ot.LinearModelAlgorithm(firstSample, secondSample).getResult()
 
 drawLinearModel = ot.VisualTest.DrawLinearModel(lmtest)
 
-View(drawLinearModel, figure_kw={"figsize": (5, 5)})
+otv.View(drawLinearModel, figure_kw={"figsize": (5, 5)})
