@@ -1,7 +1,6 @@
 import openturns as ot
-from openturns.viewer import View
+import openturns.viewer as otv
 
-ot.RandomGenerator.SetSeed(0)
 
 sample = ot.Normal(3).getSample(100)
 distribution = ot.JointDistribution(
@@ -9,4 +8,4 @@ distribution = ot.JointDistribution(
 )
 graph = ot.VisualTest.DrawPairsMarginals(sample, distribution)
 
-View(graph, figure_kw={"figsize": (6.0, 6.0)})
+otv.View(graph, figure_kw={"figsize": (6.0, 6.0)})
