@@ -1,7 +1,6 @@
 import openturns as ot
-from openturns.viewer import View
+import openturns.viewer as otv
 
-ot.RandomGenerator.SetSeed(0)
 
 sampleX = ot.Normal(2).getSample(100)
 
@@ -11,4 +10,4 @@ sampleY = f(sampleX)
 
 graph = ot.VisualTest.DrawPairsXY(sampleX, sampleY)
 
-View(graph, figure_kw={"figsize": (6.0, 6.0)})
+otv.View(graph, figure_kw={"figsize": (6.0, 6.0)})
