@@ -1,7 +1,6 @@
 import openturns as ot
-from openturns.viewer import View
+import openturns.viewer as otv
 
-ot.RandomGenerator.SetSeed(0)
 
 size = 100
 inputDimension = 6
@@ -20,4 +19,6 @@ cobweb = ot.VisualTest.DrawParallelCoordinates(
     inputSample, outputSample, 2.5, 3.0, "red", False
 )
 
-View(cobweb, figure_kw={"figsize": (10, 6)}, legend_kw={"loc": "lower right"})
+cobweb.setLegendCorner([1.0, 0.0])
+cobweb.setLegendPosition("lower right")
+otv.View(cobweb, figure_kw={"figsize": (9, 5)})
