@@ -1,11 +1,10 @@
 import openturns as ot
-from openturns.viewer import View
+import openturns.viewer as otv
 
-ot.RandomGenerator.SetSeed(0)
 size = 100
 normal = ot.Normal(1)
 sample = normal.getSample(size)
 
 QQPlot = ot.VisualTest.DrawQQplot(sample, normal)
 
-View(QQPlot, figure_kw={"figsize": (4.5, 4.5)})
+otv.View(QQPlot, figure_kw={"figsize": (4.5, 4.5)})
