@@ -1,8 +1,7 @@
 import openturns as ot
-from openturns.viewer import View
+import openturns.viewer as otv
 
-ot.RandomGenerator.SetSeed(0)
 data = ot.FrankCopula().getSample(1000)
 graph = ot.VisualTest.DrawUpperTailDependenceFunction(data)
 
-View(graph, figure_kw={"figsize": (4.5, 4.5)})
+otv.View(graph, figure_kw={"figsize": (4.5, 4.5)})
