@@ -1,8 +1,7 @@
 import openturns as ot
 from matplotlib import pyplot as plt
-from openturns.viewer import View
+import openturns.viewer as otv
 
-ot.RandomGenerator.SetSeed(0)
 
 # Generate sample with the given plane
 size = 20
@@ -30,4 +29,4 @@ graph.add(cloud)
 fig = plt.figure(figsize=(4, 4))
 axis = fig.add_subplot(111)
 axis.set_xlim(auto=True)
-View(graph, figure=fig, axes=[axis], add_legend=False)
+otv.View(graph, figure=fig, axes=[axis], add_legend=False)
