@@ -1,5 +1,5 @@
 import openturns as ot
-from openturns.viewer import View
+import openturns.viewer as otv
 
 analytical = ot.SymbolicFunction(["x"], ["2*x-8"])
 levelset = ot.LevelSet(analytical, ot.Less(), 0.0)
@@ -7,4 +7,4 @@ f = ot.IndicatorFunction(levelset)
 
 graph = f.draw(0.0, 10.0)
 graph.setTitle(r"$y=\mathbb{1}_{2x-8<0}$")
-View(graph, figure_kw={"figsize": (8, 4)}, add_legend=True)
+otv.View(graph, figure_kw={"figsize": (8, 4)}, add_legend=True)
