@@ -1,5 +1,5 @@
 import openturns as ot
-from openturns.viewer import View
+import openturns.viewer as otv
 
 sample = ot.Gamma(6.0, 1.0).getSample(100)
 ks = ot.KernelSmoothing()
@@ -9,4 +9,4 @@ fittedDist = ks.build(sample, bandwidth)
 graph = fittedDist.drawPDF()
 graph.add(ot.Gamma(6.0, 1.0).drawPDF())
 graph.setLegends(["KS dist", "Gamma"])
-View(graph)
+otv.View(graph)
