@@ -1,5 +1,5 @@
 import openturns as ot
-from openturns.viewer import View
+import openturns.viewer as otv
 
 f = ot.SymbolicFunction(["x"], ["x * sin(x)"])
 sampleX = [[1.0], [2.0], [3.0], [4.0], [5.0], [6.0], [7.0], [8.0]]
@@ -19,4 +19,4 @@ graph.add(ot.Cloud(sampleX, sampleY))
 graph.setLegends(["model", "meta model", "sample"])
 graph.setLegendPosition("upper left")
 graph.setTitle("y(x)=x * sin(x)")
-View(graph, figure_kw={"figsize": (8, 4)})
+otv.View(graph, figure_kw={"figsize": (8, 4)})
