@@ -1,7 +1,6 @@
 import openturns as ot
-from openturns.viewer import PlotDesign
+import openturns.viewer as otv
 
-ot.RandomGenerator.SetSeed(0)
 dim = 3
 size = 10
 distribution = ot.JointDistribution([ot.Uniform(0.0, 1.0)] * dim)
@@ -9,4 +8,4 @@ bounds = distribution.getRange()
 lhs = ot.LHSExperiment(distribution, size)
 sample = lhs.generate()
 subdivisions = [size] * dim
-fig = PlotDesign(sample, bounds, subdivisions)
+fig = otv.PlotDesign(sample, bounds, subdivisions)
