@@ -1,5 +1,5 @@
 import openturns as ot
-from openturns.viewer import View
+import openturns.viewer as otv
 
 f1 = ot.SymbolicFunction(["x"], ["sin(x)"])
 f2 = ot.SymbolicFunction(["x"], ["x"])
@@ -8,4 +8,4 @@ f3 = ot.SymbolicFunction(["x"], ["cos(x)"])
 f = ot.LinearCombinationFunction([f1, f2, f3], [1.0, 2.0, 3.0])
 graph = f.draw(0.0, 10.0)
 graph.setTitle("y=1*f1+2*f2+3*f3")
-View(graph, figure_kw={"figsize": (8, 4)}, add_legend=True)
+otv.View(graph, figure_kw={"figsize": (8, 4)}, add_legend=True)
