@@ -1,7 +1,6 @@
 import openturns as ot
-from openturns.viewer import View
+import openturns.viewer as otv
 
-ot.RandomGenerator.SetSeed(0)
 # Define the model
 dist = ot.Uniform(-3.0, 3.0)
 model = ot.SymbolicFunction(["x"], ["sin(x)"])
@@ -13,9 +12,9 @@ total_degree = 3
 polynomialCollection = ["x^%d" % (degree) for degree in range(1, total_degree + 1)]
 basis = ot.SymbolicFunction(["x"], polynomialCollection)
 designMatrix = basis(x_train)
-myLeastSquares = ot.LinearLeastSquares(designMatrix, y_train)
-myLeastSquares.run()
-leastSquaresModel = myLeastSquares.getMetaModel()
+algo = ot.LinearLeastSquares(designMatrix, y_train)
+algo.run()
+leastSquaresModel = algo.getResult().getMetaModel()
 metaModel = ot.ComposedFunction(leastSquaresModel, basis)
 
 # Validate the metamodel
@@ -24,4 +23,4 @@ y_test = model(x_test)
 metamodelPredictions = metaModel(x_test)
 val = ot.MetaModelValidation(y_test, metamodelPredictions)
 graph = val.drawValidation()
-View(graph)
+otv.View(graph)
