@@ -1,7 +1,6 @@
 import openturns as ot
-from openturns.viewer import View
+import openturns.viewer as otv
 
-ot.RandomGenerator.SetSeed(0)
 
 # 3-d test
 R1 = ot.CovarianceMatrix(3)
@@ -26,4 +25,4 @@ distribution = ot.KernelSmoothing().build(sample)
 algo = ot.MinimumVolumeClassifier(distribution, [0.8])
 graph = algo.drawContourAndSample([0.1, 0.5, 0.8], sample, [0, 1])
 
-View(graph, contour_kw={"colors": ["black"]}, figure_kw={"figsize": (6.0, 6.0)})
+otv.View(graph, contour_kw={"colors": ["black"]}, figure_kw={"figsize": (6.0, 6.0)})
