@@ -1,6 +1,6 @@
 import openturns as ot
 from matplotlib import pyplot as plt
-from openturns.viewer import View
+import openturns.viewer as otv
 
 
 mu = [2.0, 2.0]
@@ -25,6 +25,6 @@ cdf_axis = fig.add_subplot(122)
 pdf_axis.set_xlim(auto=True)
 cdf_axis.set_xlim(auto=True)
 
-View(graphPDF, figure=fig, axes=[pdf_axis], add_legend=True)
-View(graphCDF, figure=fig, axes=[cdf_axis], add_legend=True)
+otv.View(graphPDF, figure=fig, axes=[pdf_axis], add_legend=True)
+otv.View(graphCDF, figure=fig, axes=[cdf_axis], add_legend=True)
 fig.suptitle("Mixture: 0.3*Normal1 + 0.7*Normal2: pdf and cdf")
