@@ -1,11 +1,10 @@
 import openturns as ot
 from matplotlib import pyplot as plt
-from openturns.viewer import View
+import openturns.viewer as otv
 
-ot.RandomGenerator.SetSeed(0)
 
 # Generate sample with the given plane
-distribution = ot.ComposedDistribution([ot.Uniform(0, 1)] * 2)
+distribution = ot.JointDistribution([ot.Uniform(0, 1)] * 2)
 size = 10
 experiment = ot.MonteCarloExperiment(distribution, size)
 
@@ -22,4 +21,4 @@ graph.add(cloud)
 fig = plt.figure(figsize=(4, 4))
 axis = fig.add_subplot(111)
 axis.set_xlim(auto=True)
-View(graph, figure=fig, axes=[axis], add_legend=False)
+otv.View(graph, figure=fig, axes=[axis], add_legend=False)
