@@ -1,5 +1,5 @@
 import openturns as ot
-from openturns.viewer import View
+import openturns.viewer as otv
 
 center = [0.0]
 constant = [3.0]
@@ -11,4 +11,4 @@ graph = f.draw(-5.0, 5.0)
 graph.setTitle(r"Quadratic function $x \mapsto 5x^2+2x+3$")
 graph.setXTitle(r"$x$")
 graph.setYTitle(r"$y$")
-View(graph, figure_kw={"figsize": (8, 4)}, add_legend=True)
+otv.View(graph, figure_kw={"figsize": (8, 4)}, add_legend=True)
