@@ -1,8 +1,6 @@
 import openturns as ot
 from matplotlib import pyplot as plt
-from openturns.viewer import View
-
-ot.RandomGenerator.SetSeed(0)
+import openturns.viewer as otv
 
 
 def flooding(X):
@@ -21,12 +19,12 @@ def flooding(X):
 
 myFunction = ot.PythonFunction(4, 1, flooding)
 Q = ot.Gumbel(558.0, 1013.0)
-Q = ot.TruncatedDistribution(Q, 0.0, ot.SpecFunc.MaxScalar)
+Q = ot.TruncatedDistribution(Q, 0.0, ot.SpecFunc.Infinity)
 Ks = ot.Normal(30.0, 7.5)
-Ks = ot.TruncatedDistribution(Ks, 0.0, ot.SpecFunc.MaxScalar)
+Ks = ot.TruncatedDistribution(Ks, 0.0, ot.SpecFunc.Infinity)
 Zv = ot.Uniform(49.0, 51.0)
 Zm = ot.Uniform(54.0, 56.0)
-inputX = ot.ComposedDistribution([Q, Ks, Zv, Zm])
+inputX = ot.JointDistribution([Q, Ks, Zv, Zm])
 inputX.setDescription(["Q", "Ks", "Zv", "Zm"])
 
 size = 5000
@@ -40,4 +38,4 @@ graph = sensitivityAnalysis.draw()
 fig = plt.figure(figsize=(8, 4))
 axis = fig.add_subplot(111)
 axis.set_xlim(auto=True)
-View(graph, figure=fig, axes=[axis], add_legend=True)
+otv.View(graph, figure=fig, axes=[axis], add_legend=True)
