@@ -1,6 +1,6 @@
 import openturns as ot
 from matplotlib import pyplot as plt
-from openturns.viewer import View
+import openturns.viewer as otv
 
 model = ot.SymbolicFunction(["E", "F", "L", "I"], ["F*L^3/(3*E*I)"])
 
@@ -27,9 +27,9 @@ estimator.setUseAsymptoticDistribution(True)
 # algorithm
 algo = ot.SobolSimulationAlgorithm(distribution, model, estimator)
 algo.setMaximumOuterSampling(250)  # number of iterations
-algo.setBlockSize(100)  # size of Sobol experiment at each iteration
-algo.setBatchSize(4)  # number of points evaluated simultaneously
-# alpha: cirteria checks whether CIs are small enough
+algo.setExperimentSize(100)
+algo.setBlockSize(4)
+# alpha: criteria checks whether CIs are small enough
 algo.setIndexQuantileLevel(0.05)
 # epsilon: criteria checks whether CIs are tight enough
 algo.setIndexQuantileEpsilon(1e-2)
@@ -40,4 +40,4 @@ graph = algo.drawFirstOrderIndexConvergence(0)
 fig = plt.figure(figsize=(8, 4))
 axis = fig.add_subplot(111)
 axis.set_xlim(auto=True)
-View(graph, figure=fig, axes=[axis], add_legend=True)
+otv.View(graph, figure=fig, axes=[axis], add_legend=True)
