@@ -1,8 +1,7 @@
 import openturns as ot
 from matplotlib import pyplot as plt
-from openturns.viewer import View
+import openturns.viewer as otv
 
-ot.RandomGenerator.SetSeed(0)
 
 experiment1 = ot.GaussProductExperiment(ot.Uniform(0.0, 1.0), [3])
 experiment2 = ot.GaussProductExperiment(ot.Uniform(0.0, 1.0), [5])
@@ -22,4 +21,4 @@ graph.add(cloud)
 fig = plt.figure(figsize=(4, 4))
 axis = fig.add_subplot(111)
 axis.set_xlim(auto=True)
-View(graph, figure=fig, axes=[axis], add_legend=False)
+otv.View(graph, figure=fig, axes=[axis], add_legend=False)
