@@ -1,7 +1,7 @@
 import openturns as ot
 from math import exp
 from matplotlib import pyplot as plt
-from openturns.viewer import View
+import openturns.viewer as otv
 
 
 def C(s, t):
@@ -27,4 +27,4 @@ cov_graph.setTitle("User defined covariance model")
 
 fig = plt.figure(figsize=(10, 4))
 cov_axis = fig.add_subplot(111)
-View(cov_graph, figure=fig, axes=[cov_axis], add_legend=False, square_axes=True)
+otv.View(cov_graph, figure=fig, axes=[cov_axis], add_legend=False, square_axes=True)
