@@ -34,7 +34,7 @@ class IshigamiModel:
     X3 : :class:`~openturns.Uniform`
         Third marginal, ot.Uniform(-np.pi, np.pi)
 
-    inputDistribution : :class:`~openturns.JointDistribution`
+    distribution : :class:`~openturns.JointDistribution`
         The joint distribution of the input parameters.
 
     ishigami : :class:`~openturns.SymbolicFunction`
@@ -109,8 +109,9 @@ class IshigamiModel:
         self.X3.setDescription(["X3"])
 
         # Input distribution
-        self.inputDistribution = ot.JointDistribution([self.X1, self.X2, self.X3])
-        self.inputDistribution.setDescription(["X1", "X2", "X3"])
+        self.distribution = ot.JointDistribution([self.X1, self.X2, self.X3])
+        self.distribution.setDescription(["X1", "X2", "X3"])
+        self.inputDistribution = self.distribution  # deprecated
 
         self.ishigami = ot.SymbolicFunction(
             ["X1", "X2", "X3", "a", "b"],
