@@ -159,6 +159,9 @@ class View:
     legend_kw : dict, optional
         Passed on to matplotlib.axes.Axes.legend kwargs
 
+    colorbar_kw : dict, optional
+        Passed on to matplotlib.figure.Figure.colorbar kwargs
+
     add_legend : bool, optional
         Adds a legend if True. Default is True.
 
@@ -211,6 +214,7 @@ class View:
         scatter_kw=None,
         text_kw=None,
         legend_kw=None,
+        colorbar_kw=None,
         add_legend=True,
         square_axes=False,
         **kwargs,
@@ -249,6 +253,7 @@ class View:
         scatter_kw_default = self._CheckDict(scatter_kw)
         text_kw_default = self._CheckDict(text_kw)
         legend_kw_default = self._CheckDict(legend_kw)
+        colorbar_kw_default = self._CheckDict(colorbar_kw)
         legend_handles = []
         legend_labels = []
 
@@ -566,7 +571,10 @@ class View:
                     polygon_kw["edgecolor"] = drawable.ConvertFromName(
                         drawable.getEdgeColor()
                     )
-                self._ax[0].add_patch(matplotlib.patches.Polygon(data, **polygon_kw))
+                poly = matplotlib.patches.Polygon(data, **polygon_kw)
+                self._ax[0].add_patch(poly)
+                legend_handles.append(poly)
+                legend_labels.append(drawable.getLegend())
 
             elif drawableKind == "PolygonArray":
                 polygonsNumber = drawable.getPalette().getSize()
@@ -667,6 +675,12 @@ class View:
                         contour_kw["norm"] = normDict[norm]
                     except KeyError:
                         warnings.warn("-- Unknown norm " + norm)
+
+                    # 3.3.4 (debian 11) does not like null log levels
+                    if norm == "log" and "levels" in contour_kw:
+                        contour_kw["levels"] = list(
+                            filter(lambda x: x > 0.0, contour_kw["levels"])
+                        )
                 else:
                     contour_kw["norm"] = norm
                 if contour_kw.get("norm") == "rank":
@@ -725,19 +739,20 @@ class View:
                     legend_labels.append(drawable.getLegend())
                 if contour.getColorBarPosition() and len(contour.getLevels()) != 1:
                     colorbar = None
+                    colorbar_kw = dict(colorbar_kw_default)
+                    if "format" not in colorbar_kw:
+                        colorbar_kw["format"] = "%.3g"
                     if matplotlib_version >= Version("3.7.0"):
-                        colorbar = self._fig.colorbar(
-                            contourset,
-                            location=contour.getColorBarPosition(),
-                            format="%.3g",
-                        )
+                        if "location" not in colorbar_kw:
+                            colorbar_kw["location"] = contour.getColorBarPosition()
+                        colorbar = self._fig.colorbar(contourset, **colorbar_kw)
                     else:
                         # do not draw colorbar when Z range has too few values
                         # https://github.com/matplotlib/matplotlib/issues/23817
                         nZ = len(set([z[0] for z in drawable.getData()]))
                         if nZ > 2:
                             try:
-                                colorbar = self._fig.colorbar(contourset, format="%.3g")
+                                colorbar = self._fig.colorbar(contourset, **colorbar_kw)
                                 if contour.getColorBarPosition() != "right":
                                     warnings.warn(
                                         "-- colorbar location was not used in matplotlib < 3.7.0"
@@ -1104,18 +1119,18 @@ def PlotDesign(
     Plot a sample in 2 dimensions.
 
     >>> import openturns as ot
-    >>> from openturns.viewer import PlotDesign
+    >>> import openturns.viewer as otv
     >>> dim = 2
     >>> X = [ot.Uniform()] * dim
     >>> distribution = ot.JointDistribution(X)
     >>> sampleSize = 10
     >>> sample = distribution.getSample(sampleSize)
-    >>> fig = PlotDesign(sample)
+    >>> fig = otv.PlotDesign(sample)
 
     Plot a sample in 5 dimensions.
 
     >>> import openturns as ot
-    >>> from openturns.viewer import PlotDesign
+    >>> import openturns.viewer as otv
     >>> dim = 5
     >>> size = 10
     >>> distribution = ot.JointDistribution([ot.Uniform(0.0, 1.0)]*dim)
@@ -1123,7 +1138,7 @@ def PlotDesign(
     >>> lhs = ot.LHSExperiment(distribution, size)
     >>> sample = lhs.generate()
     >>> subdivisions = [size]*dim
-    >>> fig = PlotDesign(sample, bounds, subdivisions)
+    >>> fig = otv.PlotDesign(sample, bounds, subdivisions)
     """
     # check that arguments are dictionaries
     axes_kw = View._CheckDict(axes_kw)
