@@ -6,13 +6,10 @@ ot.TESTPREAMBLE()
 
 # create a function
 dim = 4
-function = ot.SymbolicFunction(
-    ['E', 'F', 'L', 'I'], ['F*L^3/(3.*E*I)'])
+function = ot.SymbolicFunction(["E", "F", "L", "I"], ["F*L^3/(3.*E*I)"])
 
 # create a distribution
-distribution = ot.Normal(
-    [50., 1.0, 10.0, 5.0], [1.0] * dim,
-    ot.IdentityMatrix(dim))
+distribution = ot.Normal([50.0, 1.0, 10.0, 5.0], [1.0] * dim, ot.IdentityMatrix(dim))
 vect = ot.RandomVector(distribution)
 composite = ot.CompositeRandomVector(function, vect)
 event = ot.ThresholdEvent(composite, ot.Less(), -3.0)
@@ -31,13 +28,13 @@ print(result)
 algo2 = algo
 algo2.setPartialStratification(True)
 algo2.run()
-print('T=', algo2.getTStatistic())
+print("T=", algo2.getTStatistic())
 result = algo2.getResult()
 print(result)
 
 # DPADS-2
 algo3 = algo2
-algo3.setQuadrantOrientation([1.] * dim)  # enables DPADS-2, sets design
+algo3.setQuadrantOrientation([1.0] * dim)  # enables DPADS-2, sets design
 algo3.run()
 result = algo3.getResult()
 print(result)
