@@ -24,7 +24,7 @@ def compute_roughness_sampling(distribution, size=500000):
 
 class Quartic(ot.PythonDistribution):
     def __init__(self):
-        super(Quartic, self).__init__(1)
+        super().__init__(1)
         self.c = 15.0 / 16
 
     def computeCDF(self, x):
