@@ -1,7 +1,7 @@
 #! /usr/bin/env python
 
 import openturns as ot
-
+import openturns.testing as ott
 
 ot.TESTPREAMBLE()
 
@@ -31,12 +31,6 @@ size = 10
 oneSample = copula.getSample(size)
 print("oneSample=", repr(oneSample))
 
-# Test for sampling
-size = 10000
-anotherSample = copula.getSample(size)
-print("anotherSample mean=", repr(anotherSample.computeMean()))
-print("anotherSample covariance=", repr(anotherSample.computeCovariance()))
-
 # Define a point
 point = ot.Point(dim, 0.2)
 
@@ -100,9 +94,7 @@ for i in range(dim):
     print("margin realization=", repr(margin.getRealization()))
 
 # Extract a 2-D marginal
-indices = ot.Indices(2, 0)
-indices[0] = 1
-indices[1] = 0
+indices = [1, 0]
 print("indices=", repr(indices))
 margins = copula.getMarginal(indices)
 print("margins=", repr(margins))
@@ -112,3 +104,7 @@ quantile = ot.Point(margins.computeQuantile(0.95))
 print("margins quantile=", repr(quantile))
 print("margins CDF(qantile)=%.6f" % margins.computeCDF(quantile))
 print("margins realization=", repr(margins.getRealization()))
+
+ot.Log.Show(ot.Log.TRACE)
+validation = ott.DistributionValidation(copula)
+validation.run()
