@@ -1,7 +1,6 @@
 #!/usr/bin/env python
 
 import openturns as ot
-import openturns.experimental as otexp
 import openturns.testing as ott
 
 ot.TESTPREAMBLE()
@@ -44,7 +43,7 @@ p1 = ot.FunctionalBasisProcess(coefDis, myBasis, tg)
 p2 = ot.GaussianProcess(ot.SquaredExponential([1.0], [T / 4.0]), tg)
 
 # Third process: elementary process based on a bivariate random vector
-randomParameters = ot.ComposedDistribution([ot.Uniform(), ot.Normal()])
+randomParameters = ot.JointDistribution([ot.Uniform(), ot.Normal()])
 p3 = ot.FunctionalBasisProcess(
     randomParameters,
     ot.Basis(
@@ -60,14 +59,14 @@ x = X.getSample(N)
 y = f(x)
 
 # run algo
-algo = otexp.FieldToPointFunctionalChaosAlgorithm(x, y)
+algo = ot.FieldToPointFunctionalChaosAlgorithm(x, y)
 ot.ResourceMap.SetAsUnsignedInteger("FunctionalChaosAlgorithm-BasisSize", N)
 ot.ResourceMap.SetAsBool("FunctionalChaosAlgorithm-Sparse", True)
 algo.setThreshold(4e-2)
 algo.setRecompress(True)
 algo.run()
 result = algo.getResult()
-bi = result.getBlockIndices()
+bi = result.getInputBlockIndices()
 print(f"block indices={bi}")
 assert len(bi) == 4, "wrong number of blocks"
 
@@ -79,7 +78,7 @@ ratios = [res.getSelectionRatio() for res in kl_results]
 print(f"ratios={ratios}")
 
 # retrieve Sobol indices
-sensitivity = otexp.FieldFunctionalChaosSobolIndices(result)
+sensitivity = ot.FieldFunctionalChaosSobolIndices(result)
 sobol_0 = sensitivity.getFirstOrderIndices()
 sobol_0t = sensitivity.getTotalOrderIndices()
 print(f"first order={sobol_0}")
@@ -102,7 +101,7 @@ algo.run()
 result = algo.getResult()
 
 # retrieve Sobol indices
-sensitivity = otexp.FieldFunctionalChaosSobolIndices(result)
+sensitivity = ot.FieldFunctionalChaosSobolIndices(result)
 sobol_0 = sensitivity.getFirstOrderIndices()
 sobol_0t = sensitivity.getTotalOrderIndices()
 print(f"first order={sobol_0}")
