@@ -81,8 +81,6 @@ for fittingAlgorithmIndex in range(len(listFittingAlgorithm)):
 
     result = algo.getResult()
     print("coeffs = ", result.getCoefficients())
-    print("residuals = ", result.getResiduals())
-    print("relative errors = ", result.getRelativeErrors())
     print("isLeastSquares= ", result.isLeastSquares())
     assert result.isLeastSquares()
     print("involvesModelSelection= ", result.involvesModelSelection())
