@@ -1,17 +1,11 @@
 #! /usr/bin/env python
 
 import openturns as ot
-from openturns.experimental import GaussianProcessRegression, GaussianProcessFitter
+import openturns.experimental as otexp
 import openturns.testing as ott
 
 ot.TESTPREAMBLE()
-ot.ResourceMap.SetAsUnsignedInteger(
-    "OptimizationAlgorithm-DefaultMaximumCallsNumber", 20000
-)
-ot.ResourceMap.SetAsScalar("Cobyla-DefaultRhoBeg", 0.5)
-ot.ResourceMap.SetAsScalar("OptimizationAlgorithm-DefaultMaximumAbsoluteError", 1e-8)
 
-ot.PlatformInfo.SetNumericalPrecision(3)
 ot.ResourceMap.SetAsString("GaussianProcessFitter-LinearAlgebra", "HMAT")
 ot.ResourceMap.SetAsScalar("HMatrix-RegularizationEpsilon", 1e-7)
 
@@ -40,7 +34,7 @@ def test_one_input_one_output():
     covarianceModel = ot.SquaredExponential()
 
     # create algorithm
-    fit_algo = GaussianProcessFitter(X, Y, covarianceModel, basis)
+    fit_algo = otexp.GaussianProcessFitter(X, Y, covarianceModel, basis)
 
     # set sensible optimization bounds and estimate hyper parameters
     fit_algo.setOptimizationBounds(ot.Interval(X.getMin(), X.getMax()))
@@ -49,7 +43,7 @@ def test_one_input_one_output():
     # perform an evaluation
     fit_result = fit_algo.getResult()
 
-    algo = GaussianProcessRegression(fit_result)
+    algo = otexp.GaussianProcessRegression(fit_result)
     algo.run()
     result = algo.getResult()
     ott.assert_almost_equal(result.getMetaModel()(X), Y, 1e-2)
@@ -90,7 +84,7 @@ def test_two_inputs_one_output():
     basis = ot.ConstantBasisFactory(inputDimension).build()
 
     # 4) GPF algorithm
-    fit_algo = GaussianProcessFitter(inputSample, outputSample, covarianceModel, basis)
+    fit_algo = otexp.GaussianProcessFitter(inputSample, outputSample, covarianceModel, basis)
     # set sensible optimization bounds and estimate hyper parameters
     fit_algo.setOptimizationBounds(
         ot.Interval(inputSample.getMin(), inputSample.getMax())
@@ -100,7 +94,7 @@ def test_two_inputs_one_output():
     # perform an evaluation
     fit_result = fit_algo.getResult()
     # Regression algorithm
-    algo = GaussianProcessRegression(fit_result)
+    algo = otexp.GaussianProcessRegression(fit_result)
     algo.run()
 
     result = algo.getResult()
@@ -135,18 +129,20 @@ def test_two_outputs():
     covarianceModel.setActiveParameter([])
     covarianceModel = ot.TensorizedCovarianceModel([covarianceModel] * 2)
 
-    fit_algo = GaussianProcessFitter(sampleX, sampleY, covarianceModel, basis)
+    fit_algo = otexp.GaussianProcessFitter(sampleX, sampleY, covarianceModel, basis)
     # set sensible optimization bounds and estimate hyper parameters
     fit_algo.run()
 
     # perform an evaluation
     fit_result = fit_algo.getResult()
-    algo = GaussianProcessRegression(fit_result)
+    algo = otexp.GaussianProcessRegression(fit_result)
     algo.run()
     result = algo.getResult()
     mm = result.getMetaModel()
     assert mm.getOutputDimension() == 2, "wrong output dim"
-    ott.assert_almost_equal(mm([5.5]), [-3.88, 3.90], 1e-2, 1e-3)
+    y = mm([5.5])
+    print(y)
+    ott.assert_almost_equal(y, [-3.88407, 3.90308], 1e-2, 1e-3)
 
 
 def test_stationary_fun():
@@ -159,18 +155,20 @@ def test_stationary_fun():
     y = x + ot.Normal(0, 0.1).getSample(20)
     y.setDescription(["G0"])
 
-    fit_algo = GaussianProcessFitter(x, y, model, ot.LinearBasisFactory().build())
+    fit_algo = otexp.GaussianProcessFitter(x, y, model, ot.LinearBasisFactory().build())
     # set sensible optimization bounds and estimate hyper parameters
     fit_algo.run()
 
     # perform an evaluation
     fit_result = fit_algo.getResult()
-    algo = GaussianProcessRegression(fit_result)
+    algo = otexp.GaussianProcessRegression(fit_result)
 
     algo.run()
     result = algo.getResult()
     mm = result.getMetaModel()
-    ott.assert_almost_equal(mm([5.5]), [5.58283])
+    y = mm([5.5])
+    print(y)
+    ott.assert_almost_equal(y, [5.58843])
 
 
 def test_gpr_no_opt():
@@ -195,7 +193,7 @@ def test_gpr_no_opt():
     covarianceModel = ot.SquaredExponential([1.6326932047296538], [4.895995962015954])
     trend_function = ot.SymbolicFunction("x", "1.49543")
     # GPR (comparable with test_one_input_one_output)
-    algo = GaussianProcessRegression(X, Y, covarianceModel, trend_function)
+    algo = otexp.GaussianProcessRegression(X, Y, covarianceModel, trend_function)
     algo.run()
     result = algo.getResult()
     Yhat = result.getMetaModel()(X)
