@@ -10,9 +10,11 @@ ot.PlatformInfo.SetNumericalPrecision(3)
 
 # Calibration of default optimizer
 ot.ResourceMap.SetAsScalar(
-    'GeneralLinearModelAlgorithm-DefaultOptimizationLowerBound', 1.0e-5)
+    "GeneralLinearModelAlgorithm-DefaultOptimizationLowerBound", 1.0e-5
+)
 ot.ResourceMap.SetAsScalar(
-    'GeneralLinearModelAlgorithm-DefaultOptimizationUpperBound', 100)
+    "GeneralLinearModelAlgorithm-DefaultOptimizationUpperBound", 100
+)
 # Data & estimation
 inputDimension = 1
 X = ot.Normal().getSample(100)
@@ -22,7 +24,7 @@ model = ot.SymbolicFunction(["x"], ["x - 0.6 * cos(x/3)"])
 Y = model(X)
 basis = ot.QuadraticBasisFactory(inputDimension).build()
 algo = ot.GeneralLinearModelAlgorithm(X, Y, covarianceModel, basis, True)
-algo.setOptimizationAlgorithm(ot.NLopt('LN_NELDERMEAD'))
+algo.setOptimizationAlgorithm(ot.NLopt("LN_NELDERMEAD"))
 algo.run()
 
 # perform an evaluation
@@ -30,10 +32,10 @@ result = algo.getResult()
 metaModel = result.getMetaModel()
 conditionalCovariance = result.getCovarianceModel()
 residual = metaModel(X) - Y
-ott.assert_almost_equal(residual.computeCenteredMoment(2),
-                        [1.06e-05], 1e-5, 1e-5)
-ott.assert_almost_equal(conditionalCovariance.getParameter(),
-                        [0.619144, 0.000937], 5e-3, 1e-3)
+ott.assert_almost_equal(residual.computeCentralMoment(2), [1.06e-05], 1e-5, 1e-5)
+ott.assert_almost_equal(
+    conditionalCovariance.getParameter(), [0.619144, 0.000937], 5e-3, 1e-3
+)
 likelihood = algo.getObjectiveFunction()
 assert likelihood.getInputDimension() == 1, "likelihood dim"
 print("ok")
