@@ -1,6 +1,7 @@
 #! /usr/bin/env python
 
 import openturns as ot
+import openturns.testing as ott
 
 ot.TESTPREAMBLE()
 
@@ -19,13 +20,6 @@ print("Continuous = ", distribution.isContinuous())
 oneRealization = distribution.getRealization()
 print("oneRealization=", repr(oneRealization))
 
-# Test for sampling
-size = 10000
-oneSample = distribution.getSample(size)
-print("oneSample first=", repr(oneSample[0]), " last=", repr(oneSample[1]))
-print("mean=", repr(oneSample.computeMean()))
-print("covariance=", repr(oneSample.computeCovariance()))
-
 # Define a point
 point = ot.Point(distribution.getDimension(), 3.0)
 print("Point= ", repr(point))
@@ -35,38 +29,16 @@ eps = 1e-5
 # PDF value
 PDF = distribution.computePDF(point)
 print("pdf     =%.6f" % PDF)
-# by the finite difference technique from CDF
-print(
-    "pdf (FD)=%.6f"
-    % (
-        distribution.computeCDF(point + ot.Point(1, 0))
-        - distribution.computeCDF(point + ot.Point(1, -1))
-    )
-)
 
 # derivative of the PDF with regards the parameters of the distribution
 CDF = distribution.computeCDF(point)
 print("cdf=%.6f" % CDF)
 PDFgr = distribution.computePDFGradient(point)
 print("pdf gradient     =", repr(PDFgr))
-# by the finite difference technique
-PDFgrFD = ot.Point(1)
-PDFgrFD[0] = (
-    ot.Geometric(distribution.getP() + eps).computePDF(point)
-    - ot.Geometric(distribution.getP() - eps).computePDF(point)
-) / (2.0 * eps)
-print("pdf gradient (FD)=", repr(PDFgrFD))
 
 # derivative of the PDF with regards the parameters of the distribution
 CDFgr = distribution.computeCDFGradient(point)
 print("cdf gradient     =", repr(CDFgr))
-# by the finite difference technique
-CDFgrFD = ot.Point(1)
-CDFgrFD[0] = (
-    ot.Geometric(distribution.getP() + eps).computeCDF(point)
-    - ot.Geometric(distribution.getP() - eps).computeCDF(point)
-) / (2.0 * eps)
-print("cdf gradient (FD)=", repr(CDFgrFD))
 
 # quantile
 quantile = distribution.computeQuantile(0.95)
@@ -90,3 +62,7 @@ print("Standard representative=", distribution.getStandardRepresentative())
 # computeProbability regression test for discrete distributions
 p = ot.Geometric(0.5).computeProbability(ot.Interval(2, 6))
 assert p == 0.484375, "wrong discrete interval proba"
+
+ot.Log.Show(ot.Log.TRACE)
+validation = ott.DistributionValidation(distribution)
+validation.run()
