@@ -4,6 +4,8 @@ import openturns as ot
 import openturns.testing as ott
 import math as m
 
+ot.RandomGenerator.SetSeed(0)
+
 ot.TESTPREAMBLE()
 
 
@@ -68,15 +70,13 @@ mh_coll = [
 for mh in mh_coll:
     mh.setLikelihood(conditional, y_obs, linkFunction, p)
 sampler = ot.Gibbs(mh_coll)
-sampler.setThinning(4)
-sampler.setBurnIn(2000)
 
 # get a realization
 realization = sampler.getRealization()
 print("y1=", realization)
 
 # try to generate a sample
-sampleSize = 1000
+sampleSize = 10000
 sample = sampler.getSample(sampleSize)
 
 x_mu = sample.computeMean()
@@ -109,8 +109,8 @@ mu_exp = Qn.solveLinearSystem((P.transpose() * P) * x_emp + ot.Matrix(Q0) * mu0)
 
 print("sample mean=", x_mu)
 print("expected mean=", mu_exp)
-ott.assert_almost_equal(x_mu, mu_exp, 1e-1, 1e-3)
+ott.assert_almost_equal(x_mu, mu_exp, 1e-1, 1e-1)
 
 print("covariance=", x_cov)
 print("expected covariance=", Qn_inv)
-ott.assert_almost_equal(x_cov, Qn_inv, 1e-3, 2e-2)
+ott.assert_almost_equal(x_cov, Qn_inv, 1e-1, 2e-1)
