@@ -23,7 +23,7 @@ for i in range(size):
 discreteSample1 = ot.Poisson(0.1).getSample(size)
 discreteSample2 = ot.Geometric(0.4).getSample(size)
 
-# ChiSquared Independance test : test if two samples (of sizes not necessarily equal) are independent ?
+# ChiSquared Independence test : test if two samples (of sizes not necessarily equal) are independent ?
 # Care : discrete samples only
 # H0 = independent samples
 # p-value threshold : probability of the H0 reject zone : 0.10
@@ -49,7 +49,5 @@ print("Pearson=", ot.HypothesisTest.Pearson(sampleY, sampleZ, 0.10))
 ot.RandomGenerator.SetSeed(0)
 sample1 = ot.Normal().getSample(20)
 sample2 = ot.Normal(0.1, 1.1).getSample(30)
-resultTwoSamplesKolmogorov = ot.HypothesisTest.TwoSamplesKolmogorov(
-    sample1, sample2
-)
+resultTwoSamplesKolmogorov = ot.HypothesisTest.TwoSamplesKolmogorov(sample1, sample2)
 print(resultTwoSamplesKolmogorov)
