@@ -7,7 +7,7 @@ ot.TESTPREAMBLE()
 distribution = ot.Normal(4)
 size = 10
 weightingDistribution = ot.Normal(distribution)
-weightingDistribution.setMean(ot.Point(4, 1.0))
+weightingDistribution.setMu(ot.Point(4, 1.0))
 experiment = ot.ImportanceSamplingExperiment(distribution, weightingDistribution, size)
 print("experiment = ", experiment)
 sample, weights = experiment.generateWithWeights()
