@@ -8,6 +8,6 @@ dim = 2
 transformation = ot.InverseNatafIndependentCopulaGradient(dim)
 print("transformation=", repr(transformation))
 point = ot.Point(dim, 0.75)
-print("transformation(", point, ")=", repr(transformation.gradient(point).clean(1e-6)))
+print("transformation(", point, ")=", repr(transformation.gradient(point)))
 print("input dimension=", transformation.getInputDimension())
 print("output dimension=", transformation.getOutputDimension())
