@@ -22,7 +22,8 @@ solver.setMaximumAbsoluteError(1.0e-10)
 solver.setMaximumRelativeError(1.0e-10)
 solver.setMaximumResidualError(1.0e-10)
 solver.setMaximumConstraintError(1.0e-10)
-algo = ot.FORM(solver, event, distribution.getMean())
+solver.setStartingPoint(distribution.getMean())
+algo = ot.FORM(solver, event)
 algo.run()
 result = algo.getResult()
 hasoferReliabilityIndexSensitivity = result.getHasoferReliabilityIndexSensitivity()
