@@ -12,7 +12,8 @@ transformation = ot.InverseRosenblattEvaluation(distribution)
 print("transformation=", repr(transformation))
 point = ot.Point(dim, 0.75)
 print("transformation(", point, ")=", repr(transformation(point)))
-print("transformation parameters gradient=", repr(
-    transformation.parameterGradient(point)))
+print(
+    "transformation parameters gradient=", repr(transformation.parameterGradient(point))
+)
 print("input dimension=", transformation.getInputDimension())
 print("output dimension=", transformation.getOutputDimension())
