@@ -33,7 +33,7 @@ aCollection.add(ot.Gamma(2.0, 2.0, 0.0))
 dim = aCollection.getSize()
 
 # Instantiate one distribution object
-distribution = ot.ComposedDistribution(aCollection, ot.IndependentCopula(dim))
+distribution = ot.JointDistribution(aCollection, ot.IndependentCopula(dim))
 # Test for sampling
 size = 10000
 sample = distribution.getSample(size)
@@ -72,13 +72,13 @@ point = ot.Point(dim, 1.0)
 print("point=", repr(point))
 transformedPoint = transform(point)
 print("transform value at point        =", repr(transformedPoint))
-print("transform gradient at point     =", repr(transform.gradient(point).clean(1e-6)))
+print("transform gradient at point     =", repr(transform.gradient(point)))
 print(
     "transform gradient at point (FD)=",
     repr(
-        ot.CenteredFiniteDifferenceGradient(1.0e-5, transform.getEvaluation())
-        .gradient(point)
-        .clean(1e-6)
+        ot.CenteredFiniteDifferenceGradient(1.0e-5, transform.getEvaluation()).gradient(
+            point
+        )
     ),
 )
 print(
@@ -101,14 +101,14 @@ print(
 )
 print(
     "inverse transform gradient at transformed point     =",
-    repr(inverseTransform.gradient(transformedPoint).clean(1e-6)),
+    repr(inverseTransform.gradient(transformedPoint)),
 )
 print(
     "inverse transform gradient at transformed point (FD)=",
     repr(
-        ot.CenteredFiniteDifferenceGradient(1.0e-5, inverseTransform.getEvaluation())
-        .gradient(transformedPoint)
-        .clean(1e-6)
+        ot.CenteredFiniteDifferenceGradient(
+            1.0e-5, inverseTransform.getEvaluation()
+        ).gradient(transformedPoint)
     ),
 )
 print(
@@ -138,9 +138,9 @@ gradient = ot.Matrix(5, 2)
 coll = ot.DistributionCollection(dim)
 coll[0] = ot.Uniform(-1.0 + eps, 2.0)
 coll[1] = aCollection[1]
-left = ot.ComposedDistribution(coll).getIsoProbabilisticTransformation()
+left = ot.JointDistribution(coll).getIsoProbabilisticTransformation()
 coll[0] = ot.Uniform(-1.0 - eps, 2.0)
-right = ot.ComposedDistribution(coll).getIsoProbabilisticTransformation()
+right = ot.JointDistribution(coll).getIsoProbabilisticTransformation()
 dTdp = (left(point) - right(point)) * factor
 gradient[0, 0] = dTdp[0]
 gradient[0, 1] = dTdp[1]
@@ -148,9 +148,9 @@ gradient[0, 1] = dTdp[1]
 coll = ot.DistributionCollection(dim)
 coll[0] = ot.Uniform(-1.0, 2.0 + eps)
 coll[1] = aCollection[1]
-left = ot.ComposedDistribution(coll).getIsoProbabilisticTransformation()
+left = ot.JointDistribution(coll).getIsoProbabilisticTransformation()
 coll[0] = ot.Uniform(-1.0, 2.0 - eps)
-right = ot.ComposedDistribution(coll).getIsoProbabilisticTransformation()
+right = ot.JointDistribution(coll).getIsoProbabilisticTransformation()
 dTdp = (left(point) - right(point)) * factor
 gradient[1, 0] = dTdp[0]
 gradient[1, 1] = dTdp[1]
@@ -158,9 +158,9 @@ gradient[1, 1] = dTdp[1]
 coll = ot.DistributionCollection(dim)
 coll[0] = aCollection[0]
 coll[1] = ot.Gamma(2.0 + eps, 2.0, 0.0)
-left = ot.ComposedDistribution(coll).getIsoProbabilisticTransformation()
+left = ot.JointDistribution(coll).getIsoProbabilisticTransformation()
 coll[1] = ot.Gamma(2.0 - eps, 2.0, 0.0)
-right = ot.ComposedDistribution(coll).getIsoProbabilisticTransformation()
+right = ot.JointDistribution(coll).getIsoProbabilisticTransformation()
 dTdp = (left(point) - right(point)) * factor
 gradient[2, 0] = dTdp[0]
 gradient[2, 1] = dTdp[1]
@@ -169,9 +169,9 @@ gradient[2, 1] = dTdp[1]
 coll = ot.DistributionCollection(dim)
 coll[0] = aCollection[0]
 coll[1] = ot.Gamma(2.0, 2.0 + eps, 0.0)
-left = ot.ComposedDistribution(coll).getIsoProbabilisticTransformation()
+left = ot.JointDistribution(coll).getIsoProbabilisticTransformation()
 coll[1] = ot.Gamma(2.0, 2.0 - eps, 0.0)
-right = ot.ComposedDistribution(coll).getIsoProbabilisticTransformation()
+right = ot.JointDistribution(coll).getIsoProbabilisticTransformation()
 dTdp = (left(point) - right(point)) * factor
 gradient[3, 0] = dTdp[0]
 gradient[3, 1] = dTdp[1]
@@ -180,9 +180,9 @@ gradient[3, 1] = dTdp[1]
 coll = ot.DistributionCollection(dim)
 coll[0] = aCollection[0]
 coll[1] = ot.Gamma(2.0, 2.0, 0.0 + eps)
-left = ot.ComposedDistribution(coll).getIsoProbabilisticTransformation()
+left = ot.JointDistribution(coll).getIsoProbabilisticTransformation()
 coll[1] = ot.Gamma(2.0, 2.0, 0.0 - eps)
-right = ot.ComposedDistribution(coll).getIsoProbabilisticTransformation()
+right = ot.JointDistribution(coll).getIsoProbabilisticTransformation()
 dTdp = (left(point) - right(point)) * factor
 gradient[4, 0] = dTdp[0]
 gradient[4, 1] = dTdp[1]
@@ -199,9 +199,9 @@ print(
 coll = ot.DistributionCollection(dim)
 coll[0] = ot.Uniform(-1.0 + eps, 2.0)
 coll[1] = aCollection[1]
-left = ot.ComposedDistribution(coll).getInverseIsoProbabilisticTransformation()
+left = ot.JointDistribution(coll).getInverseIsoProbabilisticTransformation()
 coll[0] = ot.Uniform(-1.0 - eps, 2.0)
-right = ot.ComposedDistribution(coll).getInverseIsoProbabilisticTransformation()
+right = ot.JointDistribution(coll).getInverseIsoProbabilisticTransformation()
 dTdp = (left(point) - right(point)) * factor
 gradient[0, 0] = dTdp[0]
 gradient[0, 1] = dTdp[1]
@@ -209,9 +209,9 @@ gradient[0, 1] = dTdp[1]
 coll = ot.DistributionCollection(dim)
 coll[0] = ot.Uniform(-1.0, 2.0 + eps)
 coll[1] = aCollection[1]
-left = ot.ComposedDistribution(coll).getInverseIsoProbabilisticTransformation()
+left = ot.JointDistribution(coll).getInverseIsoProbabilisticTransformation()
 coll[0] = ot.Uniform(-1.0, 2.0 - eps)
-right = ot.ComposedDistribution(coll).getInverseIsoProbabilisticTransformation()
+right = ot.JointDistribution(coll).getInverseIsoProbabilisticTransformation()
 dTdp = (left(point) - right(point)) * factor
 gradient[1, 0] = dTdp[0]
 gradient[1, 1] = dTdp[1]
@@ -219,9 +219,9 @@ gradient[1, 1] = dTdp[1]
 coll = ot.DistributionCollection(dim)
 coll[0] = aCollection[0]
 coll[1] = ot.Gamma(2.0 + eps, 2.0, 0.0)
-left = ot.ComposedDistribution(coll).getInverseIsoProbabilisticTransformation()
+left = ot.JointDistribution(coll).getInverseIsoProbabilisticTransformation()
 coll[1] = ot.Gamma(2.0 - eps, 2.0, 0.0)
-right = ot.ComposedDistribution(coll).getInverseIsoProbabilisticTransformation()
+right = ot.JointDistribution(coll).getInverseIsoProbabilisticTransformation()
 dTdp = (left(point) - right(point)) * factor
 gradient[2, 0] = dTdp[0]
 gradient[2, 1] = dTdp[1]
@@ -229,9 +229,9 @@ gradient[2, 1] = dTdp[1]
 coll = ot.DistributionCollection(dim)
 coll[0] = aCollection[0]
 coll[1] = ot.Gamma(2.0, 2.0 + eps, 0.0)
-left = ot.ComposedDistribution(coll).getInverseIsoProbabilisticTransformation()
+left = ot.JointDistribution(coll).getInverseIsoProbabilisticTransformation()
 coll[1] = ot.Gamma(2.0, 2.0 - eps, 0.0)
-right = ot.ComposedDistribution(coll).getInverseIsoProbabilisticTransformation()
+right = ot.JointDistribution(coll).getInverseIsoProbabilisticTransformation()
 dTdp = (left(point) - right(point)) * factor
 gradient[3, 0] = dTdp[0]
 gradient[3, 1] = dTdp[1]
@@ -239,9 +239,9 @@ gradient[3, 1] = dTdp[1]
 coll = ot.DistributionCollection(dim)
 coll[0] = aCollection[0]
 coll[1] = ot.Gamma(2.0, 2.0, 0.0 + eps)
-left = ot.ComposedDistribution(coll).getInverseIsoProbabilisticTransformation()
+left = ot.JointDistribution(coll).getInverseIsoProbabilisticTransformation()
 coll[1] = ot.Gamma(2.0, 2.0, 0.0 - eps)
-right = ot.ComposedDistribution(coll).getInverseIsoProbabilisticTransformation()
+right = ot.JointDistribution(coll).getInverseIsoProbabilisticTransformation()
 dTdp = (left(point) - right(point)) * factor
 gradient[4, 0] = dTdp[0]
 gradient[4, 1] = dTdp[1]
