@@ -1,7 +1,4 @@
 import openturns as ot
-import unittest
-import openturns.testing as ott
-import sys
 
 ot.TESTPREAMBLE()
 
@@ -26,7 +23,8 @@ graph4 = klresult.drawCumulatedEigenvaluesRemainder()
 graph4.setLogScale(ot.GraphImplementation.LOGY)
 if 0:
     from openturns.viewer import View
-    View(graph1).save('eigen1.png')
-    View(graph2).save('eigen2.png')
-    View(graph3).save('eigen3.png')
-    View(graph4).save('eigen4.png')
+
+    View(graph1).save("eigen1.png")
+    View(graph2).save("eigen2.png")
+    View(graph3).save("eigen3.png")
+    View(graph4).save("eigen4.png")
