@@ -159,5 +159,13 @@ distribution.setParameter(parameters)
 
 ot.Log.Show(ot.Log.TRACE)
 validation = ott.DistributionValidation(distribution)
-validation.skipCorrelation()  # slow
+validation.skipDependenceMeasures()  # slow
 validation.run()
+
+# Instantiate a distribution and test EnableInterpolation
+ot.ResourceMap.SetAsBool("KernelMixture-EnableInterpolation", True)
+for i in range(20):
+    meanPoint += [1.0] * dimension
+    sample.add(meanPoint)
+distribution2 = ot.KernelMixture(ot.Normal(), sigma, sample)
+ott.assert_almost_equal(distribution2.computePDF(point), 0.000709, 0.01, 0.0)
