@@ -41,8 +41,5 @@ ott.assert_almost_equal(
     krigingFittedCovarianceModel.getAmplitude()[0], 6.65231, 0.0, 1e-4
 )
 
-try:
+with ott.assert_raises(TypeError):
     ot.IsotropicCovarianceModel(ot.SquaredExponential(), 0)
-    raise ValueError("Invalid IsotropicCovarianceModel should have thrown")
-except TypeError:
-    pass
