@@ -83,4 +83,4 @@ basis = ot.LinearBasisFactory(1).build()
 algo = ot.LinearModelAlgorithm(input_sample, output_sample, basis)
 algo.run()
 result = algo.getResult()
-print(result.getCoefficients(), result.getDegreesOfFreedom(), result.getResiduals())
+print(result.getCoefficients(), result.getDegreesOfFreedom())
