@@ -1,9 +1,9 @@
 #! /usr/bin/env python
 
 import openturns as ot
+import openturns.testing as ott
 
 ot.TESTPREAMBLE()
-ot.RandomGenerator.SetSeed(0)
 
 
 # Force the use of the approximation to avoid timeout
@@ -42,8 +42,6 @@ print("covariance=", repr(oneSample.computeCovariance()))
 point = ot.Point([0.0, 3.2, 4.2, 5.0])
 print("Point= ", point)
 
-# Show PDF and CDF of point
-# eps = 1e-5
 # derivative of PDF with regards its arguments
 DDF = distribution.computeDDF(point)
 print("ddf     =", repr(DDF))
@@ -70,24 +68,6 @@ print("quantile=", repr(quantile))
 print("cdf(quantile)=%.6f" % distribution.computeCDF(quantile))
 condQuantile = distribution.computeConditionalQuantile(0.4, [0.0, 2.0])
 print("condQuantile     =%.6f" % condQuantile)
-# Get 95% survival function TAKES TOO MUCH TIME
-# inverseSurvival = ot.Point(distribution.computeInverseSurvivalFunction(0.95))
-# print("InverseSurvival=", repr(inverseSurvival))
-# print("Survival(inverseSurvival)=%.6f" % distribution.computeSurvivalFunction(inverseSurvival))
-# Confidence regions
-# threshold = ot.Point()
-# print("Minimum volume interval=", distribution.computeMinimumVolumeInterval(0.95, threshold))
-# print("threshold=", threshold)
-# beta = ot.Point()
-# levelSet = distribution.computeMinimumVolumeLevelSet(0.95, beta)
-# print("Minimum volume level set=", levelSet)
-# print("beta=", beta)
-# print("Bilateral confidence interval=", distribution.computeBilateralConfidenceInterval(0.95, beta))
-# print("beta=", beta)
-# print("Unilateral confidence interval (lower tail)=", distribution.computeUnilateralConfidenceInterval(0.95, False, beta))
-# print("beta=", beta)
-# print("Unilateral confidence interval (upper tail)=", distribution.computeUnilateralConfidenceInterval(0.95, True, beta))
-# print("beta=", beta)
 
 mean = distribution.getMean()
 print("mean=", repr(mean))
@@ -131,3 +111,12 @@ quantile = ot.Point(margins.computeQuantile(0.8))
 print("margins quantile=", repr(quantile))
 print("margins CDF(qantile)=%.6f" % margins.computeCDF(quantile))
 print("margins realization=", repr(margins.getRealization()))
+
+ot.Log.Show(ot.Log.TRACE)
+validation = ott.DistributionValidation(distribution)
+validation.skipMoments()  # slow
+validation.skipCorrelation()  # slow
+validation.skipParameters()  # slow
+validation.skipConditional()  # FIXME
+validation.skipTransformation()  # FIXME
+validation.run()
