@@ -132,3 +132,22 @@ try:
     weights = mesh.computeWeights()
 except Exception:
     print("ok")
+
+# sub-mesh
+n = 4
+m2 = ot.IntervalMesher([n] * 2).build(ot.Interval([0.0] * 2, [1.0] * 2))
+submesh = m2.getSubMesh([0, 2])
+print(f"submesh={submesh}")
+assert len(submesh.getSimplices()) == 2
+assert sum(submesh.computeSimplicesVolume()) == 1 / 16, "wrong submesh"
+
+if ot.PlatformInfo.HasFeature("boost"):
+    vertices1 = [[0.0, 0.0], [2.0, 0.0], [0.0, 1.0]]
+    simplices1 = [[0, 1, 2]]
+    mesh1 = ot.Mesh(vertices1, simplices1)
+    mesh2 = ot.IntervalMesher([2] * 2).build(ot.Interval([-1.0] * 2, [1.0] * 2))
+    intersection = mesh1.intersect(mesh2)
+    vertices3 = [[0, 1], [0, 0], [1, 0], [0, 1], [1, 0], [1, 0.5]]
+    simplices3 = [[0, 1, 2], [3, 4, 5]]
+    mesh3 = ot.Mesh(vertices3, simplices3)
+    assert intersection == mesh3, "wrong intersection"
