@@ -1,6 +1,7 @@
 #! /usr/bin/env python
 
 import openturns as ot
+import openturns.testing as ott
 
 ot.TESTPREAMBLE()
 
@@ -20,13 +21,6 @@ print("Continuous = ", distribution.isContinuous())
 oneRealization = distribution.getRealization()
 print("oneRealization=", oneRealization)
 
-# Test for sampling
-size = 10000
-oneSample = distribution.getSample(size)
-print("oneSample first=", repr(oneSample[0]), " last=", repr(oneSample[1]))
-print("mean=", repr(oneSample.computeMean()))
-print("covariance=", repr(oneSample.computeCovariance()))
-
 print("support=\n" + str(distribution.getSupport()))
 interval = ot.Interval(
     ot.Point(distribution.getDimension(), 1.0),
@@ -72,3 +66,10 @@ parameter = distribution.getParameter()
 print("parameter=", repr(parameter))
 print("parameterDesc=", distribution.getParameterDescription())
 distribution.setParameter(parameter)
+
+ot.Log.Show(ot.Log.TRACE)
+validation = ott.DistributionValidation(distribution)
+validation.skipMoments()  # slow
+validation.skipCorrelation()  # slow
+validation.skipConditional()  # FIXME
+validation.run()
