@@ -1,6 +1,7 @@
 #! /usr/bin/env python
 
 import openturns as ot
+import openturns.testing as ott
 
 ref = ot.SymbolicFunction("x", "sin(x)")
 size = 12
@@ -21,3 +22,13 @@ for x in X:
     print("f( %.12g )=" % x[0], evaluation(x), ", ref=", ref(x))
 Y = evaluation(X)
 print(Y)
+
+# Test exception enableExtrapolation
+locations = [1.0, 2.0, 3.0, 4.0, 5.0]
+values = [-2.0, 2.0, 1.0, 3.0, 5.0]
+derivatives = [0.0] * 5
+evaluation = ot.PiecewiseHermiteEvaluation(locations, values, derivatives)
+evaluation.setEnableExtrapolation(False)
+f = ot.Function(evaluation)
+with ott.assert_raises(TypeError):
+    f([-12.5])
