@@ -3,21 +3,16 @@
 import openturns as ot
 
 for lx in range(10):
-    x = 2 ** lx
+    x = 2**lx
     print("x=", x, "log2=", ot.SpecFunc.Log2(x))
 
 for lx in range(10):
-    x = 2 ** lx - 1
+    x = 2**lx - 1
     print("x=", x, "bits=", ot.SpecFunc.BitCount(x))
 
 for x in [0, 1, 2, 3, 4, 10, 100, 1000]:
     print("x=", x, "nextpow2=", ot.SpecFunc.NextPowerOfTwo(x))
 
-for n in [4, 5, 17]:
-    for k in [2, 0, 7, 3]:
-        if k <= n:
-            print("n=", n, "k=", k, "binom=", ot.SpecFunc.BinomialCoefficient(n, k))
-
 for x in [-2.0, -1.0, 0.0, 1.0, 2.0]:
     for n in [0, 1, 2]:
         print("x=", x, "n=", n, "ipow=", ot.SpecFunc.IPow(x, n))
@@ -39,10 +34,8 @@ print(
     ot.SpecFunc.RegularizedIncompleteBeta(0.0, 1.0, 0.95, True),
 )
 
-x = [1.0, 2.0 ** 53, -(2.0 ** 53)]
-s1 = sum(x)
+x = [1.0, 2.0**53, -(2.0**53)]
 s2 = ot.SpecFunc.AccurateSum(x)
-assert s1 == 0.0, "sum(x) nonzero"
 assert s2 == 1.0, "accurate sum(x) not 1"
 
 # Clip01
