@@ -112,7 +112,6 @@ try:
     myStudy.add("simulationResult", simulationResult)
 
     cNameList = [
-        "LHS",
         "DirectionalSampling",
         "SimulationSensitivityAnalysis",
         "ProbabilitySimulationAlgorithm",
@@ -313,7 +312,6 @@ try:
     # KDTree
     kDTree = ot.KDTree()
     myStudy.fillObject("kDTree", kDTree)
-    print("kDTree = ", kDTree)
 
     # ArcsineMuSigma parameter loading
     ams_parameters = ot.ArcsineMuSigma()
@@ -354,7 +352,7 @@ try:
             "j=",
             j,
             "isnormal=",
-            ot.SpecFunc.IsNormal(point2[j]),
+            m.isfinite(point2[j]),
             "isnan=",
             m.isnan(point2[j]),
             "isinf=",
