@@ -1,6 +1,7 @@
 #! /usr/bin/env python
 
 import openturns as ot
+import openturns.testing as ott
 import math as m
 
 
@@ -97,25 +98,12 @@ for testCase in range(len(distribution)):
     CCDF = distribution[testCase].computeComplementaryCDF(point)
     print("ccdf=%.6f" % CCDF)
     print("cdf (ref)=%.6f" % referenceDistribution[testCase].computeCDF(point))
-    try:
-        PDFgr = distribution[testCase].computePDFGradient(point)
-        print("pdf gradient      =", repr(cleanPoint(PDFgr)))
-        print(
-            "pdf gradient (ref)=",
-            repr(cleanPoint(referenceDistribution[testCase].computePDFGradient(point))),
-        )
-    except Exception:
-        pass
 
-    try:
-        CDFgr = distribution[testCase].computeCDFGradient(point)
-        print("cdf gradient      =", repr(cleanPoint(CDFgr)))
-        print(
-            "cdf gradient (ref)=",
-            repr(cleanPoint(referenceDistribution[testCase].computeCDFGradient(point))),
-        )
-    except Exception:
-        pass
+    PDFgr = distribution[testCase].computePDFGradient(point)
+    print("pdf gradient      =", repr(cleanPoint(PDFgr)))
+
+    CDFgr = distribution[testCase].computeCDFGradient(point)
+    print("cdf gradient      =", repr(cleanPoint(CDFgr)))
 
     # quantile
     quantile = distribution[testCase].computeQuantile(0.95)
@@ -138,7 +126,10 @@ for testCase in range(len(distribution)):
         interval, threshold = distribution[
             testCase
         ].computeMinimumVolumeIntervalWithMarginalProbability(0.95)
+        prec = ot.PlatformInfo.GetNumericalPrecision()
+        ot.PlatformInfo.SetNumericalPrecision(5)
         print("Minimum volume interval=", interval)
+        ot.PlatformInfo.SetNumericalPrecision(prec)
         print("threshold=", ot.Point(1, threshold))
         levelSet, beta = distribution[
             testCase
@@ -195,6 +186,23 @@ for testCase in range(len(distribution)):
         "Standard representative=",
         referenceDistribution[testCase].getStandardRepresentative(),
     )
+
+    mean = distribution[testCase].getMean()
+    cpdf = distribution[testCase].computeConditionalPDF(mean[0], [])
+    print(f"conditional PDF={cpdf:.6f}")
+    scpdf = distribution[testCase].computeSequentialConditionalPDF(mean)
+    print(f"sequential conditional PDF={scpdf}")
+    ccdf = distribution[testCase].computeConditionalCDF(mean[0], [])
+    print(f"conditional CDF={ccdf:.6f}")
+    sccdf = distribution[testCase].computeSequentialConditionalCDF(mean)
+    print(f"sequential conditional CDF={sccdf}")
+
+    ot.Log.Show(ot.Log.TRACE)
+    ot.RandomGenerator.SetSeed(1)
+    validation = ott.DistributionValidation(distribution[testCase])
+    validation.skipMinimumVolumeLevelSet()  # slow
+    validation.run()
+
 # Check simplification
 candidates = [
     ot.Normal(1.0, 2.0),
@@ -202,6 +210,10 @@ candidates = [
     ot.Exponential(1.0, 2.0),
     ot.TruncatedDistribution(ot.WeibullMin(), 1.5, 7.8),
     ot.Beta(1.5, 6.3, -1.0, 2.0),
+    ot.JointDistribution([ot.Normal()] * 2),
+    ot.BlockIndependentDistribution([ot.Normal(2), ot.Normal(2)]),
+    ot.BlockIndependentCopula([ot.NormalCopula(2), ot.NormalCopula(2)]),
+    ot.Dirichlet([0.7, 0.3]),
 ]
 intervals = [
     ot.Interval(-1.0, 4.0),
@@ -209,6 +221,10 @@ intervals = [
     ot.Interval(2.5, 65.0),
     ot.Interval(2.5, 6.0),
     ot.Interval(-2.5, 6.0),
+    ot.Interval(2),
+    ot.Interval(4),
+    ot.Interval(4),
+    ot.Interval(0.2, 2.4),
 ]
 for i in range(len(candidates)):
     d = ot.TruncatedDistribution(candidates[i], intervals[i])
@@ -238,3 +254,11 @@ dim = 10
 unif = ot.JointDistribution([ot.Uniform(0.0, 1.0)] * dim)
 trunc = ot.TruncatedDistribution(unif, ot.Interval([0.0] * dim, [1e-6] * dim))
 x = trunc.getRealization()
+
+# marginal of truncated is not truncated marginal
+R = ot.CorrelationMatrix(2)
+R[1, 0] = 0.8
+normal = ot.Normal([0.0] * 2, [1.0] * 2, R)
+trunc = ot.TruncatedDistribution(normal, ot.Interval([-0.5] * 2, [1.0] * 2))
+marginal0 = trunc.getMarginal(0)
+ott.assert_almost_equal(marginal0.getMean(), [0.220527])
