@@ -10,8 +10,8 @@ ot.RandomGenerator.SetSeed(0)
 
 mu = [0.0] * 4
 sigma = [1.0] * 4
-a = [-4., -1., 1., 3.]
-b = [4., 4., 2., 6.]
+a = [-4.0, -1.0, 1.0, 3.0]
+b = [4.0, 4.0, 2.0, 6.0]
 
 for i in range(4):
     ot.PlatformInfo.SetNumericalPrecision(1 if i == 2 else 2)
@@ -24,8 +24,7 @@ for i in range(4):
     print("Estimated distribution=", repr(estimatedDistribution))
     estimatedDistribution = factory.build()
     print("Default distribution=", estimatedDistribution)
-    estimatedDistribution = factory.build(
-        distribution.getParameter())
+    estimatedDistribution = factory.build(distribution.getParameter())
     print("Distribution from parameters=", estimatedDistribution)
     estimatedTruncatedNormal = factory.buildAsTruncatedNormal(sample)
     print("TruncatedNormal          =", distribution)
@@ -33,15 +32,16 @@ for i in range(4):
     estimatedTruncatedNormal = factory.buildAsTruncatedNormal()
     print("Default TruncatedNormal=", estimatedTruncatedNormal)
     estimatedTruncatedNormal = factory.buildAsTruncatedNormal(
-        distribution.getParameter())
+        distribution.getParameter()
+    )
     print("TruncatedNormal from parameters=", estimatedTruncatedNormal)
     # Various estimators
     estimatedDistribution = factory.build(sample)
-    print('Estimated distribution with default estimator =', estimatedDistribution)
+    print("Estimated distribution with default estimator =", estimatedDistribution)
     estimatedDistribution = factory.buildMethodOfMoments(sample)
-    print('Estimated distribution with moments=', estimatedDistribution)
+    print("Estimated distribution with moments=", estimatedDistribution)
     estimatedDistribution = factory.buildMethodOfLikelihoodMaximization(sample)
-    print('Estimated distribution with likelihoodMax.=', estimatedDistribution)
+    print("Estimated distribution with likelihoodMax.=", estimatedDistribution)
 
 
 # Build method of moments
@@ -59,8 +59,8 @@ computed_mu = estimatedTN.getMean()[0]
 computed_sigma2 = estimatedTN.getCovariance()[0, 0]
 computed_a = estimatedTN.getA()
 computed_b = estimatedTN.getB()
-ott.assert_almost_equal(exact_mu, computed_mu, 1.e-2, 0.0)
-ott.assert_almost_equal(exact_sigma2, computed_sigma2, 1.e-3, 0.0)
+ott.assert_almost_equal(exact_mu, computed_mu, 1.0e-2, 0.0)
+ott.assert_almost_equal(exact_sigma2, computed_sigma2, 1.0e-3, 0.0)
 ott.assert_almost_equal(exact_a, computed_a, 0.0, 10.0 / size)
 ott.assert_almost_equal(exact_b, computed_b, 0.0, 10.0 / size)
 
@@ -86,15 +86,26 @@ ott.assert_almost_equal(exact_b, computed_b, 0.0, 20.0 / size)
 
 # A tricky case
 print("A tricky case")
-data = [0.6852, 0.9349, 0.5884, 1.727, 1.581, 0.3193, -0.5701, 1.623, 2.210,
-        -0.3440, -0.1646]
+data = [
+    0.6852,
+    0.9349,
+    0.5884,
+    1.727,
+    1.581,
+    0.3193,
+    -0.5701,
+    1.623,
+    2.210,
+    -0.3440,
+    -0.1646,
+]
 sample = [[x] for x in data]
 factory = ot.TruncatedNormalFactory()
 estimatedTN = factory.buildMethodOfMoments(sample)
 exact_mu = -1.0
 exact_sigma = 2.5
-exact_a = 2.
-exact_b = 3.
+exact_a = 2.0
+exact_b = 3.0
 computed_mu = estimatedTN.getMu()
 computed_sigma = estimatedTN.getSigma()
 computed_a = estimatedTN.getA()
