@@ -211,7 +211,8 @@ solver.setMaximumAbsoluteError(1.0e-10)
 solver.setMaximumRelativeError(1.0e-10)
 solver.setMaximumResidualError(1.0e-10)
 solver.setMaximumConstraintError(1.0e-10)
-algo = ot.FORM(solver, event, mean)
+solver.setStartingPoint(mean)
+algo = ot.FORM(solver, event)
 algo.run()
 result = algo.getResult()
 graph, _ = result.drawHasoferReliabilityIndexSensitivity()
