@@ -16,8 +16,7 @@ print("distribution (circular)           =", repr(distribution))
 print("Estimated distribution (circular) =", repr(estimatedDistribution))
 estimatedDistribution = factory.build()
 print("Default distribution=", estimatedDistribution)
-estimatedDistribution = factory.build(
-    distribution.getParameter())
+estimatedDistribution = factory.build(distribution.getParameter())
 print("Distribution from parameters=", estimatedDistribution)
 estimatedVonMises = factory.buildAsVonMises(sample)
 print("VonMises          =", distribution)
