@@ -1,78 +1,43 @@
 #! /usr/bin/env python
 
 import openturns as ot
-
-# from math import *
+import openturns.testing as ott
 
 ot.TESTPREAMBLE()
 
-
-def cleanScalar(inScalar):
-    if abs(inScalar) < 1.0e-10:
-        inScalar = 0.0
-    return inScalar
-
-
 #
 # Physical model
 #
-
-inputFunction = ot.Description(2)
-inputFunction[0] = "r"
-inputFunction[1] = "s"
-
-outputFunction = ot.Description(1)
-outputFunction[0] = "g"
-
-formulas = ot.Description(outputFunction.getSize())
-formulas[0] = "r - s^2"
-
-limitState = ot.SymbolicFunction(inputFunction, outputFunction, formulas)
-
+limitState = ot.SymbolicFunction(["r", "s"], ["r - s^2"])
 dim = limitState.getInputDimension()
 
 #
 # Probabilistic model
 #
-
-mean = ot.Point(dim)
-mean[0] = 11.0
-mean[1] = 1.5
-
-sigma = ot.Point(dim)
-sigma[0] = 1.0
-sigma[1] = 0.5
-
+mean = [11.0, 1.5]
+sigma = [1.0, 0.5]
 R = ot.CorrelationMatrix(dim)
 myDistribution = ot.Normal(mean, sigma, R)
 
-start = myDistribution.getMean()
-
 #
 # Limit state
 #
-
 vect = ot.RandomVector(myDistribution)
-
-output = ot.RandomVector(limitState, vect)
-
+output = ot.CompositeRandomVector(limitState, vect)
 myEvent = ot.ThresholdEvent(output, ot.Less(), 0.0)
 
-#
-# Calculs
-#
-
 #
 # FORM/SORM Cobyla
 myCobyla = ot.Cobyla()
-myCobyla.setMaximumEvaluationNumber(1000 * dim)
+myCobyla.setMaximumCallsNumber(1000 * dim)
 myCobyla.setMaximumAbsoluteError(1.0e-4)
 myCobyla.setMaximumRelativeError(1.0e-4)
 myCobyla.setMaximumResidualError(1.0e-4)
 myCobyla.setMaximumConstraintError(1.0e-4)
+myCobyla.setStartingPoint(myDistribution.getMean())
 
-myAlgoC = ot.FORM(myCobyla, myEvent, start)
-myAlgoC2 = ot.SORM(myCobyla, myEvent, start)
+myAlgoC = ot.FORM(myCobyla, myEvent)
+myAlgoC2 = ot.SORM(myCobyla, myEvent)
 
 myAlgoC.run()
 myAlgoC2.run()
@@ -88,9 +53,10 @@ myAbdoRackwitz.setMaximumAbsoluteError(1.0e-4)
 myAbdoRackwitz.setMaximumRelativeError(1.0e-4)
 myAbdoRackwitz.setMaximumResidualError(1.0e-4)
 myAbdoRackwitz.setMaximumConstraintError(1.0e-4)
+myAbdoRackwitz.setStartingPoint(myDistribution.getMean())
 
-myAlgoAR = ot.FORM(myAbdoRackwitz, myEvent, start)
-myAlgoAR2 = ot.SORM(myAbdoRackwitz, myEvent, start)
+myAlgoAR = ot.FORM(myAbdoRackwitz, myEvent)
+myAlgoAR2 = ot.SORM(myAbdoRackwitz, myEvent)
 
 myAlgoAR.run()
 myAlgoAR2.run()
@@ -101,17 +67,24 @@ resultAR2 = myAlgoAR2.getResult()
 #
 # Monte Carlo
 CoV_MC = 0.1
-myMC = ot.MonteCarlo(myEvent)
+experiment = ot.MonteCarloExperiment()
+myMC = ot.ProbabilitySimulationAlgorithm(myEvent, experiment)
 myMC.setMaximumOuterSampling(1000000)
 myMC.setBlockSize(1000)
 myMC.setMaximumCoefficientOfVariation(CoV_MC)
 myMC.run()
+result = myMC.getResult()
+ott.assert_almost_equal(result.getProbabilityEstimate(), 0.000258312)
 
 #
 # LHS
 CoV_LHS = 0.1
-myLHS = ot.LHS(myEvent)
+experiment = ot.LHSExperiment()
+experiment.setAlwaysShuffle(True)
+myLHS = ot.ProbabilitySimulationAlgorithm(myEvent, experiment)
 myLHS.setMaximumOuterSampling(1000000)
 myLHS.setBlockSize(100)
 myLHS.setMaximumCoefficientOfVariation(CoV_LHS)
 myLHS.run()
+result = myMC.getResult()
+ott.assert_almost_equal(result.getProbabilityEstimate(), 0.000258312)
