@@ -2,7 +2,7 @@
 
 import openturns as ot
 from openturns.testing import assert_almost_equal
-from openturns.usecases import branin_function as branin_function
+from openturns.usecases import branin_function
 
 
 ot.TESTPREAMBLE()
