@@ -2,7 +2,7 @@
 
 import openturns as ot
 from openturns.testing import assert_almost_equal
-from openturns.usecases import chaboche_model as chaboche_model
+from openturns.usecases import chaboche_model
 
 
 ot.TESTPREAMBLE()
